#' ---
#' Title: "Optimised DNA isolation from marine sponges for natural sampler DNA (nsDNA) metabarcoding"
#' Author: "Lynsey Rebecca Harper"
#' Date: "29th October 2022"
#' ---
#' 
#' 
#' ## Prepare working environment
#' 
#' Clear R memory, set working directory and load required packages. 
#' 

## Clear memory
rm(list=ls())

## Set working directory to location of R script
# On first time running code: install.packages("rstudioapi")
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

## Check working directory
getwd()

## Load required packages "multcomp",
p <- c("plyr","tidyverse","ggpubr","scales","reshape2")
new.packages <- p[!(p %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages, 
                                          repos = "https://cran.ma.imperial.ac.uk/",
                                          dependencies=TRUE)
lapply(p, require, character.only = TRUE)

## To ensure reproducibility, print details about the version of R being
## used for analysis.
sessionInfo()



#' ---
#' 
#' ## 1) Raw metabarcoding datasets
#' 
#' The bioinformatics output is not particularly suited to applying
#' statistical analysis in R. Files must be manipulated for downstream 
#' analyses.
#' 

## Import metabarcoding data for Phase 1 and Phase 2.
tank.raw <- read.csv("../input_data/Horniman_sponge_blast80_denoise.csv", 
                     header = TRUE,
                     check.names = FALSE)

PHAK.VAZ.raw <- read.csv("../input_data/PHAK_VAZ_blast98_denoise.csv", 
                         header=TRUE,
                         check.names= FALSE)

## Make list of dataframes.
raw.data <- list(tank.raw, PHAK.VAZ.raw)
names(raw.data) <- c("tank.raw.formatted", "PHAK.VAZ.raw.formatted")

## Format dataframes for downstream analyses.
raw.data <- lapply(raw.data, function (x) {
  colnames(x)[1] <- "assignment"
  return(x)
})

## Unlist dataframes as one single dataframe. Remove taxonomy column and 
## replace NAs with 0. Correct taxonomic assignments where necessary.
raw.merged <- bind_rows(raw.data) %>%
  dplyr::select(-taxonomy) %>%
  mutate(across(everything(), ~replace_na(.x, 0))) %>%
  mutate(assignment = str_replace(assignment, "_", " ")) %>%
  mutate(assignment = str_replace_all(assignment, 
                                      c("Pangasiidae" = "Pangasianodon hypophthalmus",
                                        "Canis lupus" = "Canis lupus familiaris",
                                        "Gallus gallus" = "Gallus gallus domesticus",
                                        "Meleagris gallopavo" = "Meleagris gallopavo domesticus"))) 

## Merge read counts by taxonomic assignment. Anything with the same name 
## will be merged and anything unique will be retained.
raw.merged[,2:226] <- lapply(raw.merged[,2:226], function(x) as.numeric(as.character(x)))
raw.merged <- ddply(raw.merged, .(assignment), numcolwise(sum))
detach(package:plyr)

## Subset data by experimental phases, excluding samples from other 
## projects, and remove any taxonomic assignments that were unique to
## each experimental phase or other projects (i.e. sum of reads is 0).
phase1.raw <- raw.merged %>%
  select(matches("assignment|QPS|QBT|QBT-ZYMO|MUS|MUT|PCR-Neg|PCR-Pos")) %>%
  select(-matches("LIB01|LIB02")) %>%
  filter(if_any(where(is.numeric)))

phase2.raw <- raw.merged %>%
  select(matches("assignment|PHAK|VAZ|Round|LIB01|LIB02")) %>%
  select(-matches("blot|wet|spin|Round5")) %>%
  filter(if_any(where(is.numeric)))

## Duplicate data excluding unassigned reads.
phase1.dat <- filter(phase1.raw, assignment != "unassigned")
phase2.dat <- filter(phase2.raw, assignment != "unassigned")

## Calculate total read counts per sample/control for each experimental 
## phase. Make assignment column row names.
phase1.raw <- column_to_rownames(phase1.raw, "assignment")
phase2.raw <- column_to_rownames(phase2.raw, "assignment")

## Calculate total number of reads in samples/controls.
phase1.raw <- rbind(phase1.raw, colSums(phase1.raw))
phase2.raw <- rbind(phase2.raw, colSums(phase2.raw))

## Make row names first column in dataframe.
phase1.raw <- rownames_to_column(phase1.raw, "assignment")
phase2.raw <- rownames_to_column(phase2.raw, "assignment")

## Make new dataframes containing sample ID and total number of reads 
## per sample/control for each experimental phase.
phase1.total <- phase1.raw[31,]
phase1.total$assignment <- "Total"
rownames(phase1.total) <- NULL

phase2.total <- phase2.raw[96,]
phase2.total$assignment <- "Total"
rownames(phase2.total) <- NULL

## Export data for each experimental phase as .csv file
#write.csv(phase1.dat, 
#          "../output_data/Phase1_raw_data_20220629.csv", 
#          row.names=FALSE)

#write.csv(phase2.dat, 
#          "../output_data/Phase2_raw_data_20220629.csv", 
#          row.names=FALSE)



#' ---
#' 
#' ## 2) Manipulation
#' 
#' Manipulate taxonomic assignments and metadata for each experimental
#' phase to enable assessment of contamination and calculation of a 
#' false positive sequence threshold.
#' 

## Transpose read count data while maintaining wide format.
phase1.wide <- setNames(data.frame(t(phase1.dat[,-1])), phase1.dat[,1])
phase1.wide <- rownames_to_column(phase1.wide, "sequencing_ID")

phase2.wide <- setNames(data.frame(t(phase2.dat[,-1])), phase2.dat[,1])
phase2.wide <- rownames_to_column(phase2.wide, "sequencing_ID")

## Convert wide format to long format by melting dataframes. Taxa detected 
## and read counts will be condensed into two columns.
phase1.long <- melt(phase1.wide, id = "sequencing_ID")
phase2.long <- melt(phase2.wide, id = "sequencing_ID")

## Rename new columns and only keep taxa with read counts for each 
## sample/control.
phase1.long <- phase1.long %>% 
  rename(taxon = variable, reads = value) %>%
  filter(reads > 0) %>%
  droplevels()

phase2.long <- phase2.long %>% 
  rename(taxon = variable, reads = value) %>%
  filter(reads > 0) %>%
  droplevels()

## Import metadata for each experimental phase.
phase1.metadata <- read.csv("../input_data/Phase1_metadata.csv", 
                            header = TRUE)

phase2.metadata <- read.csv("../input_data/Phase2_metadata.csv", 
                            header = TRUE)

## Select metadata columns to combine with read count data.
phase1.select.metadata <- phase1.metadata %>%
  mutate(extraction_replicate = as.factor(extraction_replicate)) %>%
  select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230))

phase2.select.metadata <- phase2.metadata %>%
  mutate(extraction_replicate = as.factor(extraction_replicate)) %>%
  select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230))

## Combine selected metadata with read count data for each experimental 
## phase.
phase1.df <- merge(phase1.select.metadata, phase1.long, 
                   by = "sequencing_ID",
                   all.x = TRUE)

phase2.df <- merge(phase2.select.metadata, phase2.long, 
                   by = "sequencing_ID",
                   all.x = TRUE)

## Add column specifying whether sample ID corresponds to a sample or 
## control for each experimental phase. Move new column to come after 
## sequencing_ID column.
phase1.df <- phase1.df %>%
  mutate(sample_type = if_else(sample_ID %in% c("EB","PCR-Neg","PCR-Pos"), 
                               "control", "nsDNA")) %>%
  relocate(sample_type, .after = sequencing_ID)

phase2.df <- phase2.df %>%
  mutate(sample_type = if_else(sample_ID %in% c("EB","PCR-Neg","PCR-Pos"), 
                               "control", "nsDNA")) %>%
  relocate(sample_type, .after = sequencing_ID)

## Remove coarse taxonomic assignments (i.e. above family-level) as well 
## as genera and families which are represented by multiple species, then
## add 'spp.' to any genus or family level assignments.
phase1.df <- phase1.df %>%
  filter(!taxon %in% c("Auxis", "Delphinidae", "Gadidae", "Scombridae")) %>%
  mutate(taxon = fct_drop(taxon)) %>%
  mutate(taxon = str_replace_all(taxon, 
                                 c("Hippoglossus" = "Hippoglossus spp.",
                                   "Thunnus" = "Thunnus spp.")))

phase2.df <- phase2.df %>%
  filter(!taxon %in% c("Delphinidae", "Gadidae", "Gadus", "Helicolenus",
                       "Labridae", "Lophius", "Maurolicus", "Molva",
                       "Pleuronectidae", "Pollachius", "Scombridae",
                       "Sebastes", "Sebastidae", "Trachurus", "Triglidae")) %>%
  mutate(taxon = fct_drop(taxon)) %>%
  mutate(taxon = str_replace_all(taxon, 
                                 c("Chromis" = "Chromis spp.",
                                   "Dipturus" = "Dipturus spp.",
                                   "Gnathophis" = "Gnathophis spp.",
                                   "Hippoglossus" = "Hippoglossus spp.",
                                   "Macroramphosus" = "Macroramphosus spp.",
                                   "Mola" = "Mola spp.",
                                   "Sparidae" = "Sparidae spp.",
                                   "Spicara" = "Spicara spp.",
                                   "Thalassoma" = "Thalassoma spp.",
                                   "Thunnus" = "Thunnus spp.")))

## Transpose dataframes containing total read counts for each experimental
## phase
phase1.total <- setNames(data.frame(t(phase1.total[,-1])), phase1.total[,1])
phase1.total <- phase1.total %>%
  rownames_to_column("sequencing_ID") %>%
  rename(total_reads = Total)

phase2.total <- setNames(data.frame(t(phase2.total[,-1])), phase2.total[,1])
phase2.total <- phase2.total %>%
  rownames_to_column("sequencing_ID") %>%
  rename(total_reads = Total)

## Combine total read counts with taxon read counts for each experimental
## phase.
phase1.df <- merge(phase1.df, phase1.total, 
                   by = "sequencing_ID", 
                   all.x = TRUE)

phase2.df <- merge(phase2.df, phase2.total, 
                   by = "sequencing_ID", 
                   all.x = TRUE)

## Calculate the proportional read counts for taxa detected in each 
## sample/control. Remove rows containing NA for proportional read counts.
phase1.df <- phase1.df %>% 
  mutate(PRC = reads/total_reads) %>%
  select(-total_reads) %>%
  filter(!is.na(PRC))

phase2.df <- phase2.df %>% 
  mutate(PRC = reads/total_reads) %>%
  select(-total_reads) %>%
  filter(!is.na(PRC))



#' ---
#' 
#' ## 3) Contamination
#' 
#' Examine how much contamination in present in extraction blanks and PCR
#' controls before removing domestic taxa, non-marine taxa and potential 
#' lab contaminants from the dataset for each experimental phase.
#' 

## Create separate dataframe for nsDNA samples for each experimental phase.
phase1.samples <- phase1.df %>%
  filter(sample_type == "nsDNA") %>%
  select(-sample_type) %>%
  droplevels()

phase2.samples <- phase2.df %>%
  filter(sample_type == "nsDNA") %>%
  select(-sample_type) %>%
  droplevels()

## Create separate dataframe for controls for each experimental phase, 
## reorder factor levels, and drop controls where no taxa were detected.
phase1.controls <- phase1.df %>% 
  filter(sample_type != "nsDNA") %>%
  mutate(sample_ID = str_replace_all(sample_ID, 
                                     c("EB" = "Extraction blank",
                                       "PCR-Neg" = "PCR negative",
                                       "PCR-Pos" = "PCR positive"))) %>%
  mutate(sample_ID = fct_relevel(sample_ID,
                                 "Extraction blank",
                                 "PCR negative",
                                 "PCR positive")) %>%
  drop_na(taxon) %>%
  droplevels()

phase2.controls <- phase2.df %>% 
  filter(sample_type != "nsDNA") %>%
  mutate(sample_ID = str_replace_all(sample_ID, 
                                     c("EB" = "Extraction blank",
                                       "PCR-Neg" = "PCR negative",
                                       "PCR-Pos" = "PCR positive"))) %>%
  mutate(sample_ID = fct_relevel(sample_ID,
                                 "Extraction blank",
                                 "PCR negative",
                                 "PCR positive")) %>%
  drop_na(taxon) %>%
  droplevels()

## Filter sample dataframes by irridescent shark (PCR positive control)
## detections.
phase1.positive <- filter(phase1.samples, taxon == "Pangasianodon hypopthalmus")
phase2.positive <- filter(phase2.samples, taxon == "Pangasianodon hypopthalmus")
# No irridescent shark DNA detected in any samples.

## Order control dataframes by taxonomic assignment.
phase1.controls <- arrange(phase1.controls, taxon)
phase2.controls <- arrange(phase2.controls, taxon)

## Plot contamination found in process controls for each experimental 
## phase.

## Phase 1:
hm1 <- ggplot(phase1.controls, 
              aes(x = sequencing_ID,
                  y = fct_rev(as_factor(taxon)),
                  fill = PRC)) +
  geom_tile(colour = "black") +
  scale_fill_gradient(name = "Proportional\nread counts", 
                      limits = c(0, 1),
                      breaks = c(0, 0.25, 0.50, 0.75, 1),
                      low = "white", high = "red",
                      guide = guide_colourbar(frame.colour = "black",
                                              ticks.colour = "black")) +
  labs(title = "(a) Phase 1",
       x = "Process controls", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        strip.text.y = element_text(angle = 360),
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black", angle = 60, hjust = 1),
        axis.text.y = element_text(colour = "black", face = "italic"),
        text = element_text(size = 20),
        legend.key.size = unit(1, "lines")) + 
  facet_grid(. ~ sample_ID, scales = "free")
hm1

## Phase 2:
hm2 <- ggplot(phase2.controls, aes(x = sequencing_ID, 
                                   y = fct_rev(as_factor(taxon)),
                                   fill = PRC)) +
  geom_tile(colour = "black") +
  scale_fill_gradient(name = "Proportional\nread counts", 
                      limits = c(0, 1),
                      breaks = c(0, 0.25, 0.50, 0.75, 1),
                      low = "white", high = "red",
                      guide = guide_colourbar(frame.colour = "black",
                                              ticks.colour = "black")) +
  labs(title = "(b) Phase 2",
       x = "Process controls", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        strip.text.y = element_text(angle = 360),
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black", angle = 60, hjust = 1),
        axis.text.y = element_text(colour = "black", face = "italic"),
        axis.ticks.x = element_blank(),
        text = element_text(size = 20),
        legend.key.size = unit(1, "lines")) + 
  facet_grid(. ~ sample_ID, scales = "free", space = "free")
hm2

## Combine plots into a single plot.
g1 <- ggarrange(hm1, hm2, nrow = 2, ncol = 1,
                align = "hv", heights = c(0.5, 1.5),
                common.legend = TRUE, legend = "right")

## Export plot.
ggsave(filename = "../figures/FigS1_contamination.jpeg", 
       plot = g1, width = 13, height = 18, dpi = 300, units = "in")

## No irridescent shark DNA was detected in samples and only human DNA
## was detected in PCR negative controls. This indicates that laboratory 
## workflows were robust and no contamination was introduced during 
## preparation of PCR reactions and libraries.

## In Phase 1, no contaminants were detected in the PCR positive controls
## and only human DNA was detected in one extraction blank and one PCR 
## negative control. In Phase 2, several taxa were detected in the PCR 
## positive controls and the extraction blanks. Only human DNA was detected
## in PCR negative controls. This indicates that some contamination 
## occurred during DNA extraction that spread to PCR positive controls or 
## the DNA extract used as the PCR positive control had become contaminated.

## Human DNA is a common contaminant in metabarcoding and can be removed
## from both datasets. Likewise, the positive control, irridescent shark 
## (Pangasionodon hypopthalmus), can be removed from the datasets as it
## did not contaminate samples. However, we cannot remove taxa that are
## potential lab contaminants and also occur in nature as this could remove
## real detections. Therefore, we will apply taxon-specific false positive 
## thresholds, based on the frequency of contamination across all process 
## controls, to remove contamination from the experimental datasets.

## From the phase2.controls dataframe, remove human and irridescent
## shark, then find the maximum frequency for each contaminant.
thresholds <- phase2.controls %>%
  filter(!taxon %in% c("Homo sapiens", "Pangasianodon hypophthalmus")) %>%
  droplevels() %>%
  group_by(taxon) %>%
  top_n(1, PRC) %>%
  rename(threshold = PRC) %>%
  select(taxon, threshold)

## Apply taxon-specific false positive thresholds to Phase 2 dataset. 
## First, join the thresholds dataframe with the phase2.samples dataframe.
## Replace all NA values in threshold column with 0. Then, apply the 
## filter - proportional read counts for each taxon must surpass the 
## maximum frequency at which they occurred in process controls in order 
## to be considered a real detection.
phase2.clean <- left_join(phase2.samples, thresholds, by = "taxon") %>%
  mutate(threshold = replace_na(threshold, 0)) %>%
  filter(PRC > threshold) %>%
  select(-threshold) %>%
  droplevels()

## Read counts for some species in some samples are exceptionally low 
## (<10 reads) and could be the result of sequencing error, tag jumping,
## or cross-contamination. We cannot apply a threshold based on actual
## read counts to remove these detections due to variation in total read
## counts across samples, i.e. some samples have <100 reads so 10 reads
## would constitute an abundant taxon in these samples. Instead, we will
## apply a threshold based on read count frequency, where all detections
## less than 0.1% of the total reads for each sample are removed.

## Apply low frequency threshold to phase1.samples and phase2.clean
phase1.clean <- phase1.samples %>%
  group_by(sequencing_ID, sample_ID, ethanol_treatment, extraction_method,
           extraction_replicate, taxon) %>%
  filter(PRC >= 0.001) %>%
  ungroup() %>%
  droplevels()

phase2.clean <- phase2.clean %>%
  group_by(sequencing_ID, sponge, sample_ID, starting_material, amount, 
           extraction_replicate, taxon) %>%
  filter(PRC >= 0.001) %>%
  ungroup() %>%
  droplevels()

## Now remove human, domestic taxa and non-marine taxa from the datasets
## for each experimental phase. This includes cow (Bos taurus), dog (Canis
## lupus familiaris), cat (Felis catus), chicken (Gallus gallus domesticus),
## turkey (Meleagris gallopavo domesticus), and starling (Sturnus vulgaris).
## Also remove the experiment column from each dataset as it is no longer
## required.
phase1.final <- phase1.clean %>%
  filter(!taxon %in% c("Homo sapiens", "Bos taurus", 
                       "Canis lupus familiaris", "Felis catus",
                       "Gallus gallus domesticus", 
                       "Meleagris gallopavo domesticus",
                       "Sturnus vulgaris")) %>%
  droplevels()

phase2.final <- phase2.clean %>%
  filter(!taxon %in% c("Homo sapiens", "Bos taurus", 
                       "Canis lupus familiaris", "Felis catus",
                       "Gallus gallus domesticus", 
                       "Meleagris gallopavo domesticus",
                       "Sturnus vulgaris")) %>%
  droplevels()



#' ---
#'
#' 4) Compare detections before and after dataset refinement
#' 

## Add column stating whether data has been refined or not.
phase1.samples <- mutate(phase1.samples, dataset = "Unrefined")
phase1.final <- mutate(phase1.final, dataset = "Refined")

phase2.samples <- mutate(phase2.samples, dataset = "Unrefined")
phase2.final <- mutate(phase2.final, dataset = "Refined")

## Get list of taxa removed by dataset refinement for each experimental
## phase.
phase1.missing <- unique(phase1.samples$taxon)[!unique(phase1.samples$taxon) %in% unique(phase1.final$taxon)]
phase2.missing <- unique(phase2.samples$taxon)[!unique(phase2.samples$taxon) %in% unique(phase2.final$taxon)]

## Combine dataframes for each experimental phase for plotting.
phase1.all <- bind_rows(phase1.samples, phase1.final)
phase2.all <- bind_rows(phase2.samples, phase2.final)

## Create new factor specifying order that facets are to be plotted
phase1.all <- phase1.all %>%
  mutate(dataset = fct_relevel(dataset, "Unrefined", "Refined")) %>%
  arrange(taxon)

phase2.all <- phase2.all %>%
  mutate(dataset = fct_relevel(dataset, "Unrefined", "Refined")) %>%
  arrange(taxon)

## Create custom y axis labels - add asterisk to taxa removed by dataset
## refinement.
phase1.labels <- unique(phase1.all$taxon)
phase1.labels[phase1.labels %in% phase1.missing] <- paste("*", phase1.labels[phase1.labels %in% phase1.missing])
phase1.labels

phase2.labels <- unique(phase2.all$taxon)
phase2.labels[phase2.labels %in% phase2.missing] <- paste("*", phase2.labels[phase2.labels %in% phase2.missing])
phase2.labels

## Plot detections before and after dataset refinement for each 
## experimental phase.

## Phase 1:
hm3 <- ggplot(phase1.all, aes(x = sequencing_ID, 
                              y = fct_rev(as_factor(taxon)), 
                              fill = PRC)) + 
  geom_tile(colour = "black") + 
  scale_fill_gradient(name = "Proportional\nread counts    ", 
                      limits = c(0,1), 
                      breaks = c(0,0.25,0.5,0.75,1),
                      low = "white", high = "blue",
                      guide = guide_colourbar(frame.colour = "black",
                                              ticks.colour = "black")) + 
  scale_y_discrete(labels = rev(phase1.labels)) + 
  labs(title = "(a) Phase 1",
       x = "Samples", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        strip.text.y = element_text(angle = 360),
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_blank(),
        axis.text.y = element_text(colour = "black", face = "italic"),
        axis.ticks.x = element_blank(),
        text = element_text(size = 20),
        legend.key.size = unit(1, "lines")) + 
  facet_grid(. ~ dataset, scales = "free", space = "free")
hm3

## Phase 2:
hm4 <- ggplot(phase2.all, aes(x = sequencing_ID, 
                              y = fct_rev(as_factor(taxon)), 
                              fill = PRC)) + 
  geom_tile(colour = "black") + 
  scale_fill_gradient(name = "Proportional\nread counts    ", 
                      limits = c(0,1), 
                      breaks = c(0,0.25,0.5,0.75,1),
                      low = "white", high = "blue",
                      guide = guide_colourbar(frame.colour = "black",
                                              ticks.colour = "black")) + 
  scale_y_discrete(labels = rev(phase2.labels)) + 
  labs(title = "(b) Phase 2",
       x = "Samples", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        strip.text.y = element_text(angle = 360),
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_blank(),
        axis.text.y = element_text(colour = "black", face = "italic"),
        axis.ticks.x = element_blank(),
        text = element_text(size = 20),
        legend.key.size = unit(1, "lines")) + 
  facet_grid(. ~ dataset, scales = "free", space = "free")
hm4

## Combine plots into a single plot.
g2 <- ggarrange(hm3, hm4, nrow = 2, ncol = 1,
                align = "hv", heights = c(0.5, 1.5),
                common.legend = TRUE, legend = "right")

## Export plot.
ggsave(filename = "../figures/FigS2_dataset_refinement.jpeg", 
       plot = g2, width = 25, height = 30, dpi = 300, units = "in")



#'---
#'
#' 5) Export data for downstream analyses
#' 

## Recombine refined data with metadata in order to recover samples
## which did not detect any taxa or had taxa filtered out
phase1.downstream <- left_join(phase1.select.metadata, phase1.final) %>%
  select(-c(dataset)) %>%
  filter(!grepl("EB|Neg|Pos", sequencing_ID)) %>%
  droplevels()

phase2.downstream <- left_join(phase2.select.metadata, phase2.final) %>%
  select(-c(dataset)) %>%
  filter(!grepl("EB|Neg|Pos", sequencing_ID)) %>%
  droplevels()

## Export data for downstream analysis.
#write.csv(phase1.downstream, 
#          "../output_data/Phase1_refined_data_20220629.csv", 
#          row.names = FALSE)

#write.csv(phase2.downstream, 
#          "../output_data/Phase2_refined_data_20220629.csv", 
#          row.names = FALSE)


#################
# END OF SCRIPT #
#################

