#' ---
#' Title: "Optimised DNA isolation from marine sponges for natural sampler DNA (nsDNA) metabarcoding"
#' Author: "Lynsey Rebecca Harper"
#' Date: "29th October 2022"
#' ---
#' 
#' 
#' ## Prepare working environment
#' 
#' Clear R memory, set working directory and load required packages. 
#' 

## Clear memory.
rm(list=ls())

## Set working directory to location of R script.
# On first time running code: install.packages("rstudioapi")
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

## Check working directory.
getwd()

## Load required packages.
p <- c("tidyverse","ggpubr","scales","car","MASS","emmeans","FSA",
       "lawstat","vegan","betapart")
new.packages <- p[!(p %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages, 
                                          repos = "https://cran.ma.imperial.ac.uk/",
                                          dependencies=TRUE)
lapply(p, require, character.only = TRUE)

## Load custom functions.
f <- c("CheckResidsFunction.R")
lapply(f, source)

## To ensure reproducibility, print details about the version of R being
## used for analysis.
sessionInfo()



###############
# IMPORT DATA #
###############

## Import refined metabarcoding dataset.
phase1.dat <- read.csv("../output_data/Phase1_refined_data_20220629.csv", 
                       header = TRUE)

## Import metadata.
phase1.metadata <- read.csv("../input_data/Phase1_metadata.csv", 
                            header = TRUE)

## The Horniman invasive sponge was identified as Lendenfeldia chondrodes
## after sequencing had occurred and the manuscript associated with this
## data was submitted to Environmental DNA. Change all instances of
## H-INV to LEN in sequencing data and metadata.
phase1.dat <- phase1.dat %>%
  mutate(sequencing_ID = gsub("H-INV", "LEN", sequencing_ID),
         sample_ID = gsub("H-INV", "LEN", sample_ID))

phase1.metadata <- phase1.metadata %>%
  mutate(sequencing_ID = gsub("H-INV", "LEN", sequencing_ID),
         sample_ID = gsub("H-INV", "LEN", sample_ID))

## Save a copy of metadata for producing plots summarising DNA 
## concentration and purity for each sample downstream.
phase1.conc.purity <- phase1.metadata %>%
  filter(!grepl("EB|Neg|Pos", sequencing_ID)) %>%
  mutate(extraction_replicate = as.factor(extraction_replicate),
         sample_ID = gsub("[[:digit:]]+", "", sample_ID)) %>%
  droplevels()



###################
# BASIC SUMMARIES #
###################

## Summarise the data for each ethanol treatment and each extraction 
## method in terms of DNA concentration, purity, total taxon richness, 
## total read counts, consistency across extraction replicates, and
## proportional read counts for each taxon.


#==============================#
# DNA CONCENTRATION AND PURITY #
#==============================#

## Plot relationship between total DNA concentration, ethanol treatment
## and extraction method.
p1 <- ggplot(phase1.conc.purity,
             aes(x = ethanol_treatment, y = Qubit_total_DNA,)) + 
  geom_jitter(aes(fill = ethanol_treatment),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.05, 20), 
                     breaks = seq(0, 20, 5)) +
  scale_fill_manual(values = c("grey30","goldenrod2","dodgerblue3"),
                    guide = "none") +
  labs(title = expression(bold("(a) Total DNA yield")),
       x = "", 
       y = expression(paste("Qubit concentration (ng/",mu,"l)"))) +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ extraction_method, scales = "free", space = "free")
p1

## Plot relationship between fish DNA concentration, ethanol treatment
## and extraction method.
p2 <- ggplot(phase1.conc.purity,
             aes(x = ethanol_treatment, y = Qubit_fish_DNA,)) + 
  geom_jitter(aes(fill = ethanol_treatment),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.05, 60),
                     breaks = seq(0, 60, 10)) +
  scale_fill_manual(values = c("grey30","goldenrod2","dodgerblue3"),
                    guide = "none") +
  labs(title = expression(bold("(b) Post-PCR DNA concentration")),
       x = "", 
       y = expression(paste("Qubit concentration (ng/",mu,"l)"))) +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ extraction_method, scales = "free", space = "free")
p2

## Remove outlier data for A260/A280 and A260/A230 ratios.
purity.filt <- phase1.conc.purity %>%
  filter(A260_A280 > -30, A260_A280 < 30) %>%
  filter(A260_A230 > -30, A260_A230 < 30)

## Plot relationship between nanodrop A260/A280 ratio, ethanol treatment
## and extraction method.
p3 <- ggplot(purity.filt,
             aes(x = ethanol_treatment, y = A260_A280,)) + 
  geom_jitter(aes(fill = ethanol_treatment),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  geom_hline(yintercept = 1.8, linetype = "dashed", 
             colour = "black") +
  scale_y_continuous(limits = c(-20, 25),
                     breaks = seq(-20, 25, 5)) +
  scale_fill_manual(values = c("grey30","goldenrod2","dodgerblue3"),
                    guide = "none") +
  labs(title = expression(bold("(c) DNA purity (A260/A280)")),
       x = "", y = "Adsorbence") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ extraction_method, scales = "free", space = "free")
p3

## Plot relationship between nanodrop A260/A230 ratio, ethanol treatment
## and extraction method.
p4 <- ggplot(purity.filt,
             aes(x = ethanol_treatment, y = A260_A230,)) + 
  geom_jitter(aes(fill = ethanol_treatment),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  geom_hline(yintercept = 2, linetype = "dashed", 
             colour = "black") +
  scale_y_continuous(limits = c(-25, 20),
                     breaks = seq(-25, 20, 5)) +
  scale_fill_manual(values = c("grey30","goldenrod2","dodgerblue3"),
                    guide = "none") +
  labs(title = expression(bold("(d) DNA purity (A260/A230)")),
       x = "Ethanol treatment", y = "Adsorbence") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ extraction_method, scales = "free", space = "free")
p4

## Combine plots into a single plot.
g1 <- ggarrange(p1, p2, p3, p4, 
                ncol = 1, nrow = 4,
                align = "hv")

## Export plot.
#ggsave(filename = "../figures/Fig2_phase1_concentration_purity.jpeg", 
#       plot = g1, width = 13, height = 25, dpi = 300, units = "in")


#======================================#
# TOTAL TAXON RICHNESS AND READ COUNTS #
#======================================#

## Add column describing which vertebrate group species belong to, remove
## numbers from sample_ID column, and replace NA values with 0 in reads 
## and PRC columns.
phase1.df <- phase1.dat %>%
  mutate(taxon = as.character(taxon)) %>%
  mutate(taxon = replace_na(taxon, "none"),
         group = if_else(taxon %in% c("Balaenoptera musculus",
                                      "Balaenoptera physalus",
                                      "Globicephala melas",
                                      "Mesoplodon bidens"), "Mammal", 
                         if_else(taxon == "none", "NA", "Fish")),
         group = as.factor(group),
         sample_ID = gsub("[[:digit:]]+", "", sample_ID),
         reads = replace_na(reads, 0),
         PRC = replace_na(PRC, 0),
         extraction_replicate = as.factor(extraction_replicate)) %>%
  relocate(group, .before = taxon) %>%
  droplevels()

## Calculate the total number of species and number of reads belonging
## to each group for each extraction method.
method.richness <- phase1.df %>%
  group_by(sample_ID, extraction_method, group, taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  count(sample_ID, extraction_method, group) %>%
  rename(richness = n) %>%
  filter(!group == "NA")

method.reads <- phase1.df %>%
  group_by(sample_ID, extraction_method, group) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  filter(!group == "NA")

## Calculate the total number of species and number of reads belonging
## to each group for each ethanol treatment within each extraction method.
method.etoh.richness <- phase1.df %>%
  group_by(sample_ID, ethanol_treatment, extraction_method, group, taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  count(sample_ID, ethanol_treatment, extraction_method, group) %>%
  rename(richness = n) %>%
  filter(!group == "NA")

method.etoh.reads <- phase1.df %>%
  group_by(sample_ID, ethanol_treatment, extraction_method, group) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  filter(!group == "NA")

## Calculate the total number of samples for each ethanol treatment with
## each extraction method.
method.etoh.samples <- phase1.df %>%
  dplyr::select(sample_ID, ethanol_treatment, extraction_method, 
                extraction_replicate, sample_ID) %>%
  distinct() %>%
  group_by(sample_ID, ethanol_treatment, extraction_method) %>%
  count(ethanol_treatment) %>%
  ungroup()

## Merge method.etoh.richness and method.etoh.reads.
method.groups <- merge(method.etoh.richness, method.etoh.reads, 
                       by = c("sample_ID", "ethanol_treatment", "extraction_method", "group"), 
                       all.x = TRUE)

## Plot number of species detected for each group for each ethanol treatment
## with each extraction method.
p5 <- ggplot(method.groups,
             aes(x = ethanol_treatment, y = richness, 
                 group = group, fill = group)) + 
  geom_bar(stat = "identity", 
           position = position_dodge(preserve = "single"), 
           width = 0.5, colour = "black") +
  scale_fill_manual(name = "Group",
                    values = c("lightblue","navy")) +
  scale_y_continuous(limits = c(0, 6), breaks = seq(0, 6, 1)) +
  labs(title = "(a) Taxon richness",
       x = "", y = "Taxon richness") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(1.5, "lines")) +
  facet_grid(sample_ID ~ extraction_method, scales = "free_y", space = "free")
p5

## Plot number of reads detected for each group for each ethanol treatment
## with each extraction method.
p6 <- ggplot(method.groups,
             aes(x = ethanol_treatment, y = reads, 
                 group = group, fill = group)) + 
  geom_bar(stat = "identity", 
           position = position_dodge(preserve = "single"),
           width = 0.5, colour = "black") +
  scale_fill_manual(name = "Group",
                    values = c("lightblue","navy")) +
  scale_y_continuous(limits = c(0, 300000), 
                     breaks = seq(0,300000,25000),
                     labels = comma) +
  labs(title = "(b) Read counts",
       x = "Ethanol treatment", y = "Read counts") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(1.5, "lines")) +
  facet_grid(sample_ID ~ extraction_method, scales = "free_y", space = "free")
p6

## Combine plots into a single plot.
g2 <- ggarrange(p5, p6, 
                ncol = 1, nrow = 2,
                align = "hv", heights = c(1.2, 1.8),
                common.legend = TRUE, legend = "right")

## Export plot.
#ggsave(filename = "../figures/FigS3_phase1_richness_reads.jpeg", 
#       plot = g2, width = 13, height = 13, dpi = 300, units = "in")


#==================================#
# EXTRACTION REPLICATE CONSISTENCY #
#==================================#

## Create dataframe containing richness of individual extraction replicates.
ext.rep.richness <- phase1.df %>%
  count(sequencing_ID, sample_ID, extraction_method, ethanol_treatment,
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  filter(!group == "NA")

## Plot richness of individual extraction replicates for each amount of
## different starting material from wild sponges
p7 <- ggplot(ext.rep.richness,
             aes(x = ethanol_treatment, y = richness,
                 fill = group)) +
  geom_point(pch = 21, size = 3,
             position = position_jitterdodge(jitter.width = 0.3, dodge.width = 1)) + 
  geom_boxplot(alpha = 0.3, outlier.shape = NA,
               position = position_dodge(preserve = "single")) +
  scale_y_continuous(limits = c(0, 4),
                     breaks = seq(0, 4, 1)) +
  scale_fill_manual(name = "Group",
                    values = c("lightblue", "navy")) +
  labs(title = "(a) Taxon richness",
       x = "Ethanol treatment\n", y = "Taxon richness") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"),
        plot.title = element_text(face = "bold", hjust = 0),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "right") +
  facet_grid(sample_ID ~ extraction_method, space = "free")
p7

## Create dataframe containing detection rate across extraction replicates 
## for each taxa.
detection.rate <- phase1.df %>%
  group_by(sample_ID, extraction_method, ethanol_treatment, group, taxon) %>%
  count(extraction_replicate) %>%
  ungroup() %>%
  rename(no_ext_rep = n) %>%
  group_by(sample_ID, extraction_method, ethanol_treatment, group, taxon) %>%
  summarise(total_ext_rep = sum(no_ext_rep), .groups = "keep") %>%
  ungroup() %>%
  mutate(no_ext_rep_performed = 3,
         SO = total_ext_rep/no_ext_rep_performed) %>%
  filter(!group == "NA")

## Plot number of extraction replicates each taxa was detected in.
p8 <- ggplot(detection.rate, 
             aes(x = ethanol_treatment, y = fct_rev(taxon), 
                 size = total_ext_rep, fill = group,
                 shape = sample_ID)) + 
  geom_jitter(alpha = 0.7, width = 0.15, height = 0) +
  scale_fill_manual(name = "Group",
                    values = c("lightblue", "navy")) +
  scale_shape_manual(name = "Sponge",
                     values = c(21, 22)) +
  scale_size_continuous(name = "Number of \nextraction \nreplicates",
                        range = c(1, 5),
                        limits = c(0, 3),
                        breaks = c(0, 1, 2, 3)) + 
  guides(fill = guide_legend(override.aes = list(shape = 21, size = 5)),
         shape = guide_legend(override.aes = list(size = 5)),
         size = guide_legend(override.aes = list(shape = 21, fill = "white"))) +
  labs(title = "(b) Detection consistency",
       x = "Ethanol treatment", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"),
        plot.title = element_text(face = "bold", hjust = 0),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black", face = "italic"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(1, "lines")) + 
  facet_grid(group ~ extraction_method, scales = "free", space = "free")
p8

## Combine plots into a single plot.
g3 <- ggarrange(p7, p8,
                ncol = 1, nrow = 2)

## Export plot.
#ggsave(filename = "../figures/FigS5_phase1_extraction_replicates.jpeg", 
#       plot = g3, width = 15, height = 12, dpi = 300, units = "in")


#=====================#
# DETECTION FREQUENCY #
#=====================#

## Now plot proportional read counts for each species detected with 
## different ethanol treatments and extraction methods. Reorder factor 
## levels for plotting.
spp.summary <- phase1.df %>%
  arrange(group, taxon) %>%   
  mutate(taxon = fct_rev(factor(taxon, unique(taxon)))) %>%
  filter(!group == "NA")

## Plot species detected with different ethanol treatments across 
## different extraction methods.
b1 <- ggplot(spp.summary, 
             aes(x = ethanol_treatment, y = taxon, 
                 fill = group, shape = extraction_replicate,
                 size = PRC)) + 
  geom_jitter(alpha = 0.5, width = 0.15, height = 0) +
  scale_fill_manual(name = "Group",
                    values = c("lightblue", "navy")) +
  scale_shape_manual(name = "Extraction\nreplicate",
                     values = c(21, 24, 22)) +
  scale_size_continuous(name = "Proportional \nread counts",
                        range = c(3, 10),
                        limits = c(0, 1),
                        breaks = c(0, 0.25, 0.5, 0.75, 1),
                        labels = c("> 0","0.25","0.50","0.75","1.00")) +
  guides(fill = guide_legend(order = 1, 
                             override.aes = list(size = 8,
                                                 shape = 21)),
         size = guide_legend(order = 2,
                             override.aes = list(shape = 21,
                                                 fill = "white")),
         shape = guide_legend(order = 3,
                              override.aes = list(size = 8))) +
  labs(x = "Ethanol treatment", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black", face = "italic"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(2, "lines")) +
  facet_grid(sample_ID ~ extraction_method, 
             scales = "free_y", space = "free")
b1

## Export plot.
#ggsave(filename = "../figures/Fig3_phase1_detection_ext-method_etoh-treatment.jpeg", 
#       plot = b1, width = 15, height = 10, dpi = 300, units = "in")

## Now that basic summaries have been produced, we can perform statistical 
## analyses. We will compare ethanol treatments and extraction methods for
## each sponge species separately as the optimal extraction protocol
## may differ between sponge species.

## Subset the data by the Horniman invasive sponge.
LEN.phase1.conc.purity <- phase1.conc.purity %>%
  filter(sample_ID == "LEN") %>%
  droplevels()

## Subset the data by Vazella pourtalesii.
VAZ.phase1.conc.purity <- phase1.conc.purity %>%
  filter(sample_ID == "VAZ") %>%
  droplevels()



########################
# STATISTICAL ANALYSIS #
########################

## Compare total DNA yield, post-PCR concentration, taxon richness and 
## community compositon between ethanol treatments across extraction 
## methods for each sponge species using rstats, vegan and betapart 
## packages. 


#=================#
# TOTAL DNA YIELD #
#=================#

#-------------------------#
# LENDENFELDIA CHONDRODES #
#-------------------------#

## Check if data are normally distributed.
## Histogram:
hist(LEN.phase1.conc.purity$Qubit_total_DNA)  # broadly symmetrical

## Quantile-quantile plot (Q-Q plot):
qqnorm(LEN.phase1.conc.purity$Qubit_total_DNA)
qqline(LEN.phase1.conc.purity$Qubit_total_DNA, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(LEN.phase1.conc.purity$Qubit_total_DNA)  # P = 0.2572

## Kolmogorov-Smirnov test:
ks.test(LEN.phase1.conc.purity$Qubit_total_DNA, pnorm)  # P < 2.2e-16


## Total DNA yield data is normally distributed. Compare variance in 
## total DNA yield between different extraction methods and ethanol 
## treatments.
bartlett.test(Qubit_total_DNA ~ extraction_method,
              data = LEN.phase1.conc.purity) # P = 0.1981
levene.test(LEN.phase1.conc.purity$Qubit_total_DNA,
            LEN.phase1.conc.purity$extraction_method,
            location = "mean")  # P = 0.02956

bartlett.test(Qubit_total_DNA ~ ethanol_treatment,
              data = LEN.phase1.conc.purity) # P = 0.009678
levene.test(LEN.phase1.conc.purity$Qubit_total_DNA,
            LEN.phase1.conc.purity$ethanol_treatment,
            location = "mean")  # P = 0.07398

## The data do not conform to the assumptions of a two-way ANOVA as the
## there is unequal variance between groups. In these scenarios, switching 
## to a Generalised Linear Model (GLM) and changing the combination of 
## error family and link-function terms to achieve normally distributed 
## residuals is recommended over data transformation. We cannot use 
## Poisson or a negative binomial distribution as these are for integer 
## count data. However, a quasi-Poisson distribution can be applied to 
## non-integer count data.

## Run GLM allowing interaction between extraction method and ethanol 
## treatment.
glm.yield <- glm(Qubit_total_DNA ~ extraction_method + ethanol_treatment
                 + extraction_method:ethanol_treatment, 
                 family = quasipoisson(link = "log"),
                 data = LEN.phase1.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion.
31.338/30
1-pchisq(31.338, df = 30)  # not overdispersed


## Run GLM without interaction term.
glm.yield <- glm(Qubit_total_DNA ~ extraction_method + ethanol_treatment, 
                 family = quasipoisson(link = "log"),
                 data = LEN.phase1.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion.
33.173/38
1-pchisq(33.173, df = 38)  # not overdispersed


## Post-hoc test for extraction method.
glm.yield.posthoc <- emmeans(glm.yield, 
                             specs = "extraction_method",
                             type = "response")
multcomp::cld(glm.yield.posthoc, Letters = letters)
pairs(glm.yield.posthoc)
plot(glm.yield.posthoc)

## Post-hoc test for ethanol treatment.
glm.yield.posthoc <- emmeans(glm.yield, 
                             specs = "ethanol_treatment",
                             type = "response")
multcomp::cld(glm.yield.posthoc, Letters = letters)
pairs(glm.yield.posthoc)
plot(glm.yield.posthoc)

## Get standardised residuals for model validation.
sresid <- resid(glm.yield, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals
hist(sresid)
lines(density(sresid,adjust = 1))
par(mfrow = c(2,2))
plot(glm.yield)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.0001696
## Not normally distributed.

## Check assumption of homogeneity of variances.
plot(sresid ~ LEN.phase1.conc.purity$extraction_method)
plot(sresid ~ LEN.phase1.conc.purity$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.yield)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## confounding effect of time or space.
durbinWatsonTest(glm.yield)
acf(sresid, main = "Auto-correlation plot")
## Some autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.yield)
summary(influence)
CD <- cooks.distance(glm.yield)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality. There are no satisfactory non-parametric
## alternatives for our data unless we split the dataset by 
## ethanol treatments and compare extraction protocols using Kruskal
## -Wallis Test and vice versa.

## ETHANOL TREATMENTS
## Subset data by spin ethanol treatment.
LEN.yield.spin <- LEN.phase1.conc.purity %>%
  filter(ethanol_treatment == "spin") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ extraction_method, data = LEN.yield.spin)

## Dunn's test of multiple comparisons:
dunnTest(Qubit_total_DNA ~ extraction_method, 
         data = LEN.yield.spin,
         method = "bh")


## Subset data by wet ethanol treatment.
LEN.yield.wet <- LEN.phase1.conc.purity %>%
  filter(ethanol_treatment == "wet") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ extraction_method, data = LEN.yield.wet)


## Subset data by blot ethanol treatment.
LEN.yield.blot <- LEN.phase1.conc.purity %>%
  filter(ethanol_treatment == "blot") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ extraction_method, data = LEN.yield.blot)


## EXTRACTION PROTOCOLS
## Subset data by MUS extraction protocol.
LEN.yield.MUS <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "MUS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ ethanol_treatment, data = LEN.yield.MUS)


## Subset data by MUT extraction protocol.
LEN.yield.MUT <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "MUT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ ethanol_treatment, data = LEN.yield.MUT)

## Dunn's test of multiple comparisons:
dunnTest(Qubit_total_DNA ~ ethanol_treatment, 
         data = LEN.yield.MUT,
         method = "bh")


## Subset data by QBT extraction protocol.
LEN.yield.QBT <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "QBT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ ethanol_treatment, data = LEN.yield.QBT)

## Dunn's test of multiple comparisons:
dunnTest(Qubit_total_DNA ~ ethanol_treatment, 
         data = LEN.yield.QBT,
         method = "bh")


## Subset data by QBT-ZYMO extraction protocol
LEN.yield.QBTZYMO <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "QBT-ZYMO") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ ethanol_treatment, data = LEN.yield.QBTZYMO)


## Subset data by QPS extraction protocol
LEN.yield.QPS <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "QPS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ ethanol_treatment, data = LEN.yield.QPS)

## Total DNA yield significantly differed between extraction protocols 
## for the spin ethanol treatment, but not the blot or wet treatments. 
## For the spin treatment, none of the Dunn’s Test adjusted p-values 
## were significant, but the largest differences in effect size were 
## observed between the QBT and MUS protocols, the QBT and MUT protocols, 
## and the QBT and QPS protocols.

## Total DNA yield significantly differed between ethanol treatments with 
## the QBT and MUT protocols. For both protocols, the spin treatment 
## produced lower total DNA yields than the wet treatment, but the blot 
## treatment was not significantly different to the spin or wet treatments.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Check if data are normally distributed.
## Histogram:
hist(VAZ.phase1.conc.purity$Qubit_total_DNA)  # broadly symmetrical

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.phase1.conc.purity$Qubit_total_DNA)
qqline(VAZ.phase1.conc.purity$Qubit_total_DNA, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.phase1.conc.purity$Qubit_total_DNA)  # P = 0.002039

## Kolmogorov-Smirnov test:
ks.test(VAZ.phase1.conc.purity$Qubit_total_DNA, pnorm)  # P < 2.2e-16


## Total DNA yield data is not normally distributed. Compare variance in 
## total DNA yield between different extraction methods and ethanol 
## treatments.
bartlett.test(Qubit_total_DNA ~ extraction_method,
              data = VAZ.phase1.conc.purity) # P = 0.0009421
levene.test(VAZ.phase1.conc.purity$Qubit_total_DNA,
            VAZ.phase1.conc.purity$extraction_method,
            location = "mean")  # P = 0.3

bartlett.test(Qubit_total_DNA ~ ethanol_treatment,
              data = VAZ.phase1.conc.purity) # P = 0.6899
levene.test(VAZ.phase1.conc.purity$Qubit_total_DNA,
            VAZ.phase1.conc.purity$ethanol_treatment,
            location = "mean")  # P = 0.4145

## The data do not conform to the assumptions of a two-way ANOVA due to
## non-normal distribution and unequal variance between groups. Therefore,
## a GLM iwth quasi-Poisson distribution will be applied to the data.

## Run GLM allowing interaction between extraction method and ethanol 
## treatment.
glm.yield <- glm(Qubit_total_DNA ~ extraction_method + ethanol_treatment
                 + extraction_method:ethanol_treatment, 
                 family = quasipoisson(link = "log"),
                 data = VAZ.phase1.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion.
26.538/30
1-pchisq(26.538, df = 30)  # not overdispersed


## Run GLM without interaction term.
glm.yield <- glm(Qubit_total_DNA ~ extraction_method + ethanol_treatment, 
                 family = quasipoisson(link = "log"),
                 data = VAZ.phase1.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion.
34.99/38
1-pchisq(34.99, df = 38)  # not overdispersed


## Post-hoc test for extraction method.
glm.yield.posthoc <- emmeans(glm.yield, 
                             specs = "extraction_method",
                             type = "response")
multcomp::cld(glm.yield.posthoc, Letters = letters)
pairs(glm.yield.posthoc)
plot(glm.yield.posthoc)


## Get standardised residuals for model validation.
sresid <- resid(glm.yield, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.yield)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 9.182e-05
## Not normally distributed.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.phase1.conc.purity$extraction_method)
plot(sresid ~ VAZ.phase1.conc.purity$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.yield)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## confounding effect of time or space.
durbinWatsonTest(glm.yield)
acf(sresid, main = "Auto-correlation plot")
## Some autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.yield)
summary(influence)
CD <- cooks.distance(glm.yield)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality. There are no satisfactory non-parametric
## alternatives for our data unless we split the dataset by 
## ethanol treatment and compare extraction protocols using Kruskal
## -Wallis Test.

## Subset data by spin ethanol treatment.
VAZ.yield.spin <- VAZ.phase1.conc.purity %>%
  filter(ethanol_treatment == "spin") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ extraction_method, data = VAZ.yield.spin)


## Subset data by wet ethanol treatment.
VAZ.yield.wet <- VAZ.phase1.conc.purity %>%
  filter(ethanol_treatment == "wet") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ extraction_method, data = VAZ.yield.wet)

## Dunn's test of multiple comparisons:
dunnTest(Qubit_total_DNA ~ extraction_method, 
         data = VAZ.yield.wet,
         method = "bh")


## Subset data by blot ethanol treatment.
VAZ.yield.blot <- VAZ.phase1.conc.purity %>%
  filter(ethanol_treatment == "blot") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ extraction_method, data = VAZ.yield.blot)

## Dunn's test of multiple comparisons:
dunnTest(Qubit_total_DNA ~ extraction_method, 
         data = VAZ.yield.blot,
         method = "bh")

## Total DNA yield significantly differed between extraction protocols 
## for the wet and blot ethanol treatments, but not the spin treatment. 
## The QBT protocol produced higher total DNA yields than the QPS protocol 
## with the wet ethanol treatment and the MUT protocol with the blot
## ethanol treatment.


#========================#
# POST-PCR CONCENTRATION #
#========================#

#-------------------------#
# LENDENFELDIA CHONDRODES #
#-------------------------#

## Check if data are normally distributed.
## Histogram:
hist(LEN.phase1.conc.purity$Qubit_fish_DNA)  # asymmetrical - right skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(LEN.phase1.conc.purity$Qubit_fish_DNA)
qqline(LEN.phase1.conc.purity$Qubit_fish_DNA, lty=2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(LEN.phase1.conc.purity$Qubit_fish_DNA)  # P = 1.029e-05

## Kolmogorov-Smirnov test:
ks.test(LEN.phase1.conc.purity$Qubit_fish_DNA, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(LEN.phase1.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log(LEN.phase1.conc.purity$Qubit_fish_DNA + 1))  # P = 0.005119

## log10:
hist(log10(LEN.phase1.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log10(LEN.phase1.conc.purity$Qubit_fish_DNA + 1))  # P = 0.005119

## Exponential:
hist(exp(LEN.phase1.conc.purity$Qubit_fish_DNA))
shapiro.test(exp(LEN.phase1.conc.purity$Qubit_fish_DNA))  # P = 8.11e-15 

## logit:
hist(log(LEN.phase1.conc.purity$Qubit_fish_DNA/(phase1.conc.purity$Qubit_fish_DNA)))
shapiro.test(log(LEN.phase1.conc.purity$Qubit_fish_DNA/(phase1.conc.purity$Qubit_fish_DNA)))  # NA

## Square root:
hist(sqrt(LEN.phase1.conc.purity$Qubit_fish_DNA))
shapiro.test(sqrt(LEN.phase1.conc.purity$Qubit_fish_DNA))  # P = 0.03175

## Reciprocal:
hist(1/LEN.phase1.conc.purity$Qubit_fish_DNA)
shapiro.test(1/(LEN.phase1.conc.purity$Qubit_fish_DNA))  # NA

## Post-PCR concentration data is not normally distributed. Data
## transformation would not resolve this issue. Compare variance in 
## post-PCR between different extraction methods and ethanol treatments.
bartlett.test(Qubit_fish_DNA ~ extraction_method,
              data = LEN.phase1.conc.purity) # P = 0.007976
levene.test(LEN.phase1.conc.purity$Qubit_fish_DNA,
            LEN.phase1.conc.purity$extraction_method,
            location = "mean")  # P = 0.0009901

bartlett.test(Qubit_fish_DNA ~ ethanol_treatment,
              data = LEN.phase1.conc.purity) # P = 5.834e-07
levene.test(LEN.phase1.conc.purity$Qubit_fish_DNA,
            LEN.phase1.conc.purity$ethanol_treatment,
            location = "mean")  # P = 2.992e-06

## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed and there is unequal variance between 
## groups. In these scenarios, switching to a Generalised Linear Model 
## (GLM) and changing the combination of error family and link-function 
## terms to achieve normally distributed residuals is recommended over 
## data transformation. We cannot use Poisson or negative binomial 
## distribution as these are for integer count data. However, a 
## quasi-Poisson distribution can be applied to non-integer count data.

## Run GLM allowing interaction between extraction method and ethanol
## treatment.
glm.PCR <- glm(Qubit_fish_DNA ~ extraction_method + ethanol_treatment
               + extraction_method:ethanol_treatment, 
               family = quasipoisson(link = "log"),
               data = LEN.phase1.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
132.94/30
1-pchisq(132.94, df = 30)  # overdispersed


## Run GLM without interaction term.
glm.PCR <- glm(Qubit_fish_DNA ~ extraction_method + ethanol_treatment, 
               family = quasipoisson(link = "log"),
               data = LEN.phase1.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
183.44/38
1-pchisq(183.44, df = 38)  # overdispersed

## Post-hoc test for ethanol treatment.
glm.PCR.posthoc <- emmeans(glm.PCR, 
                           specs = "ethanol_treatment",
                           type = "response")
multcomp::cld(glm.PCR.posthoc, Letters = letters)
pairs(glm.PCR.posthoc)
plot(glm.PCR.posthoc)

## Get standardised residuals for model validation.
sresid <- resid(glm.PCR, type="pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid,adjust=1))
par(mfrow = c(2,2))
plot(glm.PCR)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.03283
## Slight deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ LEN.phase1.conc.purity$extraction_method)
plot(sresid ~ LEN.phase1.conc.purity$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.PCR)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.PCR)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.PCR)
summary(influence)
CD <- cooks.distance(glm.PCR)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality. There are no satisfactory non-parametric
## alternatives for our data unless we split the dataset by 
## extraction methods and compare ethanol treatments using Kruskal
## -Wallis Test.

## Subset data by MUS extraction protocol.
LEN.conc.MUS <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "MUS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ ethanol_treatment, data = LEN.conc.MUS)

## Dunn's test of multiple comparisons:
dunnTest(Qubit_fish_DNA ~ ethanol_treatment, 
         data = LEN.conc.MUS,
         method = "bh")


## Subset data by MUT extraction protocol.
LEN.conc.MUT <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "MUT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ ethanol_treatment, data = LEN.conc.MUT)


## Subset data by QBT extraction protocol.
LEN.conc.QBT <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "QBT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ ethanol_treatment, data = LEN.conc.QBT)


## Subset data by QBT-ZYMO extraction protocol
LEN.conc.QBTZYMO <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "QBT-ZYMO") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ ethanol_treatment, data = LEN.conc.QBTZYMO)


## Subset data by QPS extraction protocol
LEN.conc.QPS <- LEN.phase1.conc.purity %>%
  filter(extraction_method == "QPS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ ethanol_treatment, data = LEN.conc.QPS)


## The spin ethanol treatment produced lower post-PCR concentrations than
## the wet treatment with the MUS extraction protocol. No differences 
## were observed between ethanol treatments for the MUT, QBT, QBT-ZYMO or 
## QPS protocols.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Check if data are normally distributed.
## Histogram:
hist(VAZ.phase1.conc.purity$Qubit_fish_DNA)  # asymmetrical - right skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.phase1.conc.purity$Qubit_fish_DNA)
qqline(VAZ.phase1.conc.purity$Qubit_fish_DNA, lty=2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.phase1.conc.purity$Qubit_fish_DNA)  # P = 0.3374

## Kolmogorov-Smirnov test:
ks.test(VAZ.phase1.conc.purity$Qubit_fish_DNA, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(VAZ.phase1.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log(VAZ.phase1.conc.purity$Qubit_fish_DNA + 1))  # P = 0.0002616

## log10:
hist(log10(VAZ.phase1.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log10(VAZ.phase1.conc.purity$Qubit_fish_DNA + 1))  # P = 0.0002616

## Exponential:
hist(exp(VAZ.phase1.conc.purity$Qubit_fish_DNA))
shapiro.test(exp(VAZ.phase1.conc.purity$Qubit_fish_DNA))  # P = 8.124e-15 

## logit:
hist(log(VAZ.phase1.conc.purity$Qubit_fish_DNA/(phase1.conc.purity$Qubit_fish_DNA)))
shapiro.test(log(VAZ.phase1.conc.purity$Qubit_fish_DNA/(phase1.conc.purity$Qubit_fish_DNA)))  # NA

## Square root:
hist(sqrt(VAZ.phase1.conc.purity$Qubit_fish_DNA))
shapiro.test(sqrt(VAZ.phase1.conc.purity$Qubit_fish_DNA))  # P = 0.1233

## Reciprocal:
hist(1/VAZ.phase1.conc.purity$Qubit_fish_DNA)
shapiro.test(1/(VAZ.phase1.conc.purity$Qubit_fish_DNA))  # NA

## Post-PCR concentration data is not normally distributed. Data
## transformation would not resolve this issue. Compare variance in 
## post-PCR between different extraction methods and ethanol treatments.
bartlett.test(Qubit_fish_DNA ~ extraction_method,
              data = VAZ.phase1.conc.purity) # P = 0.5112
levene.test(VAZ.phase1.conc.purity$Qubit_fish_DNA,
            VAZ.phase1.conc.purity$extraction_method,
            location = "mean")  # P = 0.5537

bartlett.test(Qubit_fish_DNA ~ ethanol_treatment,
              data = VAZ.phase1.conc.purity) # P = 0.2608
levene.test(VAZ.phase1.conc.purity$Qubit_fish_DNA,
            VAZ.phase1.conc.purity$ethanol_treatment,
            location = "mean")  # P = 0.3803

## Although the data conform to the assumptions of a two-way ANOVA, we
## will apply a GLM with quasi-Poisson distribution to the data for
## consistency with the Horniman invasive sponge.

## Run GLM allowing interaction between extraction method and ethanol
## treatment.
glm.PCR <- glm(Qubit_fish_DNA ~ extraction_method + ethanol_treatment
               + extraction_method:ethanol_treatment, 
               family = quasipoisson(link = "log"),
               data = VAZ.phase1.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
106.69/30
1-pchisq(106.69, df = 30)  # overdispersed


## Run GLM without interaction term.
glm.PCR <- glm(Qubit_fish_DNA ~ extraction_method + ethanol_treatment, 
               family = quasipoisson(link = "log"),
               data = VAZ.phase1.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
163.94/38
1-pchisq(163.94, df = 38)  # overdispersed

## Post-hoc test for ethanol treatment.
glm.PCR.posthoc <- emmeans(glm.PCR, 
                           specs = "extraction_method",
                           type = "response")
multcomp::cld(glm.PCR.posthoc, Letters = letters)
pairs(glm.PCR.posthoc)
plot(glm.PCR.posthoc)

## Get standardised residuals for model validation.
sresid <- resid(glm.PCR, type="pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid,adjust=1))
par(mfrow = c(2,2))
plot(glm.PCR)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.214
## Slight deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.phase1.conc.purity$extraction_method)
plot(sresid ~ VAZ.phase1.conc.purity$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.PCR)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.PCR)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.PCR)
summary(influence)
CD <- cooks.distance(glm.PCR)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## All model assumptions are met. Post-PCR concentration was positively 
## influenced by the MUT and QBT protocols, but the MUT protocol produced 
## lower post-PCR concentrations than the QBT protocol. No differences 
## were found between other extraction protocols.


#================#
# TAXON RICHNESS #
#================#

#-------------------------#
# LENDENFELDIA CHONDRODES #
#-------------------------#

## Subset data by fish taxa and calculate taxon richness.
LEN.fish.richness <- phase1.df %>%
  filter(sample_ID == "LEN",
         group == "Fish") %>%
  droplevels() %>%
  count(sequencing_ID, extraction_method, ethanol_treatment,
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  dplyr::select(-group)

## We need to add non-detections back into the fish richness dataframe 
## so that protocols and treatments are being properly compared in terms 
## of fish detection.

## Make extraction replicate column in phase1.metadata a factor.
phase1.metadata <- phase1.metadata %>% 
  mutate(extraction_replicate = as.factor(extraction_replicate))

## Merge fish.richness with phase1.metadata.
LEN.fish.dat <- left_join(phase1.metadata, LEN.fish.richness) %>%
  dplyr::select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230)) %>%
  filter(sample_ID == "LEN",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  mutate(sample_ID = gsub("[[:digit:]]+", "", sample_ID),
         richness = replace_na(richness, 0)) %>%
  droplevels()


## Check if fish richness data are normally distributed.
## Histogram:
hist(LEN.fish.dat$richness)  # broadly symmetrical

## Quantile-quantile plot (Q-Q plot):
qqnorm(LEN.fish.dat$richness)
qqline(LEN.fish.dat$richness, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(LEN.fish.dat$richness)  # P = 6.106e-08

## Kolmogorov-Smirnov test:
ks.test(LEN.fish.dat$richness, pnorm)  # P = 2.109e-15

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(LEN.fish.dat$richness + 1))
shapiro.test(log(LEN.fish.dat$richness + 1))  # P = 1.76e-08

## log10:
hist(log10(LEN.fish.dat$richness + 1))
shapiro.test(log10(LEN.fish.dat$richness + 1))  # P = 1.76e-08

## Exponential:
hist(exp(LEN.fish.dat$richness))
shapiro.test(exp(LEN.fish.dat$richness))  # P = 1.375e-09

## logit:
hist(log(LEN.fish.dat$richness/(LEN.fish.dat$richness)))
shapiro.test(log(LEN.fish.dat$richness/(LEN.fish.dat$richness)))  # NA

## Square root:
hist(sqrt(LEN.fish.dat$richness))
shapiro.test(sqrt(LEN.fish.dat$richness))  # P = 5.095e-09

## Reciprocal:
hist(1/LEN.fish.dat$richness)
shapiro.test(1/(LEN.fish.dat$richness))  # NA

## Fish richness data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## richness between different extraction methods and ethanol treatments.
bartlett.test(richness ~ extraction_method,
              data = LEN.fish.dat) # P = 0.3108
levene.test(LEN.fish.dat$richness,
            LEN.fish.dat$extraction_method,
            location = "mean")  # P = 0.0996

bartlett.test(richness ~ ethanol_treatment,
              data = LEN.fish.dat) # P = 0.0432
levene.test(LEN.fish.dat$richness,
            LEN.fish.dat$ethanol_treatment,
            location = "mean")  # P = 0.001302

## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed and there is unequal variance between 
## groups. In these scenarios, switching to a Generalised Linear Model 
## (GLM) and changing the combination of error family and link-function 
## terms to achieve normally distributed residuals is recommended over
## data transformation. Since we are dealing with integer count data, 
## we can use Poisson or negative binomial distribution.

## Run GLM allowing interaction between extraction method and ethanol
## treatment.
glm.richness <- glm(richness ~ extraction_method + ethanol_treatment
                    + extraction_method:ethanol_treatment, 
                    family = poisson(link = "log"),
                    data = LEN.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Test for overdispersion
10.639/30
1-pchisq(10.639, df = 30)  # not overdispersed


## Run GLM without interaction term.
glm.richness <- glm(richness ~ extraction_method + ethanol_treatment, 
                    family = poisson(link = "log"),
                    data = LEN.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Test for overdispersion
19.055/38
1-pchisq(19.055, df = 38)  # not overdispersed

## Neither GLM finds an effect of extraction protocol or ethanol treatment,
## individually or combined, on fish taxon richness.


## Get standardised residuals for model validation
sresid <- resid(glm.richness, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid,adjust=1))
par(mfrow = c(2,2))
plot(glm.richness)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.2262
## Substantial deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ LEN.fish.dat$extraction_method)
plot(sresid ~ LEN.fish.dat$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.richness)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.richness)
acf(sresid, main = "Auto-correlation plot")
## Significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.richness)
summary(influence)
CD <- cooks.distance(glm.richness)
plot(CD ~ sresid)
## Cook's distance <1 so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality. Non-parametric alternatives were not 
## explored as no significant effects were found with the GLM.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Subset data by fish taxa and calculate taxon richness.
VAZ.fish.richness <- phase1.df %>%
  filter(sample_ID == "VAZ",
         group == "Fish") %>%
  droplevels() %>%
  count(sequencing_ID, extraction_method, ethanol_treatment,
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  dplyr::select(-group)

## Subset data by mammal taxa and calculate taxon richness.
VAZ.mammal.richness <- phase1.df %>%
  filter(sample_ID == "VAZ",
         group == "Mammal") %>%
  droplevels() %>%
  count(sequencing_ID, extraction_method, ethanol_treatment,
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  dplyr::select(-group)

## Only the QBT and MUS protocols detected mammals. This combined with 
## the fact the primers are meant to target fish means we will not 
## compare extraction protocols and ethanol treatments in terms of mammal 
## richness. However, we need to add non-detections back into the fish 
## richness dataframe so that protocols and treatments are being properly 
## compared in terms of fish detection.

## Merge fish.richness with phase1.metadata.
VAZ.fish.dat <- left_join(phase1.metadata, VAZ.fish.richness) %>%
  dplyr::select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230)) %>%
  mutate(sample_ID = gsub("[[:digit:]]+", "", sample_ID),
         richness = replace_na(richness, 0)) %>%
  filter(sample_ID == "VAZ",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  droplevels()

## Check if fish richness data are normally distributed.
## Histogram:
hist(VAZ.fish.dat$richness)  # aymmetrical - right skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.fish.dat$richness)
qqline(VAZ.fish.dat$richness, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.fish.dat$richness)  # P = 9.481e-10

## Kolmogorov-Smirnov test:
ks.test(VAZ.fish.dat$richness, pnorm)  # P =  3.384e-10

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(VAZ.fish.dat$richness + 1))
shapiro.test(log(VAZ.fish.dat$richness + 1))  # P = 2.101e-09

## log10:
hist(log10(VAZ.fish.dat$richness + 1))
shapiro.test(log10(VAZ.fish.dat$richness + 1))  # P = 2.101e-09

## Exponential:
hist(exp(VAZ.fish.dat$richness))
shapiro.test(exp(VAZ.fish.dat$richness))  # P = 4.652e-12

## logit:
hist(log(VAZ.fish.dat$richness/(VAZ.fish.dat$richness)))
shapiro.test(log(VAZ.fish.dat$richness/(VAZ.fish.dat$richness)))  # NA

## Square root:
hist(sqrt(VAZ.fish.dat$richness))
shapiro.test(sqrt(VAZ.fish.dat$richness))  # P = 2.029e-09

## Reciprocal:
hist(1/VAZ.fish.dat$richness)
shapiro.test(1/(VAZ.fish.dat$richness))  # NA

## Fish richness data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## richness between different extraction methods and ethanol treatments.
bartlett.test(richness ~ extraction_method,
              data = VAZ.fish.dat) # P = 0.001108
levene.test(VAZ.fish.dat$richness,
            VAZ.fish.dat$extraction_method,
            location = "mean")  # P = 0.0004656

bartlett.test(richness ~ ethanol_treatment,
              data = VAZ.fish.dat) # P = 0.7583
levene.test(VAZ.fish.dat$richness,
            VAZ.fish.dat$ethanol_treatment,
            location = "mean")  # P = 0.4478

## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed and there is unequal variance between 
## groups. We will apply a GLM with Poisson distribution to the data.

## Run GLM allowing interaction between extraction method and ethanol
## treatment.
glm.richness <- glm(richness ~ extraction_method + ethanol_treatment
                    + extraction_method:ethanol_treatment, 
                    family = poisson(link = "log"),
                    data = VAZ.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Test for overdispersion
25.078/30
1-pchisq(25.078, df = 30)  # not overdispersed


## Run GLM without interaction term.
glm.richness <- glm(richness ~ extraction_method + ethanol_treatment, 
                    family = poisson(link = "log"),
                    data = VAZ.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Test for overdispersion
38.940/38
1-pchisq(38.940, df = 38)  # not overdispersed

## Neither GLM finds an effect of extraction protocol or ethanol treatment,
## individually or combined, on fish taxon richness.


## Get standardised residuals for model validation
sresid <- resid(glm.richness, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid,adjust=1))
par(mfrow = c(2,2))
plot(glm.richness)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 1.654e-07
## Deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.fish.dat$extraction_method)
plot(sresid ~ VAZ.fish.dat$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.richness)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.richness)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.richness)
summary(influence)
CD <- cooks.distance(glm.richness)
plot(CD ~ sresid)
## Cook's distance <1 so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality. There are no satisfactory non-parametric
## alternatives for our data unless we split the dataset by 
## ethanol treatments and compare extraction methods using Kruskal
## -Wallis Test.

## ETHANOL TREATMENT
## Subset data by spin ethanol treatment.
VAZ.richness.spin <- VAZ.fish.dat %>%
  filter(ethanol_treatment == "spin") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(richness ~ extraction_method, data = VAZ.richness.spin)


## Subset data by blot ethanol treatment.
VAZ.richness.blot <- VAZ.fish.dat %>%
  filter(ethanol_treatment == "blot") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(richness ~ extraction_method, data = VAZ.richness.blot)


## Subset data by wet ethanol treatment.
VAZ.richness.wet <- VAZ.fish.dat %>%
  filter(ethanol_treatment == "wet") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(richness ~ extraction_method, data = VAZ.richness.wet)

## No differences were observed between any extraction protocols for
## any ethanol treatments.


## Combine LEN.fish.dat and VAZ.fish.dat for plotting.
fish.dat <- rbind(LEN.fish.dat, VAZ.fish.dat)

## Plot:
p9 <- ggplot(fish.dat,
             aes(x = ethanol_treatment, y = richness)) + 
  geom_jitter(aes(fill = ethanol_treatment),
              pch = 21, cex = 5, height = 0.1, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.1, 3.1),
                     breaks = seq(0, 3, 1)) +
  scale_fill_manual(values = c("grey30","goldenrod2","dodgerblue3"),
                    guide = "none") +
  labs(title = "(a) Taxon richness",
       x = "Ethanol treatment", y = "Taxon richness") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ extraction_method, scales = "free_y", space = "free")
p9


#==========================#
# PROPORTIONAL READ COUNTS #
#==========================#

#-------------------------#
# LENDENFELDIA CHONDRODES #
#-------------------------#

## Subset data by fish taxa and calculate proportional read counts for
## all fish taxa detected in each sample.
LEN.fish.reads <- phase1.df %>%
  filter(sample_ID == "LEN",
         group == "Fish") %>%
  droplevels() %>%
  group_by(sequencing_ID, extraction_method, ethanol_treatment,
           extraction_replicate, group) %>%
  summarise(PRC = sum(PRC), .groups = "keep") %>%
  ungroup() %>%
  dplyr::select(-group)

## We need to add non-detections back into the fish reads dataset so 
## that extraction protocols and ethanol treatments are being properly 
## compared.

## Merge fish.reads with select.metadata.
LEN.fish.reads <- left_join(phase1.metadata, LEN.fish.reads) %>%
  filter(sample_ID == "LEN",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  mutate(sample_ID = gsub("[[:digit:]]+", "", sample_ID),
         PRC = replace_na(PRC, 0)) %>%
  droplevels()

## Check if fish read data are normally distributed.
## Histogram:
hist(LEN.fish.reads$PRC)  # aymmetrical - left and right skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(LEN.fish.reads$PRC)
qqline(LEN.fish.reads$PRC, lty=2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(LEN.fish.reads$PRC)  # P = 2.516e-06

## Kolmogorov-Smirnov test:
ks.test(LEN.fish.reads$PRC, pnorm)  # P = 3.384e-10

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(LEN.fish.reads$PRC + 1))
shapiro.test(log(LEN.fish.reads$PRC + 1))  # P = 1.128e-06

## log10:
hist(log10(LEN.fish.reads$PRC + 1))
shapiro.test(log10(LEN.fish.reads$PRC + 1))  # P = 1.128e-06

## Exponential:
hist(exp(LEN.fish.reads$PRC))
shapiro.test(exp(LEN.fish.reads$PRC))  # P = 5.339e-06

## logit:
hist(log(LEN.fish.reads$PRC/(LEN.fish.reads$PRC)))
shapiro.test(log(LEN.fish.reads$PRC/(LEN.fish.reads$PRC)))  # NA

## Square root:
hist(sqrt(LEN.fish.reads$PRC))
shapiro.test(sqrt(LEN.fish.reads$PRC))  # P = 3.949e-07

## Reciprocal:
hist(1/LEN.fish.reads$PRC)
shapiro.test(1/(LEN.fish.reads$PRC))  # NA

## Fish read data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## reads between different extraction protocols and ethanol treatments.
bartlett.test(PRC ~ extraction_method,
              data = LEN.fish.reads) # P = 0.6105
levene.test(LEN.fish.reads$PRC,
            LEN.fish.reads$extraction_method,
            location = "mean")  # P = 0.02258

bartlett.test(PRC ~ ethanol_treatment,
              data = LEN.fish.reads) # P = 0.4192
levene.test(LEN.fish.reads$PRC,
            LEN.fish.reads$ethanol_treatment,
            location = "mean")  # P = 0.004049

## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed and there is unequal variance between 
## groups. Since we are dealing with non-integer count data, we will use 
## a GLM with quasi-Poisson distribution.

## Run GLM allowing for interaction between extraction protocol and 
## ethanol treatment.
glm.reads <- glm(PRC ~ extraction_method + ethanol_treatment
                 + extraction_method:ethanol_treatment, 
                 family = "binomial",
                 data = LEN.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
12.558/30
1-pchisq(6.6561, df = 30)  # not overdispersed

## Post-hoc test for extraction method and ethanol treatment.
glm.reads.posthoc <- emmeans(glm.reads, 
                             specs = c("extraction_method", "ethanol_treatment"),
                             type = "response")
multcomp::cld(glm.reads.posthoc, Letters = letters)
pairs(glm.reads.posthoc)
plot(glm.reads.posthoc)


## Run GLM without interaction term.
glm.reads <- glm(PRC ~ extraction_method + ethanol_treatment, 
                 family = "binomial",
                 data = LEN.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
20.255/38
1-pchisq(20.255, df = 38)  # not overdispersed

## Post-hoc test for extraction method.
glm.reads.posthoc <- emmeans(glm.reads, 
                             specs = "ethanol_treatment",
                             type = "response")
multcomp::cld(glm.reads.posthoc, Letters = letters)
pairs(glm.reads.posthoc)
plot(glm.reads.posthoc)


## Get standardised residuals for model validation.
sresid <- resid(glm.reads, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid,adjust=1))
par(mfrow = c(2,2))
plot(glm.reads)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.0003769
## No deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ LEN.fish.reads$extraction_method)
plot(sresid ~ LEN.fish.reads$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.reads)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.reads)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.reads)
summary(influence)
CD <- cooks.distance(glm.reads)
plot(CD ~ sresid)
## Cook's distance <1 so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## from normality. There are no satisfactory non-parametric
## alternatives for our data unless we split the dataset by 
## extraction methods and compare ethanol treatments using Kruskal
## -Wallis Test.

## Subset data by MUS extraction protocol.
LEN.reads.MUS <- LEN.fish.reads %>%
  filter(extraction_method == "MUS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = LEN.reads.MUS)

## Dunn's test of multiple comparisons:
dunnTest(PRC ~ ethanol_treatment, 
         data = LEN.reads.MUS,
         method = "bh")


## Subset data by MUT extraction protocol.
LEN.reads.MUT <- LEN.fish.reads %>%
  filter(extraction_method == "MUT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = LEN.reads.MUT)


## Subset data by QBT extraction protocol.
LEN.reads.QBT <- LEN.fish.reads %>%
  filter(extraction_method == "QBT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = LEN.reads.QBT)


## Subset data by QBT-ZYMO extraction protocol
LEN.reads.QBTZYMO <- LEN.fish.reads %>%
  filter(extraction_method == "QBT-ZYMO") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = LEN.reads.QBTZYMO)


## Subset data by QPS extraction protocol
LEN.reads.QPS <- LEN.fish.reads %>%
  filter(extraction_method == "QPS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = LEN.reads.QPS)

## Dunn's test of multiple comparisons:
dunnTest(PRC ~ ethanol_treatment, 
         data = LEN.reads.QPS,
         method = "bh")

## Proportional reads counts significantly differed between ethanol 
## treatments with MUS and QPS protocols, where the wet treatment 
## produced higher proportional read counts than the spin (MUS) or blot
## (QPS) treatments, but other treatments did not significantly 
## differ from each other. No differences between ethanol treatments 
## were observed for other DNA extraction protocols.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Subset data by fish taxa and calculate proportional read counts for
## all fish taxa detected in each sample.
VAZ.fish.reads <- phase1.df %>%
  filter(sample_ID == "VAZ",
         group == "Fish") %>%
  droplevels() %>%
  group_by(sequencing_ID, extraction_method, ethanol_treatment,
           extraction_replicate, group) %>%
  summarise(PRC = sum(PRC), .groups = "keep") %>%
  ungroup() %>%
  dplyr::select(-group)

## Subset data by mammal taxa and calculate proportional read counts for
## all mammal taxa detected in each sample.
VAZ.mammal.reads <- phase1.df %>%
  filter(sample_ID == "VAZ",
         group == "Mammal") %>%
  droplevels() %>%
  group_by(sequencing_ID, extraction_method, ethanol_treatment,
           extraction_replicate, group) %>%
  summarise(PRC = sum(PRC), .groups = "keep") %>%
  ungroup() %>%
  dplyr::select(-group)

## Only the QBT and MUS extraction protocols detected mammals. This 
## combined with the fact the primers are meant to target fish means we 
## will not compare extraction protocols and ethanol treatments in terms 
## of mammal reads. We need to add non-detections back into the fish reads 
## dataset so that extraction protocols and ethanol treatments are being 
## properly compared.

## Merge fish.reads with select.metadata.
VAZ.fish.reads <- left_join(phase1.metadata, VAZ.fish.reads, 
                            by = "sequencing_ID") %>%
  mutate(sample_ID = gsub("[[:digit:]]+", "", sample_ID),
         PRC = replace_na(PRC, 0)) %>%
  filter(sample_ID == "VAZ",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  droplevels() %>%
  dplyr::select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280,
                   A260_A230, extraction_method.y, ethanol_treatment.y,
                   extraction_replicate.y)) %>%
  rename_with(~ gsub("\\.x", "", .x))

## Check if fish read data are normally distributed.
## Histogram:
hist(VAZ.fish.reads$PRC)  # aymmetrical - right skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.fish.reads$PRC)
qqline(VAZ.fish.reads$PRC, lty=2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.fish.reads$PRC)  # P = 3.867e-10

## Kolmogorov-Smirnov test:
ks.test(VAZ.fish.reads$PRC, pnorm)  # P = 3.384e-10

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(VAZ.fish.reads$PRC + 1))
shapiro.test(log(VAZ.fish.reads$PRC + 1))  # P = 5.887e-10

## log10:
hist(log10(VAZ.fish.reads$PRC + 1))
shapiro.test(log10(VAZ.fish.reads$PRC + 1))  # P = 5.887e-10

## Exponential:
hist(exp(VAZ.fish.reads$PRC))
shapiro.test(exp(VAZ.fish.reads$PRC))  # P = 1.496e-10

## logit:
hist(log(VAZ.fish.reads$PRC/(VAZ.fish.reads$PRC)))
shapiro.test(log(VAZ.fish.reads$PRC/(VAZ.fish.reads$PRC)))  # NA

## Square root:
hist(sqrt(VAZ.fish.reads$PRC))
shapiro.test(sqrt(VAZ.fish.reads$PRC))  # P = 1.434e-09

## Reciprocal:
hist(1/VAZ.fish.reads$PRC)
shapiro.test(1/(VAZ.fish.reads$PRC))  # NA

## Fish read data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## reads between different extraction protocols and ethanol treatments.
bartlett.test(PRC ~ extraction_method,
              data = VAZ.fish.reads) # P = 0.0006599
levene.test(VAZ.fish.reads$PRC,
            VAZ.fish.reads$extraction_method,
            location = "mean")  # P = 5.23e-05

bartlett.test(PRC ~ ethanol_treatment,
              data = VAZ.fish.reads) # P = 6.06e-16
levene.test(VAZ.fish.reads$PRC,
            VAZ.fish.reads$ethanol_treatment,
            location = "mean")  # P = 2.999e-05

## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed and there is unequal variance between 
## groups. Since we are dealing with non-integer count data, we will use 
## a GLM with quasi-Poisson distribution.

## Run GLM allowing for interaction between extraction protocol and 
## ethanol treatment.
glm.reads <- glm(PRC ~ extraction_method + ethanol_treatment
                 + extraction_method:ethanol_treatment, 
                 family = "binomial",
                 data = VAZ.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
8.2862/30
1-pchisq(8.2862, df = 30)  # not overdispersed


## Run GLM without interaction term.
glm.reads <- glm(PRC ~ extraction_method + ethanol_treatment, 
                 family = "binomial",
                 data = VAZ.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
12.034/38
1-pchisq(12.034, df = 38)  # not overdispersed


## Post-hoc test for extraction method.
glm.reads.posthoc <- emmeans(glm.reads, 
                             specs = "extraction_method",
                             type = "response")
multcomp::cld(glm.reads.posthoc, Letters = letters)
pairs(glm.reads.posthoc)
plot(glm.reads.posthoc)

## Post-hoc test for ethanol treatment.
glm.reads.posthoc <- emmeans(glm.reads, 
                             specs = "ethanol_treatment",
                             type = "response")
multcomp::cld(glm.reads.posthoc, Letters = letters)
pairs(glm.reads.posthoc)
plot(glm.reads.posthoc)


## Get standardised residuals for model validation.
sresid <- resid(glm.reads, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid,adjust=1))
par(mfrow = c(2,2))
plot(glm.reads)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 9.502e-05
## No deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.fish.reads$extraction_method)
plot(sresid ~ VAZ.fish.reads$ethanol_treatment)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.reads)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.reads)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.reads)
summary(influence)
CD <- cooks.distance(glm.reads)
plot(CD ~ sresid)
## Cook's distance <1 so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## from normality. There are no satisfactory non-parametric
## alternatives for our data unless we split the dataset by 
## extraction methods and compare ethanol treatments using Kruskal
## -Wallis Test and vice versa.

## ETHANOL TREATMENT
## Subset data by spin treatment.
VAZ.reads.spin <- VAZ.fish.reads %>%
  filter(ethanol_treatment == "spin") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ extraction_method, data = VAZ.reads.spin)


## Subset data by blot treatment.
VAZ.reads.blot <- VAZ.fish.reads %>%
  filter(ethanol_treatment == "blot") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ extraction_method, data = VAZ.reads.blot)


## Subset data by wet treatment.
VAZ.reads.wet <- VAZ.fish.reads %>%
  filter(ethanol_treatment == "wet") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ extraction_method, data = VAZ.reads.wet)


## EXTRACTION PROTOCOLS
## Subset data by MUS extraction protocol.
VAZ.reads.MUS <- VAZ.fish.reads %>%
  filter(extraction_method == "MUS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = VAZ.reads.MUS)


## Subset data by MUT extraction protocol.
VAZ.reads.MUT <- VAZ.fish.reads %>%
  filter(extraction_method == "MUT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = VAZ.reads.MUT)


## Subset data by QBT extraction protocol.
VAZ.reads.QBT <- VAZ.fish.reads %>%
  filter(extraction_method == "QBT") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = VAZ.reads.QBT)


## Subset data by QBT-ZYMO extraction protocol
VAZ.reads.QBTZYMO <- VAZ.fish.reads %>%
  filter(extraction_method == "QBT-ZYMO") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = VAZ.reads.QBTZYMO)

## Dunn's test of multiple comparisons:
dunnTest(PRC ~ ethanol_treatment, 
         data = VAZ.reads.QBTZYMO,
         method = "bh")


## Subset data by QPS extraction protocol
VAZ.reads.QPS <- VAZ.fish.reads %>%
  filter(extraction_method == "QPS") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ ethanol_treatment, data = VAZ.reads.QPS)


## Extraction protocol was not found to influence proportional read
## counts for the spin, blot or wet ethanol treatments. The data were 
## also split by extraction protocol in order to directly compare ethanol 
## treatments using Kruskal-Wallis Test and Dunn’s Test. Proportional 
## reads counts significantly differed between ethanol treatments with 
## the QBT-ZYMO protocol, where the blot treatment produced higher 
## proportional read counts than the spin treatments, but the blot and 
## wet treatments and spin and wet treatments did not significantly 
## differ from each other. No differences between ethanol treatments 
## were observed for other DNA extraction protocols.

## Combine LEN.fish.reads and VAZ.fish.reads for plotting.
fish.reads <- bind_rows(LEN.fish.reads, VAZ.fish.reads)


## Plot:
p10 <- ggplot(fish.reads,
             aes(x = ethanol_treatment, y = PRC)) + 
  geom_jitter(aes(fill = ethanol_treatment),
              pch = 21, cex = 5, height = 0, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.04, 1),
                     breaks = seq(0, 1, 0.1)) +
  scale_fill_manual(values = c("grey30","goldenrod2","dodgerblue3"),
                    guide = "none") +
  labs(title = "(b) Proportional read counts",
       x = "Ethanol treatment", y = "Proportional read counts") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ extraction_method, scales = "free_y", space = "free")
p10



#======================#
# COMMUNITY SIMILARITY #
#======================#

#-------------------------#
# LENDENFELDIA CHONDRODES #
#-------------------------#

## Make a copy of phase1.df where reads are summed by sequencing_ID,
## sample_ID, ethanol_treatment, extraction_method, extraction_replicate,
## group and taxon. Remove mammal detections from the dataset.
LEN.phase1.beta <- phase1.df %>%
  drop_na() %>%
  filter(sample_ID == "LEN") %>%
  group_by(sequencing_ID, sample_ID, ethanol_treatment, 
           extraction_method, extraction_replicate, group,
           taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  filter(!group == "mammal") %>%
  filter(!grepl("EB|Neg|Pos", sequencing_ID)) %>%
  droplevels()

## Create metadata for beta diversity analyses.
LEN.beta.metadata <- LEN.phase1.beta %>% 
  dplyr::select(-c(group, taxon, reads)) %>%
  distinct()

## Now convert phase1.beta into wide format for beta diversity analyses.
LEN.phase1.beta <- LEN.phase1.beta %>%
  dplyr::select(-c(sample_ID, ethanol_treatment, 
                   extraction_method, extraction_replicate, 
                   group)) %>%
  pivot_wider(names_from = taxon, 
              values_from = reads,
              values_fill = 0) %>%
  column_to_rownames("sequencing_ID")

## Remove empty samples and taxonomic assignments as these are problematic 
## for vegan.
LEN.phase1.beta <- LEN.phase1.beta[!sapply(LEN.phase1.beta, function(x) all(x == 0))]
LEN.phase1.beta <- LEN.phase1.beta[!apply(LEN.phase1.beta == 0, 1, all),]

## Convert read count data to presence-absence.
LEN.phase1.beta[LEN.phase1.beta > 0] <- 1

## Create vector of sample IDs that have been retained for beta diversity
## analyses.
LEN.complete.IDs <- rownames(LEN.phase1.beta)

## Remove samples that were empty from beta.metadata.
LEN.beta.metadata <- LEN.beta.metadata[LEN.beta.metadata$sequencing_ID %in% LEN.complete.IDs,]


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO DNA EXTRACTION PROTOCOL
## Create vectors of sample IDs associated with each extraction method.
LEN.MUT <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", extraction_method == "MUT"))
LEN.MUS <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", extraction_method == "MUS"))
LEN.QBT <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", extraction_method == "QBT"))
LEN.QBTZYMO <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", extraction_method == "QBT-ZYMO"))
LEN.QPS <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", extraction_method == "QPS"))

## Create copies of phase1.beta for each extraction protocol.
LEN.MUT.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.MUT$sequencing_ID,]
LEN.MUS.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.MUS$sequencing_ID,]
LEN.QBT.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.QBT$sequencing_ID,]
LEN.QBTZYMO.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.QBTZYMO$sequencing_ID,]
LEN.QPS.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.QPS$sequencing_ID,]

## Beta diversity across MUT samples.
LEN.MUT.multi <- beta.multi(LEN.MUT.beta, index.family = "jaccard")
print(LEN.MUT.multi)

## Beta diversity across MUT samples.
LEN.MUS.multi <- beta.multi(LEN.MUS.beta, index.family = "jaccard")
print(LEN.MUS.multi)

## Beta diversity across QBT samples.
LEN.QBT.multi <- beta.multi(LEN.QBT.beta, index.family = "jaccard")
print(LEN.QBT.multi)

## Beta diversity across QBT-ZYMO samples.
LEN.QBTZYMO.multi <- beta.multi(LEN.QBTZYMO.beta, index.family = "jaccard")
print(LEN.QBTZYMO.multi)

## Beta diversity across QPS samples.
LEN.QPS.multi <- beta.multi(LEN.QPS.beta, index.family = "jaccard")
print(LEN.QPS.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for samples extracted with each method.


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO ETHANOL TREATMENT
## Create vectors of sample IDs associated with each extraction method.
LEN.blot <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", ethanol_treatment == "blot"))
LEN.spin <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", ethanol_treatment == "spin"))
LEN.wet <- droplevels(subset(LEN.beta.metadata, select = "sequencing_ID", ethanol_treatment == "wet"))

## Create copies of phase1.beta for each ethanol treatment.
LEN.blot.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.blot$sequencing_ID,]
LEN.spin.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.spin$sequencing_ID,]
LEN.wet.beta <- LEN.phase1.beta[rownames(LEN.phase1.beta) %in% LEN.wet$sequencing_ID,]

## Beta diversity across blot samples.
LEN.blot.multi <- beta.multi(LEN.blot.beta, index.family = "jaccard")
print(LEN.blot.multi)

## Beta diversity across spin samples.
LEN.spin.multi <- beta.multi(LEN.spin.beta, index.family = "jaccard")
print(LEN.spin.multi)

## Beta diversity across wet samples.
LEN.wet.multi <- beta.multi(LEN.wet.beta, index.family = "jaccard")
print(LEN.wet.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for samples processed with each ethanol 
## treatment.


## Pairwise between-site values of each component of beta diversity
LEN.phase1.dist <- beta.pair(LEN.phase1.beta, index.family = "jaccard")


## 1. TURNOVER PARTITION (COMPLETE CHANGE IN COMMUNITIES)

## BY DNA EXTRACTION PROTOCOL:
LEN.phase1.bd.turn <- betadisper(LEN.phase1.dist$beta.jtu, 
                                 LEN.beta.metadata$extraction_method)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
LEN.phase1.turn <- with(LEN.beta.metadata, LEN.phase1.bd.turn)
LEN.phase1.turn

## Compute mean distance to centroid per group.
tapply(LEN.phase1.bd.turn$distances, 
       LEN.beta.metadata$extraction_method, 
       mean)

## Compute variance per group.
tapply(LEN.phase1.bd.turn$distances, 
       LEN.beta.metadata$extraction_method, 
       var)

## Ordination plot of distances to centroid.
plot(LEN.phase1.bd.turn)

## Boxplot of distances to centroid.
boxplot(LEN.phase1.bd.turn, xlab = "Extraction method", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:5), labels = c("MUS", "MUT", "QBT", "QBT-ZYMO", "QPS"))

## Plots indicate that there is some difference in multivariate 
## dispersion of turnover partition between extraction methods. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(LEN.phase1.bd.turn)     # No significant difference between groups
permutest(LEN.phase1.bd.turn) # No significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(LEN.phase1.bd.turn)  # No significant difference between groups


## BY ETHANOL TREATMENT:
LEN.phase1.bd.turn <- betadisper(LEN.phase1.dist$beta.jtu, 
                                 LEN.beta.metadata$ethanol_treatment)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
LEN.phase1.turn <- with(LEN.beta.metadata, LEN.phase1.bd.turn)
LEN.phase1.turn

## Compute mean distance to centroid per group.
tapply(LEN.phase1.bd.turn$distances, 
       LEN.beta.metadata$ethanol_treatment, 
       mean)

## Compute variance per group.
tapply(LEN.phase1.bd.turn$distances, 
       LEN.beta.metadata$ethanol_treatment, 
       var)

## Ordination plot of distances to centroid.
plot(LEN.phase1.bd.turn)

## Boxplot of distances to centroid.
boxplot(LEN.phase1.bd.turn, xlab = "Ethanol treatment", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("blot", "spin", "wet"))

## Plots indicate that there is some difference in multivariate 
## dispersion of turnover partition between ethanol treatments. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(LEN.phase1.bd.turn)     # Significant difference between groups
permutest(LEN.phase1.bd.turn) # Significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(LEN.phase1.bd.turn)  # Significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by turnover. The metaMDS 
## function automatically transforms data and checks solution robustness.
LEN.phase1.comm.turn <- metaMDS(LEN.phase1.dist$beta.jtu, 
                                dist = "jaccard", 
                                k = 2,
                                maxit = 999,
                                trymax = 1000,
                                noshare = TRUE,
                                wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
LEN.phase1.comm.turn$stress
stressplot(LEN.phase1.comm.turn)

## Plot site scores as text.
ordiplot(LEN.phase1.comm.turn, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
LEN.phase1.turn.scores <- scores(LEN.phase1.comm.turn, display = "sites")

## Add required metadata to compute centroids.
LEN.phase1.turn.scores <- cbind(as.data.frame(LEN.phase1.turn.scores), 
                                Treatment = LEN.beta.metadata$ethanol_treatment,
                                Method = LEN.beta.metadata$extraction_method,
                                Sponge = LEN.beta.metadata$sample_ID)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
LEN.phase1.turn.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Treatment + Method + Sponge, 
                                       data = LEN.phase1.turn.scores, 
                                       FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
LEN.phase1.turn.segments <- merge(LEN.phase1.turn.scores, 
                                  setNames(LEN.phase1.turn.centroids, 
                                           c("Treatment","Method","Sponge","oNMDS1","oNMDS2")),
                                  by = c("Treatment", "Method", "Sponge"), 
                                  sort = FALSE)
  
## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
LEN.phase1.turn.adonis <- adonis(LEN.phase1.dist$beta.jtu ~ extraction_method 
                                 + ethanol_treatment 
                                 + extraction_method:ethanol_treatment,
                                 LEN.beta.metadata)

## Inspect results:
LEN.phase1.turn.adonis

## Taxon replacement (i.e. turnover) is influenced by ethanol treatment
## and ethanol treatment combined with extraction method. Therefore, 
## taxa in one ethanol treatment are not substituted by other taxa in a 
## different ethanol treatment.


## 2. NESTEDNESS PARTITION (SUBSET OF CHANGE IN WIDER COMMUNITY)

## BY DNA EXTRACTION PROTOCOL
LEN.phase1.bd.nest <- betadisper(LEN.phase1.dist$beta.jne,
                                 LEN.beta.metadata$extraction_method)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
LEN.phase1.nest <- with(LEN.beta.metadata, LEN.phase1.bd.nest)
LEN.phase1.nest

## Compute mean distance to centroid per group.
tapply(LEN.phase1.bd.nest$distances, 
       LEN.beta.metadata$extraction_method, 
       mean)

## Compute variance per group.
tapply(LEN.phase1.bd.nest$distances, 
       LEN.beta.metadata$extraction_method, 
       var)

## Ordination plot of distances to centroid.
plot(LEN.phase1.bd.nest)

## Boxplot of distances to centroid.
boxplot(LEN.phase1.bd.nest, xlab = "Extraction method", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:5), labels = c("MUS", "MUT", "QBT", "QBT-ZYMO", "QPS"))

## Plots indicate that there is some difference in multivariate 
## dispersion of nestedness partition between extraction methods. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(LEN.phase1.bd.nest)     # No significant difference between groups
permutest(LEN.phase1.bd.nest) # No significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(LEN.phase1.bd.nest)  # No significant difference between groups


## BY ETHANOL TREATMENT:
LEN.phase1.bd.nest <- betadisper(LEN.phase1.dist$beta.jne, 
                                 LEN.beta.metadata$ethanol_treatment)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
LEN.phase1.nest <- with(LEN.beta.metadata, LEN.phase1.bd.nest)
LEN.phase1.nest

## Compute mean distance to centroid per group.
tapply(LEN.phase1.bd.nest$distances, 
       LEN.beta.metadata$ethanol_treatment, 
       mean)

## Compute variance per group.
tapply(LEN.phase1.bd.nest$distances, 
       LEN.beta.metadata$ethanol_treatment, 
       var)

## Ordination plot of distances to centroid.
plot(LEN.phase1.bd.nest)

## Boxplot of distances to centroid.
boxplot(LEN.phase1.bd.nest, xlab = "Ethanol treatment", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("blot", "spin", "wet"))

## Plots indicate that there is some difference in multivariate 
## dispersion of nestedness partition between ethanol treatments. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(LEN.phase1.bd.nest)     # No significant difference between groups
permutest(LEN.phase1.bd.nest) # No significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(LEN.phase1.bd.nest)  # No significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by nestedness-resultant. 
## The metaMDS function automatically transforms data and checks solution 
## robustness.
LEN.phase1.comm.nest <- metaMDS(LEN.phase1.dist$beta.jne, 
                                dist = "jaccard", 
                                k = 2,
                                maxit = 999,
                                trymax = 1000,
                                noshare = TRUE,
                                wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
LEN.phase1.comm.nest$stress
stressplot(LEN.phase1.comm.nest)

## Plot site scores as text.
ordiplot(LEN.phase1.comm.nest, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
LEN.phase1.nest.scores <- scores(LEN.phase1.comm.nest, display = "sites")

## Add required metadata to compute centroids.
LEN.phase1.nest.scores <- cbind(as.data.frame(LEN.phase1.nest.scores), 
                                Treatment = LEN.beta.metadata$ethanol_treatment,
                                Method = LEN.beta.metadata$extraction_method,
                                Sponge = LEN.beta.metadata$sample_ID)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
LEN.phase1.nest.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Treatment + Method + Sponge, 
                                       data = LEN.phase1.nest.scores, 
                                       FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
LEN.phase1.nest.segments <- merge(LEN.phase1.nest.scores, 
                                  setNames(LEN.phase1.nest.centroids, 
                                           c("Treatment","Method","Sponge","oNMDS1","oNMDS2")),
                                  by = c("Treatment", "Method", "Sponge"), 
                                  sort = FALSE)

## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
LEN.phase1.nest.adonis <- adonis(LEN.phase1.dist$beta.jne ~ extraction_method 
                                 + ethanol_treatment 
                                 + extraction_method:ethanol_treatment,
                                 LEN.beta.metadata)

## Inspect results:
LEN.phase1.nest.adonis

## There is no substantial difference in taxon loss or gain (i.e. nestedness) 
## between extraction methods or ethanol treatments.


## 3. TOTAL BETA DIVERSITY

## BY DNA EXTRACTION PROTOCOL
LEN.phase1.bd.total <- betadisper(LEN.phase1.dist$beta.jac, 
                                  LEN.beta.metadata$extraction_method)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
LEN.phase1.total <- with(LEN.beta.metadata, LEN.phase1.bd.total)
LEN.phase1.total

## Compute mean distance to centroid per group.
tapply(LEN.phase1.bd.total$distances, 
       LEN.beta.metadata$extraction_method, 
       mean)

## Compute variance per group.
tapply(LEN.phase1.bd.total$distances, 
       LEN.beta.metadata$extraction_method, 
       var)

## Ordination plot of distances to centroid.
plot(LEN.phase1.bd.total)

## Boxplot of distances to centroid.
boxplot(LEN.phase1.bd.total, xlab = "Extraction method", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:5), labels = c("MUS", "MUT", "QBT", "QBT-ZYMO", "QPS"))

## Plots indicate that there is some difference in multivariate 
## dispersion of total beta diversity between extraction methods. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(LEN.phase1.bd.total)     # No significant difference between groups
permutest(LEN.phase1.bd.total) # No significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(LEN.phase1.bd.total)  # No significant difference between groups


## BY ETHANOL TREATMENT:
LEN.phase1.bd.total <- betadisper(LEN.phase1.dist$beta.jac, 
                                  LEN.beta.metadata$ethanol_treatment)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
LEN.phase1.total <- with(LEN.beta.metadata, LEN.phase1.bd.total)
LEN.phase1.total

## Compute mean distance to centroid per group.
tapply(LEN.phase1.bd.total$distances, 
       LEN.beta.metadata$ethanol_treatment, 
       mean)

## Compute variance per group.
tapply(LEN.phase1.bd.total$distances, 
       LEN.beta.metadata$ethanol_treatment, 
       var)

## Ordination plot of distances to centroid.
plot(LEN.phase1.bd.total)

## Boxplot of distances to centroid.
boxplot(LEN.phase1.bd.total, xlab = "Ethanol treatment", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("blot", "spin", "wet"))

## Plots indicate that there is some difference in multivariate 
## dispersion of total beta diversity between ethanol treatments. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(LEN.phase1.bd.total)     # Significant difference between groups
permutest(LEN.phase1.bd.total) # Significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(LEN.phase1.bd.total)  # Significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by turnover. The metaMDS 
## function automatically transforms data and checks solution robustness.
LEN.phase1.comm.total <- metaMDS(LEN.phase1.dist$beta.jac, 
                                 dist = "jaccard",
                                 maxit = 999,
                                 trymax = 1000,
                                 noshare = TRUE,
                                 wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
LEN.phase1.comm.total$stress
stressplot(LEN.phase1.comm.total)

## Plot site scores as text.
ordiplot(LEN.phase1.comm.total, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
LEN.phase1.total.scores <- scores(LEN.phase1.comm.total, display = "sites")

## Add required metadata to compute centroids.
LEN.phase1.total.scores <- cbind(as.data.frame(LEN.phase1.total.scores), 
                                 Treatment = LEN.beta.metadata$ethanol_treatment,
                                 Method = LEN.beta.metadata$extraction_method,
                                 Sponge = LEN.beta.metadata$sample_ID)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
LEN.phase1.total.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Treatment + Method + Sponge, 
                                        data = LEN.phase1.total.scores, 
                                        FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
LEN.phase1.total.segments <- merge(LEN.phase1.total.scores, 
                                   setNames(LEN.phase1.total.centroids, 
                                            c("Treatment","Method","Sponge","oNMDS1","oNMDS2")),
                                   by = c("Treatment", "Method", "Sponge"),
                                   sort = FALSE)

## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
LEN.phase1.total.adonis <- adonis(LEN.phase1.dist$beta.jac ~ extraction_method 
                                  + ethanol_treatment 
                                  + extraction_method:ethanol_treatment,
                                  LEN.beta.metadata)

## Inspect results:
LEN.phase1.total.adonis

## Total beta diversity is influenced by ethanol treatment and ethanol
## treatment combined with extraction method.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Make a copy of phase1.df where reads are summed by sequencing_ID,
## sample_ID, ethanol_treatment, extraction_method, extraction_replicate,
## group and taxon. Remove mammal detections from the dataset.
VAZ.phase1.beta <- phase1.df %>%
  drop_na() %>%
  filter(sample_ID == "VAZ") %>%
  group_by(sequencing_ID, sample_ID, ethanol_treatment, 
           extraction_method, extraction_replicate, group,
           taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  filter(!group == "mammal") %>%
  filter(!grepl("EB|Neg|Pos", sequencing_ID)) %>%
  droplevels()

## Create metadata for beta diversity analyses.
VAZ.beta.metadata <- VAZ.phase1.beta %>% 
  dplyr::select(-c(group, taxon, reads)) %>%
  distinct()

## Now convert phase1.beta into wide format for beta diversity analyses.
VAZ.phase1.beta <- VAZ.phase1.beta %>%
  dplyr::select(-c(sample_ID, ethanol_treatment, 
                   extraction_method, extraction_replicate, 
                   group)) %>%
  pivot_wider(names_from = taxon, 
              values_from = reads,
              values_fill = 0) %>%
  column_to_rownames("sequencing_ID")

## Remove empty samples and taxonomic assignments as these are problematic 
## for vegan.
VAZ.phase1.beta <- VAZ.phase1.beta[!sapply(VAZ.phase1.beta, function(x) all(x == 0))]
VAZ.phase1.beta <- VAZ.phase1.beta[!apply(VAZ.phase1.beta == 0, 1, all),]

## Convert read count data to presence-absence.
VAZ.phase1.beta[VAZ.phase1.beta > 0] <- 1

## Create vector of sample IDs that have been retained for beta diversity
## analyses.
VAZ.complete.IDs <- rownames(VAZ.phase1.beta)

## Remove samples that were empty from beta.metadata.
VAZ.beta.metadata <- VAZ.beta.metadata[VAZ.beta.metadata$sequencing_ID %in% VAZ.complete.IDs,]


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO DNA EXTRACTION PROTOCOL
## Create vectors of sample IDs associated with each extraction method.
VAZ.MUT <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", extraction_method == "MUT"))
VAZ.MUS <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", extraction_method == "MUS"))
VAZ.QBT <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", extraction_method == "QBT"))
VAZ.QBTZYMO <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", extraction_method == "QBT-ZYMO"))
VAZ.QPS <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", extraction_method == "QPS"))

## Create copies of phase1.beta for each extraction protocol.
VAZ.MUT.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.MUT$sequencing_ID,]
VAZ.MUS.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.MUS$sequencing_ID,]
VAZ.QBT.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.QBT$sequencing_ID,]
VAZ.QBTZYMO.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.QBTZYMO$sequencing_ID,]
VAZ.QPS.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.QPS$sequencing_ID,]

## Beta diversity across MUT samples.
VAZ.MUT.multi <- beta.multi(VAZ.MUT.beta, index.family = "jaccard")
print(VAZ.MUT.multi)

## Beta diversity across MUT samples.
VAZ.MUS.multi <- beta.multi(VAZ.MUS.beta, index.family = "jaccard")
print(VAZ.MUS.multi)

## Beta diversity across QBT samples.
VAZ.QBT.multi <- beta.multi(VAZ.QBT.beta, index.family = "jaccard")
print(VAZ.QBT.multi)

## Beta diversity across QBT-ZYMO samples.
VAZ.QBTZYMO.multi <- beta.multi(VAZ.QBTZYMO.beta, index.family = "jaccard")
print(VAZ.QBTZYMO.multi)

## Beta diversity across QPS samples.
VAZ.QPS.multi <- beta.multi(VAZ.QPS.beta, index.family = "jaccard")
print(VAZ.QPS.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for samples extracted with each method. 
## Contributions could not be calculated for QPS as there is only one
## Vazella sample extracted with this method that produced data.


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO ETHANOL TREATMENT
## Create vectors of sample IDs associated with each extraction method.
VAZ.blot <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", ethanol_treatment == "blot"))
VAZ.spin <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", ethanol_treatment == "spin"))
VAZ.wet <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", ethanol_treatment == "wet"))

## Create copies of phase1.beta for each ethanol treatment.
VAZ.blot.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.blot$sequencing_ID,]
VAZ.spin.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.spin$sequencing_ID,]
VAZ.wet.beta <- VAZ.phase1.beta[rownames(VAZ.phase1.beta) %in% VAZ.wet$sequencing_ID,]

## Beta diversity across blot samples.
VAZ.blot.multi <- beta.multi(VAZ.blot.beta, index.family = "jaccard")
print(VAZ.blot.multi)

## Beta diversity across spin samples.
VAZ.spin.multi <- beta.multi(VAZ.spin.beta, index.family = "jaccard")
print(VAZ.spin.multi)

## Beta diversity across wet samples.
VAZ.wet.multi <- beta.multi(VAZ.wet.beta, index.family = "jaccard")
print(VAZ.wet.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for samples processed with each ethanol 
## treatment.


## Pairwise between-site values of each component of beta diversity
VAZ.phase1.dist <- beta.pair(VAZ.phase1.beta, index.family = "jaccard")


## 1. TURNOVER PARTITION (COMPLETE CHANGE IN COMMUNITIES)

## BY DNA EXTRACTION PROTOCOL:
VAZ.phase1.bd.turn <- betadisper(VAZ.phase1.dist$beta.jtu, 
                                  VAZ.beta.metadata$extraction_method)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase1.turn <- with(VAZ.beta.metadata, VAZ.phase1.bd.turn)
VAZ.phase1.turn

## Compute mean distance to centroid per group.
tapply(VAZ.phase1.bd.turn$distances, 
       VAZ.beta.metadata$extraction_method, 
       mean)

## Compute variance per group.
tapply(VAZ.phase1.bd.turn$distances, 
       VAZ.beta.metadata$extraction_method, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase1.bd.turn)

## Boxplot of distances to centroid.
boxplot(VAZ.phase1.bd.turn, xlab = "Extraction method", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:5), labels = c("MUS", "MUT", "QBT", "QBT-ZYMO", "QPS"))

## Plots indicate that there is some difference in multivariate 
## dispersion of turnover partition between extraction methods. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(VAZ.phase1.bd.turn)     # No significant difference between groups
permutest(VAZ.phase1.bd.turn) # No significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase1.bd.turn)  # No significant difference between groups


## BY ETHANOL TREATMENT:
VAZ.phase1.bd.turn <- betadisper(VAZ.phase1.dist$beta.jtu, 
                                 VAZ.beta.metadata$ethanol_treatment)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase1.turn <- with(VAZ.beta.metadata, VAZ.phase1.bd.turn)
VAZ.phase1.turn

## Compute mean distance to centroid per group.
tapply(VAZ.phase1.bd.turn$distances, 
       VAZ.beta.metadata$ethanol_treatment, 
       mean)

## Compute variance per group.
tapply(VAZ.phase1.bd.turn$distances, 
       VAZ.beta.metadata$ethanol_treatment, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase1.bd.turn)

## Boxplot of distances to centroid.
boxplot(VAZ.phase1.bd.turn, xlab = "Ethanol treatment", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("blot", "spin", "wet"))

## Plots indicate that there is some difference in multivariate 
## dispersion of turnover partition between ethanol treatments. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(VAZ.phase1.bd.turn)     # Significant difference between groups
permutest(VAZ.phase1.bd.turn) # Significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase1.bd.turn)  # Significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by turnover. The metaMDS 
## function automatically transforms data and checks solution robustness.
VAZ.phase1.comm.turn <- metaMDS(VAZ.phase1.dist$beta.jtu, 
                                dist = "jaccard", 
                                k = 2,
                                maxit = 999,
                                trymax = 1000,
                                noshare = TRUE,
                                wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
VAZ.phase1.comm.turn$stress
stressplot(VAZ.phase1.comm.turn)

## Plot site scores as text.
ordiplot(VAZ.phase1.comm.turn, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
VAZ.phase1.turn.scores <- scores(VAZ.phase1.comm.turn, display = "sites")

## Add required metadata to compute centroids.
VAZ.phase1.turn.scores <- cbind(as.data.frame(VAZ.phase1.turn.scores), 
                                 Treatment = VAZ.beta.metadata$ethanol_treatment,
                                 Method = VAZ.beta.metadata$extraction_method,
                                 Sponge = VAZ.beta.metadata$sample_ID)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
VAZ.phase1.turn.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Treatment + Method + Sponge, 
                                        data = VAZ.phase1.turn.scores, 
                                        FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
VAZ.phase1.turn.segments <- merge(VAZ.phase1.turn.scores, 
                                   setNames(VAZ.phase1.turn.centroids, 
                                            c("Treatment","Method","Sponge","oNMDS1","oNMDS2")),
                                   by = c("Treatment", "Method", "Sponge"), 
                                   sort = FALSE)

## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
VAZ.phase1.turn.adonis <- adonis(VAZ.phase1.dist$beta.jtu ~ extraction_method 
                                 + ethanol_treatment 
                                 + extraction_method:ethanol_treatment,
                                 VAZ.beta.metadata)

## Inspect results:
VAZ.phase1.turn.adonis

## Taxon replacement (i.e. turnover) is not influenced by ethanol 
## treatment or extraction method.


## 2. NESTEDNESS PARTITION (SUBSET OF CHANGE IN WIDER COMMUNITY)

## BY DNA EXTRACTION PROTOCOL
VAZ.phase1.bd.nest <- betadisper(VAZ.phase1.dist$beta.jne, 
                                 VAZ.beta.metadata$extraction_method)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase1.nest <- with(VAZ.beta.metadata, VAZ.phase1.bd.nest)
VAZ.phase1.nest

## Compute mean distance to centroid per group.
tapply(VAZ.phase1.bd.nest$distances, 
       VAZ.beta.metadata$extraction_method, 
       mean)

## Compute variance per group.
tapply(VAZ.phase1.bd.nest$distances, 
       VAZ.beta.metadata$extraction_method, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase1.bd.nest)

## Boxplot of distances to centroid.
boxplot(VAZ.phase1.bd.nest, xlab = "Extraction method", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:5), labels = c("MUS", "MUT", "QBT", "QBT-ZYMO", "QPS"))

## Plots indicate that there is some difference in multivariate 
## dispersion of nestedness partition between extraction methods. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(VAZ.phase1.bd.nest)     # No significant difference between groups
permutest(VAZ.phase1.bd.nest) # No significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase1.bd.nest)  # No significant difference between groups


## BY ETHANOL TREATMENT:
VAZ.phase1.bd.nest <- betadisper(VAZ.phase1.dist$beta.jne, 
                                 VAZ.beta.metadata$ethanol_treatment)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase1.nest <- with(VAZ.beta.metadata, VAZ.phase1.bd.nest)
VAZ.phase1.nest

## Compute mean distance to centroid per group.
tapply(VAZ.phase1.bd.nest$distances, 
       VAZ.beta.metadata$ethanol_treatment, 
       mean)

## Compute variance per group.
tapply(VAZ.phase1.bd.nest$distances, 
       VAZ.beta.metadata$ethanol_treatment, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase1.bd.nest)

## Boxplot of distances to centroid.
boxplot(VAZ.phase1.bd.nest, xlab = "Ethanol treatment", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("blot", "spin", "wet"))

## Plots indicate that there is some difference in multivariate 
## dispersion of nestedness partition between ethanol treatments. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(VAZ.phase1.bd.nest)     # Significant difference between groups
permutest(VAZ.phase1.bd.nest) # Significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase1.bd.nest)  # Significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by nestedness-resultant. 
## The metaMDS function automatically transforms data and checks solution 
## robustness.
VAZ.phase1.comm.nest <- metaMDS(VAZ.phase1.dist$beta.jne, 
                                 dist = "jaccard", 
                                 k = 2,
                                 maxit = 999,
                                 trymax = 1000,
                                 noshare = TRUE,
                                 wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
VAZ.phase1.comm.nest$stress
stressplot(VAZ.phase1.comm.nest)

## Plot site scores as text.
ordiplot(VAZ.phase1.comm.nest, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
VAZ.phase1.nest.scores <- scores(VAZ.phase1.comm.nest, display = "sites")

## Add required metadata to compute centroids.
VAZ.phase1.nest.scores <- cbind(as.data.frame(VAZ.phase1.nest.scores), 
                                Treatment = VAZ.beta.metadata$ethanol_treatment,
                                Method = VAZ.beta.metadata$extraction_method,
                                Sponge = VAZ.beta.metadata$sample_ID)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
VAZ.phase1.nest.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Treatment + Method + Sponge, 
                                       data = VAZ.phase1.nest.scores, 
                                       FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
VAZ.phase1.nest.segments <- merge(VAZ.phase1.nest.scores, 
                                  setNames(VAZ.phase1.nest.centroids, 
                                           c("Treatment","Method","Sponge","oNMDS1","oNMDS2")),
                                  by = c("Treatment", "Method", "Sponge"), 
                                  sort = FALSE)

## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
VAZ.phase1.nest.adonis <- adonis(VAZ.phase1.dist$beta.jne ~ extraction_method 
                                 + ethanol_treatment 
                                 + extraction_method:ethanol_treatment,
                                 VAZ.beta.metadata)

## Inspect results:
VAZ.phase1.nest.adonis

## There is no substantial difference in taxon loss or gain (i.e. nestedness) 
## between extraction methods or ethanol treatments.


## 3. TOTAL BETA DIVERSITY

## BY DNA EXTRACTION PROTOCOL
VAZ.phase1.bd.total <- betadisper(VAZ.phase1.dist$beta.jac, 
                                  VAZ.beta.metadata$extraction_method)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase1.total <- with(VAZ.beta.metadata, VAZ.phase1.bd.total)
VAZ.phase1.total

## Compute mean distance to centroid per group.
tapply(VAZ.phase1.bd.total$distances, 
       VAZ.beta.metadata$extraction_method, 
       mean)

## Compute variance per group.
tapply(VAZ.phase1.bd.total$distances, 
       VAZ.beta.metadata$extraction_method, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase1.bd.total)

## Boxplot of distances to centroid.
boxplot(VAZ.phase1.bd.total, xlab = "Extraction method", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:5), labels = c("MUS", "MUT", "QBT", "QBT-ZYMO", "QPS"))

## Plots indicate that there is some difference in multivariate 
## dispersion of total beta diversity between extraction methods. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(VAZ.phase1.bd.total)     # Significant difference between groups
permutest(VAZ.phase1.bd.total) # Significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase1.bd.total)  # Significant difference between groups


## BY ETHANOL TREATMENT:
VAZ.phase1.bd.total <- betadisper(VAZ.phase1.dist$beta.jac, 
                                  VAZ.beta.metadata$ethanol_treatment)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase1.total <- with(VAZ.beta.metadata, VAZ.phase1.bd.total)
VAZ.phase1.total

## Compute mean distance to centroid per group.
tapply(VAZ.phase1.bd.total$distances, 
       VAZ.beta.metadata$ethanol_treatment, 
       mean)

## Compute variance per group.
tapply(VAZ.phase1.bd.total$distances, 
       VAZ.beta.metadata$ethanol_treatment, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase1.bd.total)

## Boxplot of distances to centroid.
boxplot(VAZ.phase1.bd.total, xlab = "Ethanol treatment", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("blot", "spin", "wet"))

## Plots indicate that there is some difference in multivariate 
## dispersion of total beta diversity between ethanol treatments. 
## Statistically check whether variance is different between methods
## using standard parametric anova or permutation tests.
anova(VAZ.phase1.bd.total)     # No significant difference between groups
permutest(VAZ.phase1.bd.total) # No significant difference between groups

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase1.bd.total)  # Significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by turnover. The metaMDS 
## function automatically transforms data and checks solution robustness.
VAZ.phase1.comm.total <- metaMDS(VAZ.phase1.dist$beta.jac, 
                                 dist = "jaccard", 
                                 k = 2,
                                 maxit = 999,
                                 trymax = 1000,
                                 noshare = TRUE,
                                 wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
VAZ.phase1.comm.total$stress
stressplot(VAZ.phase1.comm.total)

## Plot site scores as text.
ordiplot(VAZ.phase1.comm.total, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
VAZ.phase1.total.scores <- scores(VAZ.phase1.comm.total, display = "sites")

## Add required metadata to compute centroids.
VAZ.phase1.total.scores <- cbind(as.data.frame(VAZ.phase1.total.scores), 
                                 Treatment = VAZ.beta.metadata$ethanol_treatment,
                                 Method = VAZ.beta.metadata$extraction_method,
                                 Sponge = VAZ.beta.metadata$sample_ID)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
VAZ.phase1.total.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Treatment + Method + Sponge, 
                                        data = VAZ.phase1.total.scores, 
                                        FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
VAZ.phase1.total.segments <- merge(VAZ.phase1.total.scores, 
                                   setNames(VAZ.phase1.total.centroids, 
                                            c("Treatment","Method","Sponge","oNMDS1","oNMDS2")),
                                   by = c("Treatment", "Method", "Sponge"),
                                   sort = FALSE)

## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
VAZ.phase1.total.adonis <- adonis(VAZ.phase1.dist$beta.jac ~ extraction_method 
                                  + ethanol_treatment 
                                  + extraction_method:ethanol_treatment,
                                  VAZ.beta.metadata)

## Inspect results:
VAZ.phase1.total.adonis

## Total beta diversity is influenced by ethanol treatment and ethanol
## treatment combined with extraction method.


#===============#
# SUMMARY PLOTS #
#===============#

## Bind dataframes for scores, centroids and segments for each component
## of beta diversity and each sponge species.
## Scores:
phase1.turn.scores <- bind_rows(LEN.phase1.turn.scores,
                                VAZ.phase1.turn.scores)

phase1.nest.scores <- bind_rows(LEN.phase1.nest.scores,
                                VAZ.phase1.nest.scores)

phase1.total.scores <- bind_rows(LEN.phase1.total.scores,
                                 VAZ.phase1.total.scores)

## Centroids:
phase1.turn.centroids <- bind_rows(LEN.phase1.turn.centroids,
                                   VAZ.phase1.turn.centroids)

phase1.nest.centroids <- bind_rows(LEN.phase1.nest.centroids,
                                   VAZ.phase1.nest.centroids)

phase1.total.centroids <- bind_rows(LEN.phase1.total.centroids,
                                    VAZ.phase1.total.centroids)

## Segments:
phase1.turn.segments <- bind_rows(LEN.phase1.turn.segments,
                                  VAZ.phase1.turn.segments)

phase1.nest.segments <- bind_rows(LEN.phase1.nest.segments,
                                  VAZ.phase1.nest.segments)

phase1.total.segments <- bind_rows(LEN.phase1.total.segments,
                                   VAZ.phase1.total.segments)


## Plot beta diversity partitioned by turnover.
p11a <- ggplot(phase1.turn.scores, 
               aes(x = NMDS1, y = NMDS2, 
                   fill = Treatment, shape = Sponge)) + 
  geom_point(data = phase1.turn.centroids, size = 5, alpha = 0.5) + 
  geom_segment(data = phase1.turn.segments,
               mapping = aes(xend = oNMDS1, yend = oNMDS2,
                             colour = Treatment)) +
  geom_point(size = 3, alpha = 0.5) +
  scale_fill_manual(name = "Ethanol\ntreatment",
                    values = c("grey30","goldenrod2","dodgerblue3")) +
  scale_colour_manual(name = "Ethanol\ntreatment",
                      values = c("grey30","goldenrod2","dodgerblue3"),
                      guide = "none") +
  scale_shape_manual(name = "Sponge",
                     values = c(21, 24)) +
  scale_x_continuous(limits = c(-0.6, 0.6), breaks = seq(-0.6, 0.6, 0.3),
                     labels = scales::number_format(accuracy = 0.1)) + 
  scale_y_continuous(limits = c(-0.8, 0.8), breaks = seq(-0.8, 0.8, 0.4),
                     labels = scales::number_format(accuracy = 0.1)) + 
  guides(fill = guide_legend(override.aes = list(shape = 21, size = 5)),
         shape = guide_legend(override.aes = list(size = 5))) +
  labs(title = expression(bold("(c) "~beta~-"diversity")), 
       subtitle = "(i) Turnover", 
       x = "NMDS1", y = "NMDS2") + 
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        plot.subtitle = element_text(face = "bold", hjust = 0, color = "black", margin = unit(c(2, 0, 0, 0), "mm")),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "bottom",
        panel.spacing = unit(1, "lines")) +
  facet_grid(Sponge ~ Method)
p11a

## Plot beta diversity partitioned by nestedness-resultant.
p11b <- ggplot(phase1.nest.scores, 
               aes(x = NMDS1, y = NMDS2, 
                   fill = Treatment, shape = Sponge)) + 
  geom_point(data = phase1.nest.centroids, size = 5, alpha = 0.5) + 
  geom_segment(data = phase1.nest.segments,
               mapping = aes(xend = oNMDS1, yend = oNMDS2,
                             colour = Treatment)) +
  geom_point(size = 3, alpha = 0.5) +
  scale_fill_manual(name = "Ethanol\ntreatment",
                    values = c("grey30","goldenrod2","dodgerblue3")) +
  scale_colour_manual(name = "Ethanol\ntreatment",
                      values = c("grey30","goldenrod2","dodgerblue3"),
                      guide = "none") +
  scale_shape_manual(name = "Sponge",
                     values = c(21, 24)) +
  scale_x_continuous(limits = c(-0.4, 0.4), breaks = seq(-0.4, 0.4, 0.2),
                     labels = scales::number_format(accuracy = 0.1)) + 
  scale_y_continuous(limits = c(-0.4, 0.4), breaks = seq(-0.4, 0.4, 0.2),
                     labels = scales::number_format(accuracy = 0.1)) + 
  guides(fill = guide_legend(override.aes = list(shape = 21, size = 5)),
         shape = guide_legend(override.aes = list(size = 5))) +
  labs(subtitle = "(ii) Nestedness-resultant", 
       x = "NMDS1", y = "NMDS2") + 
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        plot.subtitle = element_text(face = "bold", hjust = 0, color = "black", margin = unit(c(2, 0, 0, 0), "mm")),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "bottom",
        panel.spacing = unit(1, "lines")) +
  facet_grid(Sponge ~ Method)
p11b

## Plot total beta diversity.
p11c <- ggplot(phase1.total.scores, 
               aes(x = NMDS1, y = NMDS2, 
                   fill = Treatment, shape = Sponge)) + 
  geom_point(data = phase1.total.centroids, size = 5, alpha = 0.5) + 
  geom_segment(data = phase1.total.segments,
               mapping = aes(xend = oNMDS1, yend = oNMDS2,
                             colour = Treatment)) +
  geom_point(size = 3, alpha = 0.5) +
  scale_fill_manual(name = "Ethanol\ntreatment",
                    values = c("grey30","goldenrod2","dodgerblue3")) +
  scale_colour_manual(name = "Ethanol\ntreatment",
                      values = c("grey30","goldenrod2","dodgerblue3"),
                      guide = "none") +
  scale_shape_manual(name = "Sponge",
                     values = c(21, 24)) +
  scale_x_continuous(limits = c(-0.8, 0.8), breaks = seq(-0.8, 0.8, 0.4),
                     labels = scales::number_format(accuracy = 0.1)) + 
  scale_y_continuous(limits = c(-0.6, 0.6), breaks = seq(-0.6, 0.6, 0.3),
                     labels = scales::number_format(accuracy = 0.1)) + 
  guides(fill = guide_legend(override.aes = list(shape = 21, size = 5)),
         shape = guide_legend(override.aes = list(size = 5))) +
  labs(subtitle = expression(bold("(iii) Total"~beta~-"diversity")), 
       x = "NMDS1", y = "NMDS2") + 
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        plot.subtitle = element_text(face = "bold", hjust = 0, color = "black", margin = unit(c(2, 0, 0, 0), "mm")),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "bottom",
        panel.spacing = unit(1, "lines")) +
  facet_grid(Sponge ~ Method)
p11c


## Plot all diversity results.
g4 <- ggarrange(ggarrange(p9, p10, nrow = 2, ncol = 1, align = "hv"),
                ggarrange(p11a, p11b, p11c, nrow = 3,  ncol = 1, 
                          align = "hv", common.legend = TRUE, legend = "right"),
                nrow = 1, ncol = 2, widths = c(1.3, 1.7))

## Export plot.
#ggsave(filename = "../figures/Fig4_phase1_alpha_beta_diversity.jpeg", 
#       plot = g4, width = 25, height = 18, dpi = 300, units = "in")


#################
# END OF SCRIPT #
#################

