#' ---
#' Title: "Optimised DNA isolation from marine sponges for natural sampler DNA (nsDNA) metabarcoding"
#' Author: "Lynsey Rebecca Harper"
#' Date: "29th October 2022"
#' ---
#' 
#' 
#' ## Prepare working environment
#' 
#' Clear R memory, set working directory and load required packages. 
#' 

## Clear memory.
rm(list=ls())

## Set working directory to location of R script.
# On first time running code: install.packages("rstudioapi")
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

## Check working directory.
getwd()

## Load required packages.
p <- c("tidyverse","ggpubr","scales","car","MASS","emmeans","FSA",
       "lawstat","vegan","betapart")
new.packages <- p[!(p %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages, 
                                          repos = "https://cran.ma.imperial.ac.uk/",
                                          dependencies=TRUE)
lapply(p, require, character.only = TRUE)

## Load custom functions.
f <- c("CheckResidsFunction.R")
lapply(f, source)

## To ensure reproducibility, print details about the version of R being
## used for analysis.
sessionInfo()



###############
# IMPORT DATA #
###############

## Import refined metabarcoding dataset.
phase2.dat <- read.csv("../output_data/Phase2_refined_data_20220629.csv", 
                       header = TRUE)

## Import metadata.
phase2.metadata <- read.csv("../input_data/Phase2_metadata.csv", 
                            header = TRUE)

## Remove metadata for samples that belong to a different project and
## modify for producing plots summarising DNA concentration and purity 
## for each sample downstream.
phase2.conc.purity <- phase2.metadata %>%
  filter(!grepl("EB|Neg|Pos", sequencing_ID),
         !grepl("H-", sequencing_ID)) %>%
  mutate(extraction_replicate = as.factor(extraction_replicate),
         Qubit_total_DNA = as.numeric(Qubit_total_DNA),
         sample_ID = as.factor(gsub("[[:digit:]]+", "", sample_ID)),
         amount = as.factor(gsub("H|W", "", amount))) %>%
  droplevels()



###################
# BASIC SUMMARIES #
###################

## Summarise the data for each starting material type and amount in terms 
## of DNA concentration, purity, total taxon richness, total read counts, 
## consistency across extraction replicates, and proportional read counts 
## for each taxon.


#==============================#
# DNA CONCENTRATION AND PURITY #
#==============================#

## Plot relationship between total DNA concentration, starting material,
## and amount of starting material.
p1 <- ggplot(phase2.conc.purity,
              aes(x = amount, y = Qubit_total_DNA)) + 
  geom_jitter(aes(fill = amount),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.05, 100), 
                     breaks = seq(0, 100, 20)) +
  scale_fill_manual(values = c("darkorange", "purple", "cyan4",
                               "darkorange", "purple", "cyan4"),
                    guide = "none") +
  labs(title = expression(bold("(a) Total DNA yield")),
       x = "", 
       y = expression(paste("Qubit concentration (ng/",mu,"l)"))) +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ starting_material, scales = "free", space = "free")
p1

## Plot relationship between post-PCR DNA concentration, starting material,
## and amount of starting material.
p2 <- ggplot(phase2.conc.purity,
              aes(x = amount, y = Qubit_fish_DNA,)) + 
  geom_jitter(aes(fill = amount),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.05, 40),
                     breaks = seq(0, 40, 10)) +
  scale_fill_manual(values = c("darkorange", "purple", "cyan4",
                               "darkorange", "purple", "cyan4"),
                    guide = "none") +
  labs(title = expression(bold("(b) Post-PCR DNA concentration")),
       x = "", 
       y = expression(paste("Qubit concentration (ng/",mu,"l)"))) +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ starting_material, scales = "free", space = "free")
p2

## Plot relationship between nanodrop A260/A280 ratio, starting material,
## and amount of starting material.
p3 <- ggplot(phase2.conc.purity,
              aes(x = amount, y = A260_A280,)) + 
  geom_jitter(aes(fill = amount),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  geom_hline(yintercept = 1.8, linetype = "dashed", 
             colour = "black") +
  scale_y_continuous(limits = c(0, 2.5),
                     breaks = seq(0, 2.5, 0.5)) +
  scale_fill_manual(values = c("darkorange", "purple", "cyan4",
                               "darkorange", "purple", "cyan4"),
                    guide = "none") +
  labs(title = expression(bold("(c) DNA purity (A260/A280)")),
       x = "", y = "Adsorbence") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ starting_material, scales = "free", space = "free")
p3

## Plot relationship between nanodrop A260/A230 ratio, starting material,
## and amount of starting material.
p4 <- ggplot(phase2.conc.purity,
              aes(x = amount, y = A260_A230,)) + 
  geom_jitter(aes(fill = amount),
              pch = 21, cex = 5, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  geom_hline(yintercept = 2, linetype = "dashed", 
             colour = "black") +
  scale_y_continuous(limits = c(0, 2.5),
                     breaks = seq(0, 2.5, 0.5)) +
  scale_fill_manual(values = c("darkorange", "purple", "cyan4",
                               "darkorange", "purple", "cyan4"),
                    guide = "none") +
  labs(title = expression(bold("(d) DNA purity (A260/A230)")),
       x = "Amount of starting material", y = "Adsorbence") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sample_ID ~ starting_material, scales = "free", space = "free")
p4

## Combine plots into a single plot.
g1 <- ggarrange(p1, p2, p3, p4, 
                ncol = 1, nrow = 4,
                align = "hv")

## Export plot.
#ggsave(filename = "../figures/Fig5_phase2_concentration_purity.jpeg", 
#       plot = g1, width = 13, height = 25, dpi = 300, units = "in")


#======================================#
# TOTAL TAXON RICHNESS AND READ COUNTS #
#======================================#

## Remove samples belonging to another project, add column describing which 
## vertebrate group taxa belong to, remove numbers from sample_ID column, 
## and replace NA values with 0 in the reads and PRC columns.
phase2.df <- phase2.dat %>%
  mutate_at(vars(taxon), as.character) %>%
  mutate(taxon = replace_na(taxon, "none"),
         group = if_else(taxon %in% c("Balaenoptera acutorostrata",
                                      "Balaenoptera borealis",  
                                      "Balaenoptera musculus",
                                      "Balaenoptera physalus",
                                      "Globicephala melas",
                                      "Grampus griseus",
                                      "Mesoplodon bidens",
                                      "Mesoplodon mirus",
                                      "Tursiops truncatus"), "Mammal", 
                         if_else(taxon == "none", "NA", "Fish")),
         group = as.factor(group),
         taxon = as.factor(taxon),
         reads = replace_na(reads, 0),
         PRC = replace_na(PRC, 0)) %>%
  relocate(group, .before = taxon) %>%
  droplevels()

## Calculate the total number of taxa and number of reads belonging
## to each group for each type of starting material.
sm.richness <- phase2.df %>%
  group_by(sponge, starting_material, group, taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  count(sponge, starting_material, group) %>%
  rename(richness = n) %>%
  drop_na(group)

sm.reads <- phase2.df %>%
  group_by(sponge, starting_material, group) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  drop_na(group)

## Calculate the total number of taxa and number of reads belonging
## to each group for each type and amount of starting material.
sm.amount.richness <- phase2.df %>%
  group_by(sponge, starting_material, amount, group, taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  count(sponge, starting_material, amount, group) %>%
  rename(richness = n) %>%
  drop_na(group)

sm.amount.reads <- phase2.df %>%
  group_by(sponge, starting_material, amount, group) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  drop_na(group)

## Calculate the total number of samples for each type and amount of 
## starting material.
sm.amount.samples <- phase2.df %>%
  dplyr::select(sponge, sample_ID, starting_material, amount,
                extraction_replicate) %>%
  distinct() %>%
  group_by(sponge, sample_ID, starting_material, amount) %>%
  count(starting_material) %>%
  ungroup()

## Merge ws.amount.richness and ws.amount.reads
sm.dat <- merge(sm.amount.richness, sm.amount.reads, 
                by = c("sponge", "starting_material", "amount", "group"), 
                all.x = TRUE)
sm.dat$richness <- ifelse(sm.dat$group == "NA", 0, sm.dat$richness)

## Remove data for samples where no fish or mammal taxa were detected
sm.dat <- sm.dat %>%
  filter(!grepl("NA", group)) %>%
  mutate(amount = as.factor(gsub("H|W", "", amount))) %>%
  droplevels()

## Plot number of taxa detected for each vertebrate group for each type 
## and amount of starting material.
p5 <- ggplot(sm.dat,
             aes(x = amount, y = richness, 
                 group = group, fill = group)) + 
  geom_bar(stat = "identity", 
           position = position_dodge(preserve = "single"), 
           width = 0.5, colour = "black") +
  scale_fill_manual(name = "Group",
                    values = c("lightblue","navy")) +
  scale_y_continuous(limits = c(0, 30), breaks = seq(0, 30, 5)) +
  labs(title = "(a) Taxon richness",
       x = "", y = "Taxon richness") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(1.5, "lines")) +
  facet_grid(sponge ~ starting_material, scales = "free", space = "free")
p5

## Plot number of reads detected for each verterbate group for each type 
## amount of starting material.
p6 <- ggplot(sm.dat,
             aes(x = amount, y = reads, 
                 group = group, fill = group)) + 
  geom_bar(stat = "identity", 
           position = position_dodge(preserve = "single"),
           width = 0.5, colour = "black") +
  scale_fill_manual(name = "Group",
                    values = c("lightblue","navy")) +
  scale_y_continuous(limits = c(0, 160000), 
                     breaks = seq(0, 160000,20000),
                     labels = comma) +
  labs(title = "(b) Read counts",
       x = "Amount of starting material", y = "Read counts") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(1.5, "lines")) +
  facet_grid(sponge ~ starting_material, scales = "free", space = "free")
p6

## Combine plots into a single plot.
g2 <- ggarrange(p5, p6, 
                ncol = 1, nrow = 2,
                align = "hv", 
                common.legend = TRUE, legend = "right")

## Export plot.
#ggsave(filename = "../figures/FigS4_phase2_richness_reads.jpeg", 
#       plot = g2, width = 10, height = 13, dpi = 300, units = "in")


#==================================#
# EXTRACTION REPLICATE CONSISTENCY #
#==================================#

## Create dataframe containing richness of individual extraction 
## replicates.
ext.rep.richness <- phase2.df %>%
  count(sponge, sample_ID, starting_material, amount,
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  mutate(extraction_replicate = as.factor(extraction_replicate)) %>%
  filter(!grepl("NA", group)) %>%
  droplevels()

## Plot richness of individual extraction replicates for each type and
## amount of starting material.
p7 <- ggplot(ext.rep.richness,
             aes(x = extraction_replicate, y = richness,
                 fill = group)) +
  geom_point(pch = 21, size = 3,
             position = position_jitterdodge(jitter.width = 0.3, dodge.width = 1)) + 
  geom_boxplot(alpha = 0.3, outlier.shape = NA,
               position = position_dodge(preserve = "single")) +
  scale_y_continuous(limits = c(0, 12),
                     breaks = seq(0, 12, 1)) +
  scale_fill_manual(name = "Group",
                    values = c("lightblue", "navy")) +
  labs(title = "(a) Taxon richness",
       x = "Extraction replicate\n", y = "Taxon richness") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"),
        plot.title = element_text(face = "bold", hjust = 0),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "right") +
  facet_grid(sponge ~ amount, space = "free")
p7

## Create dataframe containing detection rate across extraction replicates 
## for each taxon. Within dataframe, create new column specifying sample
## number for each sponge species.
detection.rate <- phase2.df %>%
  group_by(sponge, sample_ID, starting_material, amount, 
           group, taxon) %>%
  count(extraction_replicate) %>%
  ungroup() %>%
  rename(no_ext_rep = n) %>%
  group_by(sponge, sample_ID, starting_material, amount, 
           group, taxon) %>%
  summarise(total_ext_rep = sum(no_ext_rep), .groups = "keep") %>%
  ungroup() %>%
  mutate(no_ext_rep_performed = 3,
         SO = total_ext_rep/no_ext_rep_performed,
         amount = as.factor(gsub("H|W", "", amount))) %>%
  filter(!grepl("NA", group)) %>%
  droplevels()

## Plot number of extraction replicates each taxa was detected in.
p8 <- ggplot(detection.rate, 
             aes(x = amount, y = fct_rev(taxon), 
                 size = total_ext_rep, fill = group)) + 
  geom_point(pch = 21) + 
  scale_size_continuous(name = "Number of \nextraction \nreplicates",
                        range = c(1, 5),
                        limits = c(0, 3),
                        breaks = c(0, 1, 2, 3)) + 
  scale_fill_manual(name = "Group",
                    values = c("lightblue", "navy")) +
  guides(fill = guide_legend(override.aes = list(size = 5))) +
  labs(title = "(b) Detection consistency",
       x = "Amount of starting material", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"),
        plot.title = element_text(face = "bold", hjust = 0),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black", face = "italic"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(1, "lines")) + 
  facet_grid(group ~ sample_ID, scales = "free", space = "free")
p8

## Combine plots into a single plot.
g3 <- ggarrange(p7, p8,
                ncol = 1, nrow = 2,
                heights = c(1,2))

## Export plot.
#ggsave(filename = "../figures/FigS6_phase2_extraction_replicates.jpeg", 
#       plot = g3, width = 22, height = 25, dpi = 300, units = "in")


#=====================#
# DETECTION FREQUENCY #
#=====================#

## Now plot proportional read counts for each species detected with 
## different types and amounts of starting material from wild sponges. 
## Reorder factor levels for plotting.
spp.summary <- phase2.df %>%
  arrange(group, taxon) %>%   
  mutate(extraction_replicate = as.factor(extraction_replicate),
         taxon = fct_rev(factor(taxon, unique(taxon))),
         amount = as.factor(gsub("H|W", "", amount))) %>%
  filter(!grepl("NA", group)) %>%
  droplevels()

## Subset for Vazella and Phakellia.
VAZ.spp.summary <- spp.summary %>%
  filter(sponge == "VAZ") %>%
  droplevels()

PHAK.spp.summary <- spp.summary %>%
  filter(sponge == "PHAK") %>%
  droplevels()

## Plot species detected with different amounts of homogenate and dry
## weight for Vazella.
b1a <- ggplot(VAZ.spp.summary, 
              aes(x = amount, y = taxon, 
                  fill = group, shape = extraction_replicate,
                  size = PRC)) + 
  geom_jitter(alpha = 0.5, width = 0.15, height = 0) +
  scale_fill_manual(name = "Group",
                    values = c("lightblue", "navy")) +
  scale_shape_manual(name = "Extraction\nreplicate",
                     values = c(21, 24, 22)) +
  scale_size_continuous(name = "Proportional \nread counts",
                        range = c(3, 10),
                        limits = c(0, 1),
                        breaks = c(0, 0.25, 0.5, 0.75, 1),
                        labels = c("> 0","0.25","0.50","0.75","1.00")) +
  guides(fill = guide_legend(order = 1, 
                             override.aes = list(size = 8,
                                                 shape = 21)),
         size = guide_legend(order = 2,
                             override.aes = list(shape = 21,
                                                 colour = "black",
                                                 fill = "white")),
         shape = guide_legend(order = 3,
                              override.aes = list(size = 8))) +
  labs(title = expression(paste(bold("(a) "), 
                                bolditalic("Vazella pourtalesii"))),
       x = "Amount of starting material", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        plot.title = element_text(face = "bold", hjust = 0),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black", face = "italic"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(2, "lines")) +
  facet_grid(sample_ID ~ starting_material, 
             scales = "free", space = "free")
b1a

## Plot species detected with different amounts of homogenate and dry
## weight for Phakellia.
b1b <- ggplot(PHAK.spp.summary, 
              aes(x = amount, y = taxon, 
                  fill = group, shape = extraction_replicate,
                  size = PRC)) + 
  geom_jitter(alpha = 0.5, width = 0.15, height = 0) +
  scale_fill_manual(name = "Group",
                    values = c("lightblue", "navy")) +
  scale_shape_manual(name = "Extraction\nreplicate",
                     values = c(21, 24, 22)) +
  scale_size_continuous(name = "Proportional \nread counts",
                        range = c(3, 10),
                        limits = c(0, 1),
                        breaks = c(0, 0.25, 0.5, 0.75, 1),
                        labels = c("> 0","0.25","0.50","0.75","1.00")) +
  guides(fill = guide_legend(order = 1, 
                             override.aes = list(size = 8,
                                                 shape = 21)),
         size = guide_legend(order = 2,
                             override.aes = list(shape = 21,
                                                 colour = "black",
                                                 fill = "white")),
         shape = guide_legend(order = 3,
                              override.aes = list(size = 8))) +
  labs(title = expression(paste(bold("(b) "), 
                                bolditalic("Phakellia ventilabrum"))),
       x = "Amount of starting material", y = "Taxon") + 
  theme_bw() + 
  theme(panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        plot.title = element_text(face = "bold", hjust = 0),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black", face = "italic"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key.size = unit(2, "lines")) +
  facet_grid(sample_ID ~ starting_material, 
             scales = "free", space = "free")
b1b

## Combine plots into a single plot.
g4 <- ggarrange(b1a, b1b, 
          ncol = 2, nrow = 1,
          common.legend = TRUE, legend = "right")

## Export plot.
#ggsave(filename = "../figures/Fig6_phase2_detection_summary.jpeg", 
#       plot = g4, width = 20, height = 20, dpi = 300, units = "in")

## Now that basic summaries have been produced, we can perform statistical 
## analyses.

## Subset the data by the Horniman invasive sponge.
PHAK.phase2.conc.purity <- phase2.conc.purity %>%
  filter(sample_ID == "PHAK") %>%
  droplevels()

## Subset the data by Vazella pourtalesii.
VAZ.phase2.conc.purity <- phase2.conc.purity %>%
  filter(sample_ID == "VAZ") %>%
  droplevels()



########################
# STATISTICAL ANALYSIS #
########################

## Compare total DNA yield, post-PCR concentration, taxon richness and 
## community compositon between types and amounts of starting material
## for each sponge species using rstats, vegan and betapart packages. 


#=================#
# TOTAL DNA YIELD #
#=================#

#-----------------------#
# PHAKELLIA VENTILABRUM #
#-----------------------#

## Check if data are normally distributed.
## Histogram:
hist(PHAK.phase2.conc.purity$Qubit_total_DNA)  # broadly symmetrical

## Quantile-quantile plot (Q-Q plot):
qqnorm(PHAK.phase2.conc.purity$Qubit_total_DNA)
qqline(PHAK.phase2.conc.purity$Qubit_total_DNA, lty=2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(PHAK.phase2.conc.purity$Qubit_total_DNA)  # P = 0.2965

## Kolmogorov-Smirnov test:
ks.test(PHAK.phase2.conc.purity$Qubit_total_DNA, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(PHAK.phase2.conc.purity$Qubit_total_DNA + 1))
shapiro.test(log(PHAK.phase2.conc.purity$Qubit_total_DNA + 1))  # P = 0.06572

## log10:
hist(log10(PHAK.phase2.conc.purity$Qubit_total_DNA + 1))
shapiro.test(log10(PHAK.phase2.conc.purity$Qubit_total_DNA +1))  # P = 0.06572

## Exponential:
hist(exp(PHAK.phase2.conc.purity$Qubit_total_DNA))
shapiro.test(exp(PHAK.phase2.conc.purity$Qubit_total_DNA))  # P = 4.302e-14

## logit:
hist(log(PHAK.phase2.conc.purity$Qubit_total_DNA/(PHAK.phase2.conc.purity$Qubit_total_DNA)))
shapiro.test(log(PHAK.phase2.conc.purity$Qubit_total_DNA/(PHAK.phase2.conc.purity$Qubit_total_DNA)))  # NA

## Square root:
hist(sqrt(PHAK.phase2.conc.purity$Qubit_total_DNA))
shapiro.test(sqrt(PHAK.phase2.conc.purity$Qubit_total_DNA))  # P = 0.6365

## Reciprocal:
hist(1/PHAK.phase2.conc.purity$Qubit_total_DNA)
shapiro.test(1/(PHAK.phase2.conc.purity$Qubit_total_DNA))  # P = 5.394e-07


## Total DNA Qubit data is not normally distributed and transformations 
## do not resolve this issue. Compare variance in total DNA concentration 
## between different starting materials and starting amounts.
bartlett.test(Qubit_total_DNA ~ starting_material,
              data = PHAK.phase2.conc.purity) # P = 0.891
levene.test(PHAK.phase2.conc.purity$Qubit_total_DNA,
            PHAK.phase2.conc.purity$starting_material,
            location = "mean") # P = 0.8999

bartlett.test(Qubit_total_DNA ~ amount,
              data = PHAK.phase2.conc.purity) # P = 0.9851
levene.test(PHAK.phase2.conc.purity$Qubit_total_DNA,
            PHAK.phase2.conc.purity$amount,
            location = "mean")  # P = 0.9833


## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed and there is unequal variance between 
## groups. In these scenarios, switching to a Generalised Linear Model 
## (GLM) and changing the combination of error family and link-function 
## terms to achieve normally distributed residuals is recommended over 
## data transformation. We cannot use Poisson or negative binomial 
## distribution as these are for integer count data. However, a 
## quasi-Poisson distribution can be applied to non-integer count data.

## Run GLM allowing interaction between type and amount of starting
## material.
glm.yield <- glm(Qubit_total_DNA ~ starting_material + amount 
                 + starting_material:amount,
                 family = quasipoisson(link = "log"),
                 data = PHAK.phase2.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion
158.08/35
1-pchisq(158.08, df = 35)  # overdispersed


## Run GLM without interaction term.
glm.yield <- glm(Qubit_total_DNA ~ starting_material + amount,
                 family = quasipoisson(link = "log"),
                 data = PHAK.phase2.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion
187.04/37
1-pchisq(187.04, df = 37)  # overdispersed


## Post-hoc test for type of starting material
glm.yield.posthoc <- emmeans(glm.yield, 
                             specs = "starting_material",
                             type = "response")
multcomp::cld(glm.yield.posthoc, Letters = letters)
pairs(glm.yield.posthoc)
plot(glm.yield.posthoc)


## Post-hoc test for amount of starting material
glm.yield.posthoc <- emmeans(glm.yield, 
                             specs = "amount",
                             type = "response")
multcomp::cld(glm.yield.posthoc, Letters = letters)
pairs(glm.yield.posthoc)
plot(glm.yield.posthoc)

## Get standardised residuals for model validation
sresid <- resid(glm.yield, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.yield)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.9325
## Normally distributed.

## Check assumption of homogeneity of variances.
plot(sresid ~ PHAK.phase2.conc.purity$starting_material)
plot(sresid ~ PHAK.phase2.conc.purity$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.yield)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.yield)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.yield)
summary(influence)
CD <- cooks.distance(glm.yield)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters

## All major model assumptions are met despite model being overdispersed, 
## thus a quasi-Poisson GLM is appropriate. Model indicates that type and
## amount of starting material influence total DNA yield. Total DNA yield 
## is significantly higher with homogenate and larger amounts of starting 
## material.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Check if data are normally distributed.
## Histogram:
hist(VAZ.phase2.conc.purity$Qubit_total_DNA)  # negatively skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.phase2.conc.purity$Qubit_total_DNA)
qqline(VAZ.phase2.conc.purity$Qubit_total_DNA, lty=2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.phase2.conc.purity$Qubit_total_DNA)  # P = 0.001877

## Kolmogorov-Smirnov test:
ks.test(VAZ.phase2.conc.purity$Qubit_total_DNA, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(VAZ.phase2.conc.purity$Qubit_total_DNA + 1))
shapiro.test(log(VAZ.phase2.conc.purity$Qubit_total_DNA + 1))  # P = 4.851e-08

## log10:
hist(log10(VAZ.phase2.conc.purity$Qubit_total_DNA + 1))
shapiro.test(log10(VAZ.phase2.conc.purity$Qubit_total_DNA +1))  # P = 4.851e-08

## Exponential:
hist(exp(VAZ.phase2.conc.purity$Qubit_total_DNA))
shapiro.test(exp(VAZ.phase2.conc.purity$Qubit_total_DNA))  # P = 3.7e-15

## logit:
hist(log(VAZ.phase2.conc.purity$Qubit_total_DNA/(VAZ.phase2.conc.purity$Qubit_total_DNA)))
shapiro.test(log(VAZ.phase2.conc.purity$Qubit_total_DNA/(VAZ.phase2.conc.purity$Qubit_total_DNA)))  # NA

## Square root:
hist(sqrt(VAZ.phase2.conc.purity$Qubit_total_DNA))
shapiro.test(sqrt(VAZ.phase2.conc.purity$Qubit_total_DNA))  # P = 1.815e-05

## Reciprocal:
hist(1/VAZ.phase2.conc.purity$Qubit_total_DNA)
shapiro.test(1/(VAZ.phase2.conc.purity$Qubit_total_DNA))  # P = 1.432e-13


## Total DNA Qubit data is not normally distributed and transformations 
## do not resolve this issue. Compare variance in total DNA concentration 
## between different starting materials and starting amounts.
bartlett.test(Qubit_total_DNA ~ starting_material,
              data = VAZ.phase2.conc.purity) # P = 0.4709
levene.test(VAZ.phase2.conc.purity$Qubit_total_DNA,
            VAZ.phase2.conc.purity$starting_material,
            location = "mean") # P = 0.08465

bartlett.test(Qubit_total_DNA ~ amount,
              data = VAZ.phase2.conc.purity) # P = 0.2292
levene.test(VAZ.phase2.conc.purity$Qubit_total_DNA,
            VAZ.phase2.conc.purity$amount,
            location = "mean")  # P = 0.2284


## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed. Instead, we will apply a GLM with
## quasi-Poisson distribution to the non-integer count data.

## Run GLM allowing interaction between type and amount of starting
## material.
glm.yield <- lm(Qubit_total_DNA ~ starting_material + amount 
                 + starting_material:amount,
                 data = VAZ.phase2.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion
23.59/46
1-pchisq(23.59, df = 46)  # overdispersed


## Run GLM without interaction term.
glm.yield <- lm(Qubit_total_DNA ~ starting_material + amount,
                 data = VAZ.phase2.conc.purity)
summary(glm.yield)
anova(glm.yield)
drop1(glm.yield, test = "F")

## Test for overdispersion
23.43/48
1-pchisq(23.43, df = 48)  # overdispersed


## Get standardised residuals for model validation
sresid <- resid(glm.yield, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.yield)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.00368
## Not normally distributed.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.phase2.conc.purity$starting_material)
plot(sresid ~ VAZ.phase2.conc.purity$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.yield)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.yield)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.yield)
summary(influence)
CD <- cooks.distance(glm.yield)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters

## Most model assumptions are met apart from the residuals deviating 
## from normality. There are no satisfactory non-parametric 
## alternatives for our data unless we split the dataset by type of
## starting material and compare amounts of starting material
## using Kruskal-Wallis Test.

## Subset data by homogenised tissue.
VAZ.homog <- VAZ.phase2.conc.purity %>%
  filter(starting_material == "Homogenate") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ amount, data = VAZ.homog)


## Subset data by dried tissue.
VAZ.dried <- VAZ.phase2.conc.purity %>%
  filter(starting_material == "Dried tissue") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_total_DNA ~ amount, data = VAZ.dried)


#========================#
# POST-PCR CONCENTRATION #
#========================#

#-----------------------#
# PHAKELLIA VENTILABRUM #
#-----------------------#

## Check if data are normally distributed.
## Histogram:
hist(PHAK.phase2.conc.purity$Qubit_fish_DNA)  # asymmetrical - right skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(PHAK.phase2.conc.purity$Qubit_fish_DNA)
qqline(PHAK.phase2.conc.purity$Qubit_fish_DNA, lty = 2)  # observations tail away

## Quantitative tests for normal distribution
## Shapiro-Wilk test for normality:
shapiro.test(PHAK.phase2.conc.purity$Qubit_fish_DNA)  # P = 0.01568

## Kolmogorov-Smirnov test:
ks.test(PHAK.phase2.conc.purity$Qubit_fish_DNA, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution
## Natural log:
hist(log(PHAK.phase2.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log(PHAK.phase2.conc.purity$Qubit_fish_DNA + 1))  # P = 0.8775

## log10:
hist(log10(PHAK.phase2.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log10(PHAK.phase2.conc.purity$Qubit_fish_DNA + 1))  # P = 0.8775

## Exponential:
hist(exp(PHAK.phase2.conc.purity$Qubit_fish_DNA))
shapiro.test(exp(PHAK.phase2.conc.purity$Qubit_fish_DNA))  # P = 1.439e-13

## logit:
hist(log(PHAK.phase2.conc.purity$Qubit_fish_DNA/(PHAK.phase2.conc.purity$Qubit_fish_DNA)))
shapiro.test(log(PHAK.phase2.conc.purity$Qubit_fish_DNA/(PHAK.phase2.conc.purity$Qubit_fish_DNA)))  # NA

## Square root:
hist(sqrt(PHAK.phase2.conc.purity$Qubit_fish_DNA))
shapiro.test(sqrt(PHAK.phase2.conc.purity$Qubit_fish_DNA))  # P = 0.6563

## Reciprocal:
hist(1/PHAK.phase2.conc.purity$Qubit_fish_DNA)
shapiro.test(1/(PHAK.phase2.conc.purity$Qubit_fish_DNA))  # P = 6.474e-05

## Fish DNA Qubit data is not normally distributed. A square root 
## transformation would resolve this issue. Compare variance in fish DNA 
## concentration between different types and amounts of starting material.
bartlett.test(Qubit_fish_DNA ~ starting_material,
              data = PHAK.phase2.conc.purity) # P = 0.2395
levene.test(PHAK.phase2.conc.purity$Qubit_fish_DNA,
            PHAK.phase2.conc.purity$starting_material,
            location = "mean")  # P = 0.2394

bartlett.test(Qubit_fish_DNA ~ amount,
              data = PHAK.phase2.conc.purity) # P = 0.2879
levene.test(PHAK.phase2.conc.purity$Qubit_fish_DNA,
            PHAK.phase2.conc.purity$amount,
            location = "mean")  # P = 0.2477

## Although the data conform to the assumptions of a two-way ANOVA, we
## will apply a GLM with quasi-Poisson distribution for consistency with
## the total DNA yield analysis.

## Run GLM allowing interaction between type and amount of starting 
## material.
glm.PCR <- glm(Qubit_fish_DNA ~ starting_material + amount 
               + starting_material:amount,
               family = quasipoisson(link = "log"),
               data = PHAK.phase2.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
72.362/35
1-pchisq(72.362, df = 35)  # overdispersed


## Run GLM without interaction term.
glm.PCR <- glm(Qubit_fish_DNA ~ starting_material + amount,
               family = quasipoisson(link = "log"),
               data = PHAK.phase2.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
74.099/37
1-pchisq(74.099, df = 37)  # overdispersed


## Post-hoc test for type of starting material.
glm.PCR.posthoc <- emmeans(glm.PCR, 
                           specs = "starting_material",
                           type = "response")
multcomp::cld(glm.PCR.posthoc, Letters = letters)
pairs(glm.PCR.posthoc)
plot(glm.PCR.posthoc)

## Get standardised residuals for model validation.
sresid <- resid(glm.PCR, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.PCR)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.00494
## Slight deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ PHAK.phase2.conc.purity$starting_material)
plot(sresid ~ PHAK.phase2.conc.purity$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.PCR)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.PCR)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations
influence <- influence.measures(glm.PCR)
summary(influence)
CD <- cooks.distance(glm.PCR)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality. There are no satisfactory non-parametric 
## alternatives for our data unless we split the dataset by amount of
## starting material and compare types of starting material
## using Kruskal-Wallis Test.

## Subset data by amount 1.
PHAK.amount1 <- PHAK.phase2.conc.purity %>%
  filter(amount == "1") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ starting_material, data = PHAK.amount1)


## Subset data by amount 2.
PHAK.amount2 <- PHAK.phase2.conc.purity %>%
  filter(amount == "2") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ starting_material, data = PHAK.amount2)


## Subset data by amount 3.
PHAK.amount3 <- PHAK.phase2.conc.purity %>%
  filter(amount == "3") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(Qubit_fish_DNA ~ starting_material, data = PHAK.amount3)


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Check if data are normally distributed.
## Histogram:
hist(VAZ.phase2.conc.purity$Qubit_fish_DNA)  # asymmetrical - right skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.phase2.conc.purity$Qubit_fish_DNA)
qqline(VAZ.phase2.conc.purity$Qubit_fish_DNA, lty = 2)  # observations tail away

## Quantitative tests for normal distribution
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.phase2.conc.purity$Qubit_fish_DNA)  # P = 0.09923

## Kolmogorov-Smirnov test:
ks.test(VAZ.phase2.conc.purity$Qubit_fish_DNA, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution
## Natural log:
hist(log(VAZ.phase2.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log(VAZ.phase2.conc.purity$Qubit_fish_DNA + 1))  # P = 0.00156

## log10:
hist(log10(VAZ.phase2.conc.purity$Qubit_fish_DNA + 1))
shapiro.test(log10(VAZ.phase2.conc.purity$Qubit_fish_DNA + 1))  # P = 0.00156

## Exponential:
hist(exp(VAZ.phase2.conc.purity$Qubit_fish_DNA))
shapiro.test(exp(VAZ.phase2.conc.purity$Qubit_fish_DNA))  # P = 2.312e-15

## logit:
hist(log(VAZ.phase2.conc.purity$Qubit_fish_DNA/(VAZ.phase2.conc.purity$Qubit_fish_DNA)))
shapiro.test(log(VAZ.phase2.conc.purity$Qubit_fish_DNA/(VAZ.phase2.conc.purity$Qubit_fish_DNA)))  # P = NA

## Square root:
hist(sqrt(VAZ.phase2.conc.purity$Qubit_fish_DNA))
shapiro.test(sqrt(VAZ.phase2.conc.purity$Qubit_fish_DNA))  # P = 0.4318

## Reciprocal:
hist(1/VAZ.phase2.conc.purity$Qubit_fish_DNA)
shapiro.test(1/(VAZ.phase2.conc.purity$Qubit_fish_DNA))  # NA

## Fish DNA Qubit data is not normally distributed. A square root 
## transformation would resolve this issue. Compare variance in fish DNA 
## concentration between different types and amounts of starting material.
bartlett.test(Qubit_fish_DNA ~ starting_material,
              data = VAZ.phase2.conc.purity) # P = 0.09486
levene.test(VAZ.phase2.conc.purity$Qubit_fish_DNA,
            VAZ.phase2.conc.purity$starting_material,
            location = "mean")  # P = 0.007278

bartlett.test(Qubit_fish_DNA ~ amount,
              data = VAZ.phase2.conc.purity) # P = 0.6811
levene.test(VAZ.phase2.conc.purity$Qubit_fish_DNA,
            VAZ.phase2.conc.purity$amount,
            location = "mean")  # P = 0.7539

## Although the data conform to the assumptions of a two-way ANOVA, we
## will apply a GLM with quasi-Poisson distribution for consistency with
## the total DNA yield analysis.

## Run GLM allowing interaction between type and amount of starting 
## material.
glm.PCR <- glm(Qubit_fish_DNA ~ starting_material + amount 
               + starting_material:amount,
               family = quasipoisson(link = "log"),
               data = VAZ.phase2.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
272.34/46
1-pchisq(272.34, df = 46)  # overdispersed


## Run GLM without interaction term.
glm.PCR <- glm(Qubit_fish_DNA ~ starting_material + amount,
               family = quasipoisson(link = "log"),
               data = VAZ.phase2.conc.purity)
summary(glm.PCR)
anova(glm.PCR)
drop1(glm.PCR, test = "F")

## Test for overdispersion.
278.67/48
1-pchisq(278.67, df = 48)  # overdispersed


## Get standardised residuals for model validation.
sresid <- resid(glm.PCR, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.PCR)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.02792
## Slight deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.phase2.conc.purity$starting_material)
plot(sresid ~ VAZ.phase2.conc.purity$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.PCR)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.PCR)
acf(sresid, main = "Auto-correlation plot")
## Significant autocorrelation.

## Check model not biased by unduly influential observations
influence <- influence.measures(glm.PCR)
summary(influence)
CD <- cooks.distance(glm.PCR)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality and serial autocorrelation.


#================#
# TAXON RICHNESS #
#================#

#-----------------------#
# PHAKELLIA VENTILABRUM #
#-----------------------#

## Subset data by fish species.
PHAK.fish.richness <- phase2.df %>%
  filter(sponge == "PHAK",
         group == "Fish") %>%
  droplevels() %>%
  count(sponge, sample_ID, starting_material, amount, 
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  mutate(extraction_replicate = as.factor(extraction_replicate)) %>%
  dplyr::select(-group)

## We need to add non-detections back into the fish richness dataframe 
## so that protocols and treatments are being properly compared in terms 
## of fish detection.

## Make extraction replicate column in phase2.metadata a factor.
phase2.metadata <- phase2.metadata %>% 
  mutate(extraction_replicate = as.factor(extraction_replicate))

## Merge PHAK.fish.richness with phase2.metadata. Replace W and H in 
## amount column and convert amount to factor.
PHAK.fish.dat <- left_join(phase2.metadata, PHAK.fish.richness) %>%
  dplyr::select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230)) %>%
  filter(sponge == "PHAK",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  mutate(amount = as.factor(gsub("H|W", "", amount)),
         richness = replace_na(richness, 0)) %>%
  droplevels()

## Check if fish richness data are normally distributed.
## Histogram:
hist(PHAK.fish.dat$richness)  # negatively skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(PHAK.fish.dat$richness)
qqline(PHAK.fish.dat$richness, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(PHAK.fish.dat$richness)  # P = 0.0006857

## Kolmogorov-Smirnov test:
ks.test(PHAK.fish.dat$richness, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(PHAK.fish.dat$richness + 1))
shapiro.test(log(PHAK.fish.dat$richness + 1))  # P = 0.0003485

## log10:
hist(log10(PHAK.fish.dat$richness + 1))
shapiro.test(log10(PHAK.fish.dat$richness + 1))  # P = 0.0003485

## Exponential:
hist(exp(PHAK.fish.dat$richness))
shapiro.test(exp(PHAK.fish.dat$richness))  # P = 1.326e-06

## logit:
hist(log(PHAK.fish.dat$richness/(PHAK.fish.dat$richness)))
shapiro.test(log(PHAK.fish.dat$richness/(PHAK.fish.dat$richness)))  # NA

## Square root:
hist(sqrt(PHAK.fish.dat$richness))
shapiro.test(sqrt(PHAK.fish.dat$richness))  # P = 0.0004908

## Reciprocal:
hist(1/PHAK.fish.dat$richness)
shapiro.test(1/(PHAK.fish.dat$richness))  # 0.0001017

## Fish richness data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## richness between different extraction methods and ethanol treatments.
bartlett.test(richness ~ starting_material,
              data = PHAK.fish.dat) # P = 0.2531
levene.test(PHAK.fish.dat$richness,
            PHAK.fish.dat$starting_material,
            location = "mean")  # P = 0.104

bartlett.test(richness ~ amount,
              data = PHAK.fish.dat) # P = 0.5802
levene.test(PHAK.fish.dat$richness,
            PHAK.fish.dat$amount,
            location = "mean")  # P = 0.7874

## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed. Since we are dealing with integer count data, 
## we can use Poisson or negative binomial distribution with a GLM.

## Run GLM allowing interaction between type and amount of starting
## material.
glm.richness <- glm.nb(richness ~ starting_material + amount
                       + starting_material:amount, 
                       data = PHAK.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Test for overdispersion.
3.8961/35
1-pchisq(3.8961, df = 35)  # not overdispersed


## Run GLM without interaction term.
glm.richness <- glm.nb(richness ~ starting_material + amount, 
                       data = PHAK.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Test for overdispersion.
3.9209/37
1-pchisq(3.9209, df = 37)  # not overdispersed


## Get standardised residuals for model validation.
sresid <- resid(glm.richness, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.richness)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.09392
## Residuals normal.

## Check assumption of homogeneity of variances.
plot(sresid ~ PHAK.fish.dat$starting_material)
plot(sresid ~ PHAK.fish.dat$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.richness)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.richness)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.richness)
summary(influence)
CD <- cooks.distance(glm.richness)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## Model assumptions met but no effect of type or amount of starting
## material found.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Subset data by fish taxa and calculate taxon richness.
VAZ.fish.richness <- phase2.df %>%
  filter(sponge == "VAZ",
         group == "Fish") %>%
  droplevels() %>%
  count(sponge, sample_ID, starting_material, amount, 
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  mutate(extraction_replicate = as.factor(extraction_replicate)) %>%
  dplyr::select(-group)

## Subset data by mammal taxa and calculate taxon richness.
VAZ.mammal.richness <- phase2.df %>%
  filter(sponge == "VAZ",
         group == "Mammal") %>%
  droplevels() %>%
  count(sponge, sample_ID, starting_material, amount, 
        extraction_replicate, group) %>%
  rename(richness = n) %>%
  dplyr::select(-group)

## As the primers are meant to target fish means we will not compare 
## type and amount of starting material in terms of mammal richness. 
## However, we need to add non-detections back into the fish richness 
## dataframe so that protocols and treatments are being properly 
## compared in terms of fish detection.

## Merge VAZ.fish.richness with phase2.metadata. Replace W and H in 
## amount column and convert amount to factor.
VAZ.fish.dat <- left_join(phase2.metadata, VAZ.fish.richness) %>%
  dplyr::select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230)) %>%
  filter(sponge == "VAZ",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  mutate(amount = as.factor(gsub("H|W", "", amount)),
         richness = replace_na(richness, 0)) %>%
  droplevels()

## Check if fish richness data are normally distributed.
## Histogram:
hist(VAZ.fish.dat$richness)  # positively skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.fish.dat$richness)
qqline(VAZ.fish.dat$richness, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.fish.dat$richness)  # P = 0.0006771

## Kolmogorov-Smirnov test:
ks.test(VAZ.fish.dat$richness, pnorm)  # P < 2.2e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(VAZ.fish.dat$richness + 1))
shapiro.test(log(VAZ.fish.dat$richness + 1))  # P = 0.003319

## log10:
hist(log10(VAZ.fish.dat$richness + 1))
shapiro.test(log10(VAZ.fish.dat$richness + 1))  # P = 0.003319

## Exponential:
hist(exp(VAZ.fish.dat$richness))
shapiro.test(exp(VAZ.fish.dat$richness))  # P = 1.463e-14

## logit:
hist(log(VAZ.fish.dat$richness/(VAZ.fish.dat$richness)))
shapiro.test(log(VAZ.fish.dat$richness/(VAZ.fish.dat$richness)))  # NA

## Square root:
hist(sqrt(VAZ.fish.dat$richness))
shapiro.test(sqrt(VAZ.fish.dat$richness))  # P = 0.001467

## Reciprocal:
hist(1/VAZ.fish.dat$richness)
shapiro.test(1/(VAZ.fish.dat$richness))  # NA

## Fish richness data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## richness between different types and amounts of starting material.
bartlett.test(richness ~ starting_material,
              data = VAZ.fish.dat) # P = 0.2077
levene.test(VAZ.fish.dat$richness,
            VAZ.fish.dat$starting_material,
            location = "mean")  # P = 0.185

bartlett.test(richness ~ amount,
              data = VAZ.fish.dat) # P = 0.0331
levene.test(VAZ.fish.dat$richness,
            VAZ.fish.dat$amount,
            location = "mean")  # P = 0.006442

## The data do not conform to the assumptions of a two-way ANOVA as the
## data is not normally distributed and there is unequal variance between
## groups. Since we are dealing with integer count data, we can use 
## Poisson or negative binomial distribution with a GLM.

## Run GLM allowing interaction between type and amount of starting
## material.
glm.richness <- glm.nb(richness ~ starting_material + amount
                       + starting_material:amount, 
                       data = VAZ.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Test for overdispersion.
55.395/46
1-pchisq(55.395, df = 46)  # not overdispersed


## Run GLM without interaction term.
glm.richness <- glm.nb(richness ~ starting_material + amount, 
                       data = VAZ.fish.dat)
summary(glm.richness)
anova(glm.richness)
drop1(glm.richness, test = "Chi")

## Post-hoc test for type of starting material
glm.richness.posthoc <- emmeans(glm.richness, 
                             specs = "starting_material",
                             type = "response")
multcomp::cld(glm.richness.posthoc, Letters = letters)
pairs(glm.richness.posthoc)
plot(glm.richness.posthoc)


## Test for overdispersion.
55.833/48
1-pchisq(55.833, df = 48)  # not overdispersed


## Get standardised residuals for model validation.
sresid <- resid(glm.richness, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.richness)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.09527
## Residuals normal.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.fish.dat$starting_material)
plot(sresid ~ VAZ.fish.dat$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.richness)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.richness)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.richness)
summary(influence)
CD <- cooks.distance(glm.richness)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## All model assumptions met. Type of starting material influenced fish
## taxon richness.

## Combine PHAK.fish.dat and VAZ.fish.dat for plotting.
fish.dat <- rbind(PHAK.fish.dat, VAZ.fish.dat)

## Plot:
p9 <- ggplot(fish.dat,
             aes(x = amount, y = richness)) + 
  geom_jitter(aes(fill = amount),
              pch = 21, cex = 5, height = 0.1, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.1, 16),
                     breaks = seq(0, 15, 5)) +
  scale_fill_manual(values = c("darkorange", "purple", "cyan4"),
                    guide = "none") +
  labs(title = "(a) Taxon richness",
       x = "Amount of starting material", y = "Taxon richness") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sponge ~ starting_material, scales = "free_y", space = "free")
p9


#==========================#
# PROPORTIONAL READ COUNTS #
#==========================#

#-----------------------#
# PHAKELLIA VENTILABRUM #
#-----------------------#

## Subset data by fish taxa and calculate proportional read counts for
## all fish taxa detected in each sample.
PHAK.fish.reads <- phase2.df %>%
  filter(sponge == "PHAK",
         group == "Fish") %>%
  droplevels() %>%
  group_by(sequencing_ID, starting_material, amount, 
           extraction_replicate, group) %>%
  summarise(PRC = sum(PRC), .groups = "keep") %>%
  ungroup() %>%
  mutate(extraction_replicate = as.factor(extraction_replicate)) %>%
  dplyr::select(-group)

## We need to add non-detections back into the fish reads dataset so 
## that extraction protocols and ethanol treatments are being properly 
## compared.

## Merge PHAK.fish.reads with phase2.metadata.
PHAK.fish.reads <- left_join(phase2.metadata, PHAK.fish.reads) %>%
  dplyr::select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230)) %>%
  filter(sponge == "PHAK",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  mutate(amount = as.factor(gsub("H|W", "", amount))) %>%
  droplevels() %>%
  mutate(PRC = replace_na(PRC, 0))

## Check if fish read data are normally distributed.
## Histogram:
hist(PHAK.fish.reads$PRC)  # broadly symmetrical

## Quantile-quantile plot (Q-Q plot):
qqnorm(PHAK.fish.reads$PRC)
qqline(PHAK.fish.reads$PRC, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(PHAK.fish.reads$PRC)  # P = 0.8421

## Kolmogorov-Smirnov test:
ks.test(PHAK.fish.reads$PRC, pnorm)  # P = 9.992e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(PHAK.fish.reads$PRC + 1))
shapiro.test(log(PHAK.fish.reads$PRC + 1))  # P = 0.9454

## log10:
hist(log10(PHAK.fish.reads$PRC + 1))
shapiro.test(log10(PHAK.fish.reads$PRC + 1))  # P = 0.9454

## Exponential:
hist(exp(PHAK.fish.reads$PRC))
shapiro.test(exp(PHAK.fish.reads$PRC))  # P = 0.4429

## logit:
hist(log(PHAK.fish.reads$PRC/(PHAK.fish.reads$PRC)))
shapiro.test(log(PHAK.fish.reads$PRC/(PHAK.fish.reads$PRC)))  # NA

## Square root:
hist(sqrt(PHAK.fish.reads$PRC))
shapiro.test(sqrt(PHAK.fish.reads$PRC))  # P = 0.960

## Reciprocal:
hist(1/PHAK.fish.reads$PRC)
shapiro.test(1/(PHAK.fish.reads$PRC))  # 0.1111

## Fish read data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## reads between type and amount of starting material.
bartlett.test(PRC ~ starting_material,
              data = PHAK.fish.reads) # P = 0.02508
levene.test(PHAK.fish.reads$PRC,
            PHAK.fish.reads$starting_material,
            location = "mean")  # P = 0.05118

bartlett.test(PRC ~ amount,
              data = PHAK.fish.reads) # P = 0.0188
levene.test(PHAK.fish.reads$PRC,
            PHAK.fish.reads$amount,
            location = "mean")  # P = 0.06679

## The data do not conform to the assumptions of a two-way ANOVA as
## there is unequal variance between groups. Since we are dealing with 
## proportional data bounded from 0 to 1, we can use binomial 
## distribution with a GLM.

## Run GLM allowing interaction between type and amount of starting
## material.
glm.reads <- glm(PRC ~ starting_material + amount 
                 + starting_material:amount, 
                 family = binomial,
                 data = PHAK.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
1.0231/35
1-pchisq(1.0231, df = 35)  # not overdispersed


## Run GLM allowing interaction between type and amount of starting
## material.
glm.reads <- glm(PRC ~ starting_material + amount, 
                 family = binomial,
                 data = PHAK.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
1.0911/37
1-pchisq(1.0911, df = 37)  # not overdispersed


## Get standardised residuals for model validation.
sresid <- resid(glm.reads, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.reads)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 0.5142
## No deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ PHAK.fish.reads$starting_material)
plot(sresid ~ PHAK.fish.reads$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.reads)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.reads)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.reads)
summary(influence)
CD <- cooks.distance(glm.reads)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## All model assumptions met. No effect of type or amount of starting
## material on fish proportional read counts found.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Subset data by fish taxa and calculate proportional read counts for
## all fish taxa detected in each sample.
VAZ.fish.reads <- phase2.df %>%
  filter(sponge == "VAZ",
         group == "Fish") %>%
  droplevels() %>%
  group_by(sequencing_ID, starting_material, amount, 
           extraction_replicate, group) %>%
  summarise(PRC = sum(PRC), .groups = "keep") %>%
  ungroup() %>%
  mutate(extraction_replicate = as.factor(extraction_replicate)) %>%
  dplyr::select(-group)

## We need to add non-detections back into the fish reads dataset so 
## that extraction protocols and ethanol treatments are being properly 
## compared.

## Merge VAZ.fish.reads with phase2.metadata.
VAZ.fish.reads <- left_join(phase2.metadata, VAZ.fish.reads) %>%
  dplyr::select(-c(Qubit_total_DNA, Qubit_fish_DNA, A260_A280, A260_A230)) %>%
  filter(sponge == "VAZ",
         !grepl("EB|Neg|Pos", sequencing_ID)) %>%
  mutate(amount = as.factor(gsub("H|W", "", amount))) %>%
  droplevels() %>%
  mutate(PRC = replace_na(PRC, 0))

## Check if fish read data are normally distributed.
## Histogram:
hist(VAZ.fish.reads$PRC)  # positively skewed

## Quantile-quantile plot (Q-Q plot):
qqnorm(VAZ.fish.reads$PRC)
qqline(VAZ.fish.reads$PRC, lty = 2)  # observations tail away

## Apply quantitative tests for normal distribution.
## Shapiro-Wilk test for normality:
shapiro.test(VAZ.fish.reads$PRC)  # P = 5.729e-06

## Kolmogorov-Smirnov test:
ks.test(VAZ.fish.reads$PRC, pnorm)  # P = 9.992e-16

## Check whether any common data transformations improve data distribution.
## Natural log:
hist(log(VAZ.fish.reads$PRC + 1))
shapiro.test(log(VAZ.fish.reads$PRC + 1))  # P = 2.781e-05

## log10:
hist(log10(VAZ.fish.reads$PRC + 1))
shapiro.test(log10(VAZ.fish.reads$PRC + 1))  # P = 2.781e-05

## Exponential:
hist(exp(VAZ.fish.reads$PRC))
shapiro.test(exp(VAZ.fish.reads$PRC))  # P = 9.433e-07

## logit:
hist(log(VAZ.fish.reads$PRC/(VAZ.fish.reads$PRC)))
shapiro.test(log(VAZ.fish.reads$PRC/(VAZ.fish.reads$PRC)))  # NA

## Square root:
hist(sqrt(VAZ.fish.reads$PRC))
shapiro.test(sqrt(VAZ.fish.reads$PRC))  # P = 0.2941

## Reciprocal:
hist(1/VAZ.fish.reads$PRC)
shapiro.test(1/(VAZ.fish.reads$PRC))  # NA

## Fish read data is not normally distributed and data transformation
## would not substantially improve matters. Compare variance in fish 
## reads between type and amount of starting material.
bartlett.test(PRC ~ starting_material,
              data = VAZ.fish.reads) # P = 0.6267
levene.test(VAZ.fish.reads$PRC,
            VAZ.fish.reads$starting_material,
            location = "mean")  # P = 0.6221

bartlett.test(PRC ~ amount,
              data = VAZ.fish.reads) # P = 0.003181
levene.test(VAZ.fish.reads$PRC,
            VAZ.fish.reads$amount,
            location = "mean")  # P = 0.02288

## The data do not conform to the assumptions of a two-way ANOVA as
## there is unequal variance between groups. Since we are dealing with 
## proportional data bounded from 0 to 1, we can use binomial 
## distribution with a GLM.

## Run GLM allowing interaction between type and amount of starting
## material.
glm.reads <- glm(PRC ~ starting_material + amount 
                 + starting_material:amount, 
                 family = binomial,
                 data = VAZ.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
2.9687/46
1-pchisq(2.9687, df = 46)  # not overdispersed


## Run GLM allowing interaction between type and amount of starting
## material.
glm.reads <- glm(PRC ~ starting_material + amount, 
                 family = binomial,
                 data = VAZ.fish.reads)
summary(glm.reads)
anova(glm.reads)
drop1(glm.reads, test = "F")

## Test for overdispersion.
2.9820/48
1-pchisq(2.9820, df = 48)  # not overdispersed


## Get standardised residuals for model validation.
sresid <- resid(glm.reads, type = "pearson")

## Check assumption of normal distribution. Most models are robust to 
## slight deviations from normality in the residuals.
hist(sresid)
lines(density(sresid, adjust = 1))
par(mfrow = c(2,2))
plot(glm.reads)
par(mfrow = c(1,1))
shapiro.test(sresid) # P = 3.11e-05
## No deviation from normality.

## Check assumption of homogeneity of variances.
plot(sresid ~ VAZ.fish.reads$starting_material)
plot(sresid ~ VAZ.fish.reads$amount)
## No heteroscedasticity present.

## Check assumption of no collinearity.
vif(glm.reads)
## No collinearity present.

## Check dataset does not contain serial auto-correlation. This can arise 
## if there are unaccounted for relationships in data set or if there is 
## a confounding effect of time or space.
durbinWatsonTest(glm.reads)
acf(sresid, main = "Auto-correlation plot")
## No significant autocorrelation.

## Check model not biased by unduly influential observations.
influence <- influence.measures(glm.reads)
summary(influence)
CD <- cooks.distance(glm.reads)
plot(CD ~ sresid)
## Cook's distance <1 for so observations not exerting strong influence 
## on model parameters.

## Most model assumptions are met apart from the residuals deviating 
## slightly from normality. There are no satisfactory non-parametric 
## alternatives for our data unless we split the dataset by type of
## starting material and compare amounts of starting material
## using Kruskal-Wallis Test.

## DRIED TISSUE
## Subset data by dried tissue.
VAZ.reads.tissue <- VAZ.fish.reads %>%
  filter(starting_material == "Dried tissue") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ amount, data = VAZ.reads.tissue)


## HOMOGENATE
## Subset data by homogenate.
VAZ.reads.homog <- VAZ.fish.reads %>%
  filter(starting_material == "Homogenate") %>%
  droplevels()

## Kruskal-Wallis Test:
kruskal.test(PRC ~ amount, data = VAZ.reads.homog)

## KW test indicates no significant difference in fish reads between
## amounts of starting material. 


## Combine PHAK.fish.reads and VAZ.fish.reads for plotting.
fish.reads <- bind_rows(PHAK.fish.reads, VAZ.fish.reads)

## Plot:
p10 <- ggplot(fish.reads,
              aes(x = amount, y = PRC)) + 
  geom_jitter(aes(fill = amount),
              pch = 21, cex = 5, height = 0, width = 0.3, alpha = 0.8) + 
  geom_boxplot(alpha = 0.5, outlier.shape = NA) +
  scale_y_continuous(limits = c(-0.04, 1),
                     breaks = seq(0, 1, 0.1)) +
  scale_fill_manual(values = c("darkorange", "purple", "cyan4"),
                    guide = "none") +
  labs(title = "(b) Proportional read counts",
       x = "Amount of starting material", y = "Proportional read counts") +
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"), 
        plot.title = element_text(face = "bold"),
        axis.title.x = element_text(margin = unit(c(5, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "none") + 
  facet_grid(sponge ~ starting_material, scales = "free_y", space = "free")
p10


#======================#
# COMMUNITY SIMILARITY #
#======================#

#-----------------------#
# PHAKELLIA VENTILABRUM #
#-----------------------#

## Make a copy of phase2.df where reads are summed by sequencing_ID,
## sample_ID, starting_material, amount, extraction_replicate,
## group and taxon. Remove mammal detections from the dataset.
PHAK.phase2.beta <- phase2.df %>%
  drop_na() %>%
  filter(sponge == "PHAK") %>%
  group_by(sequencing_ID, sponge, sample_ID, starting_material, 
           amount, extraction_replicate, group, taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  filter(!group == "mammal") %>%
  droplevels()

## Create metadata for beta diversity analyses.
PHAK.beta.metadata <- PHAK.phase2.beta %>%
  dplyr::select(-c(group, taxon, reads)) %>%
  mutate(amount = as.factor(gsub("H|W", "", amount)),
         extraction_replicate = as.factor(extraction_replicate)) %>%
  distinct()

## Now convert phase2.beta into wide format for beta diversity analyses.
PHAK.phase2.beta <- PHAK.phase2.beta %>%
  dplyr::select(-c(sponge, sample_ID, starting_material, amount,
                   extraction_replicate, group)) %>%
  pivot_wider(names_from = taxon, 
              values_from = reads,
              values_fill = 0) %>%
  column_to_rownames("sequencing_ID")

## Remove empty samples and taxonomic assignments as these are problematic 
## for vegan.
PHAK.phase2.beta <- PHAK.phase2.beta[!sapply(PHAK.phase2.beta, function(x) all(x == 0))]
PHAK.phase2.beta <- PHAK.phase2.beta[!apply(PHAK.phase2.beta == 0, 1, all),]

## Convert read count data to presence-absence.
PHAK.phase2.beta[PHAK.phase2.beta > 0] <- 1

## Create vector of sample IDs that have been retained for beta diversity
## analyses.
PHAK.complete.IDs <- rownames(PHAK.phase2.beta)

## Remove samples that were empty from beta.metadata.
PHAK.beta.metadata <- PHAK.beta.metadata[PHAK.beta.metadata$sequencing_ID %in% PHAK.complete.IDs,]


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO TYPE OF STARTING MATERIAL
## Create vectors of sample IDs associated with each type of starting
## material.
PHAK.tissue <- droplevels(subset(PHAK.beta.metadata, select = "sequencing_ID", starting_material == "Dried tissue"))
PHAK.homogenate <- droplevels(subset(PHAK.beta.metadata, select = "sequencing_ID", starting_material == "Homogenate"))

## Create copies of phase2.beta for each type of starting material.
PHAK.tissue.beta <- PHAK.phase2.beta[rownames(PHAK.phase2.beta) %in% PHAK.tissue$sequencing_ID,]
PHAK.homogenate.beta <- PHAK.phase2.beta[rownames(PHAK.phase2.beta) %in% PHAK.homogenate$sequencing_ID,]

## Beta diversity across dried tissue samples.
PHAK.tissue.multi <- beta.multi(PHAK.tissue.beta, index.family = "jaccard")
print(PHAK.tissue.multi)

## Beta diversity across homogenate samples.
PHAK.homogenate.multi <- beta.multi(PHAK.homogenate.beta, index.family = "jaccard")
print(PHAK.homogenate.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for each type of starting material.


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO AMOUNT OF STARTING MATERIAL
## Create vectors of sample IDs associated with each amount of starting
## material.
PHAK.amount1 <- droplevels(subset(PHAK.beta.metadata, select = "sequencing_ID", amount == "1"))
PHAK.amount2 <- droplevels(subset(PHAK.beta.metadata, select = "sequencing_ID", amount == "2"))
PHAK.amount3 <- droplevels(subset(PHAK.beta.metadata, select = "sequencing_ID", amount == "3"))

## Create copies of phase2.beta for each amount of starting material.
PHAK.amount1.beta <- PHAK.phase2.beta[rownames(PHAK.phase2.beta) %in% PHAK.amount1$sequencing_ID,]
PHAK.amount2.beta <- PHAK.phase2.beta[rownames(PHAK.phase2.beta) %in% PHAK.amount2$sequencing_ID,]
PHAK.amount3.beta <- PHAK.phase2.beta[rownames(PHAK.phase2.beta) %in% PHAK.amount3$sequencing_ID,]

## Beta diversity across amount 1 samples.
PHAK.amount1.multi <- beta.multi(PHAK.amount1.beta, index.family = "jaccard")
print(PHAK.amount1.multi)

## Beta diversity across amount 2 samples.
PHAK.amount2.multi <- beta.multi(PHAK.amount2.beta, index.family = "jaccard")
print(PHAK.amount2.multi)

## Beta diversity across amount 3 samples.
PHAK.amount3.multi <- beta.multi(PHAK.amount3.beta, index.family = "jaccard")
print(PHAK.amount3.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for each amount of starting material.


## Pairwise between-site values of each component of beta diversity
PHAK.phase2.dist <- beta.pair(PHAK.phase2.beta, index.family = "jaccard")


## 1. TURNOVER PARTITION (COMPLETE CHANGE IN COMMUNITIES)

## BY TYPE OF STARTING MATERIAL:
PHAK.phase2.bd.turn <- betadisper(PHAK.phase2.dist$beta.jtu, 
                                  PHAK.beta.metadata$starting_material)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
PHAK.phase2.turn <- with(PHAK.beta.metadata, PHAK.phase2.bd.turn)
PHAK.phase2.turn

## Compute mean distance to centroid per group.
tapply(PHAK.phase2.bd.turn$distances, 
       PHAK.beta.metadata$starting_material, 
       mean)

## Compute variance per group.
tapply(PHAK.phase2.bd.turn$distances, 
       PHAK.beta.metadata$starting_material, 
       var)

## Ordination plot of distances to centroid.
plot(PHAK.phase2.bd.turn)

## Boxplot of distances to centroid.
boxplot(PHAK.phase2.bd.turn, xlab = "starting material", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:2), labels = c("Dried tissue", "Homogenate"))

## Plots indicate that there is little difference in multivariate 
## dispersion of turnover partition between types of starting material. 
## Statistically check whether variance is different between types
## using standard parametric anova or permutation tests.
anova(PHAK.phase2.bd.turn)     # No significant difference 
permutest(PHAK.phase2.bd.turn) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(PHAK.phase2.bd.turn)  # No significant difference between groups


## BY AMOUNT OF STARTING MATERIAL:
PHAK.phase2.bd.turn <- betadisper(PHAK.phase2.dist$beta.jtu, 
                                  PHAK.beta.metadata$amount)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
PHAK.phase2.turn <- with(PHAK.beta.metadata, PHAK.phase2.bd.turn)
PHAK.phase2.turn

## Compute mean distance to centroid per group.
tapply(PHAK.phase2.bd.turn$distances, 
       PHAK.beta.metadata$amount, 
       mean)

## Compute variance per group.
tapply(PHAK.phase2.bd.turn$distances, 
       PHAK.beta.metadata$amount, 
       var)

## Ordination plot of distances to centroid.
plot(PHAK.phase2.bd.turn)

## Boxplot of distances to centroid.
boxplot(PHAK.phase2.bd.turn, xlab = "amount", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("1", "2", "3"))

## Plots indicate that there is slight difference in multivariate 
## dispersion of turnover partition between amount of starting material. 
## Statistically check whether variance is different between amounts
## using standard parametric anova or permutation tests.
anova(PHAK.phase2.bd.turn)     # Significant difference 
permutest(PHAK.phase2.bd.turn) # Significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(PHAK.phase2.bd.turn)  # Significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by turnover. The metaMDS 
## function automatically transforms data and checks solution robustness.
PHAK.phase2.comm.turn <- metaMDS(PHAK.phase2.dist$beta.jtu, 
                                 dist = "jaccard", 
                                 k = 2,
                                 maxit = 999,
                                 trymax = 1000,
                                 noshare = TRUE,
                                 wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
PHAK.phase2.comm.turn$stress
stressplot(PHAK.phase2.comm.turn)

## Plot site scores as text.
ordiplot(PHAK.phase2.comm.turn, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
PHAK.phase2.turn.scores <- scores(PHAK.phase2.comm.turn, display = "sites")

## Add required metadata to compute centroids.
PHAK.phase2.turn.scores <- cbind(as.data.frame(PHAK.phase2.turn.scores), 
                                 Type = PHAK.beta.metadata$starting_material,
                                 Amount = PHAK.beta.metadata$amount,
                                 Sponge = PHAK.beta.metadata$sponge)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
PHAK.phase2.turn.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Type + Amount + Sponge, 
                                        data = PHAK.phase2.turn.scores, 
                                        FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
PHAK.phase2.turn.segments <- merge(PHAK.phase2.turn.scores, 
                                   setNames(PHAK.phase2.turn.centroids, 
                                            c("Type", "Amount", "Sponge", "oNMDS1", "oNMDS2")),
                                   by = c("Type", "Amount", "Sponge"), 
                                   sort = FALSE)

## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
PHAK.phase2.turn.adonis <- adonis(PHAK.phase2.dist$beta.jtu ~ starting_material
                                  + amount + starting_material:amount,
                                  PHAK.beta.metadata)

## Inspect results:
PHAK.phase2.turn.adonis

## Taxon replacement (i.e. turnover) is not influenced by type of 
## starting material, but is influenced by amount. Therefore, taxa in 
## one amount of starting material are being substituted by other taxa 
## in a different amount of starting material.


## 2. NESTEDNESS PARTITION (SUBSET OF CHANGE IN WIDER COMMUNITY)

## BY TYPE OF STARTING MATERIAL:
PHAK.phase2.bd.nest <- betadisper(PHAK.phase2.dist$beta.jne, 
                                  PHAK.beta.metadata$starting_material)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
PHAK.phase2.nest <- with(PHAK.beta.metadata, PHAK.phase2.bd.nest)
PHAK.phase2.nest

## Compute mean distance to centroid per group.
tapply(PHAK.phase2.bd.nest$distances, 
       PHAK.beta.metadata$starting_material, 
       mean)

## Compute variance per group.
tapply(PHAK.phase2.bd.nest$distances, 
       PHAK.beta.metadata$starting_material, 
       var)

## Ordination plot of distances to centroid.
plot(PHAK.phase2.bd.nest)

## Boxplot of distances to centroid.
boxplot(PHAK.phase2.bd.nest, xlab = "starting material", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:2), labels = c("Dried tissue", "Homogenate"))

## Plots indicate that there is little difference in multivariate 
## dispersion of nestedness partition between types of starting material. 
## Statistically check whether variance is different between types
## using standard parametric anova or permutation tests.
anova(PHAK.phase2.bd.nest)     # No significant difference 
permutest(PHAK.phase2.bd.nest) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(PHAK.phase2.bd.nest)  # No significant difference between groups


## BY AMOUNT OF STARTING MATERIAL:
PHAK.phase2.bd.nest <- betadisper(PHAK.phase2.dist$beta.jne, 
                                  PHAK.beta.metadata$amount)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
PHAK.phase2.nest <- with(PHAK.beta.metadata, PHAK.phase2.bd.nest)
PHAK.phase2.nest

## Compute mean distance to centroid per group.
tapply(PHAK.phase2.bd.nest$distances, 
       PHAK.beta.metadata$amount, 
       mean)

## Compute variance per group.
tapply(PHAK.phase2.bd.nest$distances, 
       PHAK.beta.metadata$amount, 
       var)

## Ordination plot of distances to centroid.
plot(PHAK.phase2.bd.nest)

## Boxplot of distances to centroid.
boxplot(PHAK.phase2.bd.nest, xlab = "amount", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("1", "2", "3"))

## Plots indicate that there is slight difference in multivariate 
## dispersion of nestedness partition between amount of starting material. 
## Statistically check whether variance is different between amounts
## using standard parametric anova or permutation tests.
anova(PHAK.phase2.bd.nest)     # No significant difference 
permutest(PHAK.phase2.bd.nest) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(PHAK.phase2.bd.nest)  # No significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by nestedness. The metaMDS 
## function automatically transforms data and checks solution robustness.
PHAK.phase2.comm.nest <- metaMDS(PHAK.phase2.dist$beta.jne, 
                                 dist = "jaccard", 
                                 k = 2,
                                 maxit = 999,
                                 trymax = 1000,
                                 noshare = TRUE,
                                 wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
PHAK.phase2.comm.nest$stress
stressplot(PHAK.phase2.comm.nest)

## Plot site scores as text.
ordiplot(PHAK.phase2.comm.nest, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
PHAK.phase2.nest.scores <- scores(PHAK.phase2.comm.nest, display = "sites")

## Add required metadata to compute centroids.
PHAK.phase2.nest.scores <- cbind(as.data.frame(PHAK.phase2.nest.scores), 
                                 Type = PHAK.beta.metadata$starting_material,
                                 Amount = PHAK.beta.metadata$amount,
                                 Sponge = PHAK.beta.metadata$sponge)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
PHAK.phase2.nest.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Type + Amount + Sponge, 
                                        data = PHAK.phase2.nest.scores, 
                                        FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
PHAK.phase2.nest.segments <- merge(PHAK.phase2.nest.scores, 
                                   setNames(PHAK.phase2.nest.centroids, 
                                            c("Type", "Amount", "Sponge", "oNMDS1", "oNMDS2")),
                                   by = c("Type", "Amount", "Sponge"), 
                                   sort = FALSE)

## Statistically check difference in nestedness of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
PHAK.phase2.nest.adonis <- adonis(PHAK.phase2.dist$beta.jne ~ starting_material
                                  + amount + starting_material:amount,
                                  PHAK.beta.metadata)

## Inspect results:
PHAK.phase2.nest.adonis

## There is no substantial difference in taxon loss or gain (i.e. nestedness) 
## between types or amounts of starting material, individually or combined.
## Therefore, taxa in one type and amount of starting material are not a
## subset of taxa in a different type and amount of starting material.


## 3. TOTAL BETA DIVERSITY

## BY TYPE OF STARTING MATERIAL:
PHAK.phase2.bd.total <- betadisper(PHAK.phase2.dist$beta.jac, 
                                   PHAK.beta.metadata$starting_material)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
PHAK.phase2.total <- with(PHAK.beta.metadata, PHAK.phase2.bd.total)
PHAK.phase2.total

## Compute mean distance to centroid per group.
tapply(PHAK.phase2.bd.total$distances, 
       PHAK.beta.metadata$starting_material, 
       mean)

## Compute variance per group.
tapply(PHAK.phase2.bd.total$distances, 
       PHAK.beta.metadata$starting_material, 
       var)

## Ordination plot of distances to centroid.
plot(PHAK.phase2.bd.total)

## Boxplot of distances to centroid.
boxplot(PHAK.phase2.bd.total, xlab = "starting material", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:2), labels = c("Dried tissue", "Homogenate"))

## Plots indicate that there is little difference in multivariate 
## dispersion of total beta diversity between types of starting material. 
## Statistically check whether variance is different between types
## using standard parametric anova or permutation tests.
anova(PHAK.phase2.bd.total)     # No significant difference 
permutest(PHAK.phase2.bd.total) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(PHAK.phase2.bd.total)  # No significant difference between groups


## BY AMOUNT OF STARTING MATERIAL:
PHAK.phase2.bd.total <- betadisper(PHAK.phase2.dist$beta.jac, 
                                   PHAK.beta.metadata$amount)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
PHAK.phase2.total <- with(PHAK.beta.metadata, PHAK.phase2.bd.total)
PHAK.phase2.total

## Compute mean distance to centroid per group.
tapply(PHAK.phase2.bd.total$distances, 
       PHAK.beta.metadata$amount, 
       mean)

## Compute variance per group.
tapply(PHAK.phase2.bd.total$distances, 
       PHAK.beta.metadata$amount, 
       var)

## Ordination plot of distances to centroid.
plot(PHAK.phase2.bd.total)

## Boxplot of distances to centroid.
boxplot(PHAK.phase2.bd.total, xlab = "amount", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("1", "2", "3"))

## Plots indicate that there is slight difference in multivariate 
## dispersion of total beta diversity between amounts of starting material. 
## Statistically check whether variance is different between amounts
## using standard parametric anova or permutation tests.
anova(PHAK.phase2.bd.total)     # No significant difference 
permutest(PHAK.phase2.bd.total) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(PHAK.phase2.bd.total)  # No significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by nestedness. The metaMDS 
## function automatically transforms data and checks solution robustness.
PHAK.phase2.comm.total <- metaMDS(PHAK.phase2.dist$beta.jac, 
                                  dist = "jaccard", 
                                  k = 2,
                                  maxit = 999,
                                  trymax = 1000,
                                  noshare = TRUE,
                                  wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
PHAK.phase2.comm.total$stress
stressplot(PHAK.phase2.comm.total)

## Plot site scores as text.
ordiplot(PHAK.phase2.comm.total, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
PHAK.phase2.total.scores <- scores(PHAK.phase2.comm.total, display = "sites")

## Add required metadata to compute centroids.
PHAK.phase2.total.scores <- cbind(as.data.frame(PHAK.phase2.total.scores), 
                                  Type = PHAK.beta.metadata$starting_material,
                                  Amount = PHAK.beta.metadata$amount,
                                  Sponge = PHAK.beta.metadata$sponge)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
PHAK.phase2.total.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Type + Amount + Sponge, 
                                         data = PHAK.phase2.total.scores, 
                                         FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
PHAK.phase2.total.segments <- merge(PHAK.phase2.total.scores, 
                                    setNames(PHAK.phase2.total.centroids, 
                                             c("Type", "Amount", "Sponge", "oNMDS1", "oNMDS2")),
                                    by = c("Type", "Amount", "Sponge"), 
                                    sort = FALSE)

## Statistically check difference in nestedness of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
PHAK.phase2.total.adonis <- adonis(PHAK.phase2.dist$beta.jac ~ starting_material
                                   + amount + starting_material:amount,
                                   PHAK.beta.metadata)

## Inspect results:
PHAK.phase2.total.adonis

## There is no substantial difference in total beta diversity between 
## types or amounts of starting material, individually or combined.
## Therefore, communities in one type and amount of starting material 
## are not substantially different to other types and amounts of 
## starting material.


#---------------------#
# VAZELLA POURTALESII #
#---------------------#

## Make a copy of phase2.df where reads are summed by sequencing_ID,
## sample_ID, starting_material, amount, extraction_replicate,
## group and taxon. Remove mammal detections from the dataset.
VAZ.phase2.beta <- phase2.df %>%
  drop_na() %>%
  filter(sponge == "VAZ") %>%
  group_by(sequencing_ID, sponge, sample_ID, starting_material, 
           amount, extraction_replicate, group, taxon) %>%
  summarise(reads = sum(reads), .groups = "keep") %>%
  ungroup() %>%
  filter(!group == "mammal") %>%
  droplevels()

## Create metadata for beta diversity analyses.
VAZ.beta.metadata <- VAZ.phase2.beta %>%
  dplyr::select(-c(group, taxon, reads)) %>%
  mutate(amount = as.factor(gsub("H|W", "", amount)),
         extraction_replicate = as.factor(extraction_replicate)) %>%
  distinct()

## Now convert phase2.beta into wide format for beta diversity analyses.
VAZ.phase2.beta <- VAZ.phase2.beta %>%
  dplyr::select(-c(sponge, sample_ID, starting_material, amount,
                   extraction_replicate, group)) %>%
  pivot_wider(names_from = taxon, 
              values_from = reads,
              values_fill = 0) %>%
  column_to_rownames("sequencing_ID")

## Remove empty samples and taxonomic assignments as these are problematic 
## for vegan.
VAZ.phase2.beta <- VAZ.phase2.beta[!sapply(VAZ.phase2.beta, function(x) all(x == 0))]
VAZ.phase2.beta <- VAZ.phase2.beta[!apply(VAZ.phase2.beta == 0, 1, all),]

## Convert read count data to presence-absence.
VAZ.phase2.beta[VAZ.phase2.beta > 0] <- 1

## Create vector of sample IDs that have been retained for beta diversity
## analyses.
VAZ.complete.IDs <- rownames(VAZ.phase2.beta)

## Remove samples that were empty from beta.metadata.
VAZ.beta.metadata <- VAZ.beta.metadata[VAZ.beta.metadata$sequencing_ID %in% VAZ.complete.IDs,]


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO TYPE OF STARTING MATERIAL
## Create vectors of sample IDs associated with each type of starting
## material.
VAZ.tissue <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", starting_material == "Dried tissue"))
VAZ.homogenate <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", starting_material == "Homogenate"))

## Create copies of phase2.beta for each type of starting material.
VAZ.tissue.beta <- VAZ.phase2.beta[rownames(VAZ.phase2.beta) %in% VAZ.tissue$sequencing_ID,]
VAZ.homogenate.beta <- VAZ.phase2.beta[rownames(VAZ.phase2.beta) %in% VAZ.homogenate$sequencing_ID,]

## Beta diversity across dried tissue samples.
VAZ.tissue.multi <- beta.multi(VAZ.tissue.beta, index.family = "jaccard")
print(VAZ.tissue.multi)

## Beta diversity across homogenate samples.
VAZ.homogenate.multi <- beta.multi(VAZ.homogenate.beta, index.family = "jaccard")
print(VAZ.homogenate.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for each type of starting material.


## BETA DIVERSITY CONTRIBUTIONS ACCORDING TO AMOUNT OF STARTING MATERIAL
## Create vectors of sample IDs associated with each amount of starting
## material.
VAZ.amount1 <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", amount == "1"))
VAZ.amount2 <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", amount == "2"))
VAZ.amount3 <- droplevels(subset(VAZ.beta.metadata, select = "sequencing_ID", amount == "3"))

## Create copies of phase2.beta for each amount of starting material.
VAZ.amount1.beta <- VAZ.phase2.beta[rownames(VAZ.phase2.beta) %in% VAZ.amount1$sequencing_ID,]
VAZ.amount2.beta <- VAZ.phase2.beta[rownames(VAZ.phase2.beta) %in% VAZ.amount2$sequencing_ID,]
VAZ.amount3.beta <- VAZ.phase2.beta[rownames(VAZ.phase2.beta) %in% VAZ.amount3$sequencing_ID,]

## Beta diversity across amount 1 samples.
VAZ.amount1.multi <- beta.multi(VAZ.amount1.beta, index.family = "jaccard")
print(VAZ.amount1.multi)

## Beta diversity across amount 2 samples.
VAZ.amount2.multi <- beta.multi(VAZ.amount2.beta, index.family = "jaccard")
print(VAZ.amount2.multi)

## Beta diversity across amount 3 samples.
VAZ.amount3.multi <- beta.multi(VAZ.amount3.beta, index.family = "jaccard")
print(VAZ.amount3.multi)

## The majority of total beta diversity arises from taxon turnover
## rather than nestedness for each amount of starting material.


## Remove VAZ3-H2-REP2 and VAZ2-W2-REP3 as these are outliers which skew
## NMDS visualisation.
VAZ.beta.metadata <- VAZ.beta.metadata %>%
  filter(!grepl("VAZ3-H2-REP2|VAZ2-W2-REP3", 
                sequencing_ID)) %>%
  droplevels()

VAZ.phase2.beta <- VAZ.phase2.beta[which(!grepl("VAZ3-H2-REP2|VAZ2-W2-REP3",
                                                rownames(VAZ.phase2.beta))),]

## Pairwise between-site values of each component of beta diversity
VAZ.phase2.dist <- beta.pair(VAZ.phase2.beta, index.family = "jaccard")


## 1. TURNOVER PARTITION (COMPLETE CHANGE IN COMMUNITIES)

## BY TYPE OF STARTING MATERIAL:
VAZ.phase2.bd.turn <- betadisper(VAZ.phase2.dist$beta.jtu, 
                                 VAZ.beta.metadata$starting_material)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase2.turn <- with(VAZ.beta.metadata, VAZ.phase2.bd.turn)
VAZ.phase2.turn

## Compute mean distance to centroid per group.
tapply(VAZ.phase2.bd.turn$distances, 
       VAZ.beta.metadata$starting_material, 
       mean)

## Compute variance per group.
tapply(VAZ.phase2.bd.turn$distances, 
       VAZ.beta.metadata$starting_material, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase2.bd.turn)

## Boxplot of distances to centroid.
boxplot(VAZ.phase2.bd.turn, xlab = "starting material", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:2), labels = c("Dried tissue", "Homogenate"))

## Plots indicate that there is little difference in multivariate 
## dispersion of turnover partition between types of starting material. 
## Statistically check whether variance is different between types
## using standard parametric anova or permutation tests.
anova(VAZ.phase2.bd.turn)     # No significant difference 
permutest(VAZ.phase2.bd.turn) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase2.bd.turn)  # No significant difference between groups


## BY AMOUNT OF STARTING MATERIAL:
VAZ.phase2.bd.turn <- betadisper(VAZ.phase2.dist$beta.jtu,
                                 VAZ.beta.metadata$amount)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase2.turn <- with(VAZ.beta.metadata, VAZ.phase2.bd.turn)
VAZ.phase2.turn

## Compute mean distance to centroid per group.
tapply(VAZ.phase2.bd.turn$distances, 
       VAZ.beta.metadata$amount, 
       mean)

## Compute variance per group.
tapply(VAZ.phase2.bd.turn$distances, 
       VAZ.beta.metadata$amount, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase2.bd.turn)

## Boxplot of distances to centroid.
boxplot(VAZ.phase2.bd.turn, xlab = "amount", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("1", "2", "3"))

## Plots indicate that there is slight difference in multivariate 
## dispersion of turnover partition between amount of starting material. 
## Statistically check whether variance is different between amounts
## using standard parametric anova or permutation tests.
anova(VAZ.phase2.bd.turn)     # No significant difference 
permutest(VAZ.phase2.bd.turn) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase2.bd.turn)  # No significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by turnover. The metaMDS 
## function automatically transforms data and checks solution robustness.
VAZ.phase2.comm.turn <- metaMDS(VAZ.phase2.dist$beta.jtu, 
                                dist = "jaccard", 
                                k = 2,
                                maxit = 999,
                                trymax = 1000,
                                noshare = TRUE,
                                wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
VAZ.phase2.comm.turn$stress
stressplot(VAZ.phase2.comm.turn)

## Plot site scores as text.
ordiplot(VAZ.phase2.comm.turn, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
VAZ.phase2.turn.scores <- scores(VAZ.phase2.comm.turn, display = "sites")

## Add required metadata to compute centroids.
VAZ.phase2.turn.scores <- cbind(as.data.frame(VAZ.phase2.turn.scores), 
                                Type = VAZ.beta.metadata$starting_material,
                                Amount = VAZ.beta.metadata$amount,
                                Sponge = VAZ.beta.metadata$sponge)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
VAZ.phase2.turn.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Type + Amount + Sponge, 
                                       data = VAZ.phase2.turn.scores, 
                                       FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
VAZ.phase2.turn.segments <- merge(VAZ.phase2.turn.scores, 
                                  setNames(VAZ.phase2.turn.centroids, 
                                           c("Type", "Amount", "Sponge", "oNMDS1", "oNMDS2")),
                                  by = c("Type", "Amount", "Sponge"), 
                                  sort = FALSE)

## Statistically check difference in spatial turnover of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
VAZ.phase2.turn.adonis <- adonis(VAZ.phase2.dist$beta.jtu ~ starting_material
                                 + amount + starting_material:amount,
                                 VAZ.beta.metadata)

## Inspect results:
VAZ.phase2.turn.adonis

## Taxon replacement (i.e. turnover) is influenced by type of 
## starting material, but not influenced by amount. Therefore, taxa in 
## one type of starting material are being substituted by other taxa 
## in a different type of starting material.


## 2. NESTEDNESS PARTITION (SUBSET OF CHANGE IN WIDER COMMUNITY)

## BY TYPE OF STARTING MATERIAL:
VAZ.phase2.bd.nest <- betadisper(VAZ.phase2.dist$beta.jne, 
                                 VAZ.beta.metadata$starting_material)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase2.nest <- with(VAZ.beta.metadata, VAZ.phase2.bd.nest)
VAZ.phase2.nest

## Compute mean distance to centroid per group.
tapply(VAZ.phase2.bd.nest$distances, 
       VAZ.beta.metadata$starting_material, 
       mean)

## Compute variance per group.
tapply(VAZ.phase2.bd.nest$distances, 
       VAZ.beta.metadata$starting_material, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase2.bd.nest)

## Boxplot of distances to centroid.
boxplot(VAZ.phase2.bd.nest, xlab = "starting material", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:2), labels = c("Dried tissue", "Homogenate"))

## Plots indicate that there is little difference in multivariate 
## dispersion of nestedness partition between types of starting material. 
## Statistically check whether variance is different between types
## using standard parametric anova or permutation tests.
anova(VAZ.phase2.bd.nest)     # No significant difference 
permutest(VAZ.phase2.bd.nest) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase2.bd.nest)  # No significant difference between groups


## BY AMOUNT OF STARTING MATERIAL:
VAZ.phase2.bd.nest <- betadisper(VAZ.phase2.dist$beta.jne, 
                                 VAZ.beta.metadata$amount)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase2.nest <- with(VAZ.beta.metadata, VAZ.phase2.bd.nest)
VAZ.phase2.nest

## Compute mean distance to centroid per group.
tapply(VAZ.phase2.bd.nest$distances, 
       VAZ.beta.metadata$amount, 
       mean)

## Compute variance per group.
tapply(VAZ.phase2.bd.nest$distances, 
       VAZ.beta.metadata$amount, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase2.bd.nest)

## Boxplot of distances to centroid.
boxplot(VAZ.phase2.bd.nest, xlab = "amount", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("1", "2", "3"))

## Plots indicate that there is slight difference in multivariate 
## dispersion of nestedness partition between amount of starting material. 
## Statistically check whether variance is different between amounts
## using standard parametric anova or permutation tests.
anova(VAZ.phase2.bd.nest)     # No significant difference 
permutest(VAZ.phase2.bd.nest) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase2.bd.nest)  # No significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by nestedness. The metaMDS 
## function automatically transforms data and checks solution robustness.
VAZ.phase2.comm.nest <- metaMDS(VAZ.phase2.dist$beta.jne, 
                                dist = "jaccard", 
                                k = 2,
                                maxit = 999,
                                trymax = 1000,
                                noshare = TRUE,
                                wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
VAZ.phase2.comm.nest$stress
stressplot(VAZ.phase2.comm.nest)

## Plot site scores as text.
ordiplot(VAZ.phase2.comm.nest, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
VAZ.phase2.nest.scores <- scores(VAZ.phase2.comm.nest, display = "sites")

## Add required metadata to compute centroids.
VAZ.phase2.nest.scores <- cbind(as.data.frame(VAZ.phase2.nest.scores), 
                                Type = VAZ.beta.metadata$starting_material,
                                Amount = VAZ.beta.metadata$amount,
                                Sponge = VAZ.beta.metadata$sponge)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
VAZ.phase2.nest.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Type + Amount + Sponge, 
                                       data = VAZ.phase2.nest.scores, 
                                       FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
VAZ.phase2.nest.segments <- merge(VAZ.phase2.nest.scores, 
                                  setNames(VAZ.phase2.nest.centroids, 
                                           c("Type", "Amount", "Sponge", "oNMDS1", "oNMDS2")),
                                  by = c("Type", "Amount", "Sponge"), 
                                  sort = FALSE)

## Statistically check difference in nestedness of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
VAZ.phase2.nest.adonis <- adonis(VAZ.phase2.dist$beta.jne ~ starting_material
                                 + amount + starting_material:amount,
                                 VAZ.beta.metadata)

## Inspect results:
VAZ.phase2.nest.adonis

## There is no substantial difference in taxon loss or gain (i.e. nestedness) 
## between types or amounts of starting material, individually or combined.
## Therefore, taxa in one type and amount of starting material are not a
## subset of taxa in a different type and amount of starting material.


## 3. TOTAL BETA DIVERSITY

## BY TYPE OF STARTING MATERIAL:
VAZ.phase2.bd.total <- betadisper(VAZ.phase2.dist$beta.jac, 
                                  VAZ.beta.metadata$starting_material)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase2.total <- with(VAZ.beta.metadata, VAZ.phase2.bd.total)
VAZ.phase2.total

## Compute mean distance to centroid per group.
tapply(VAZ.phase2.bd.total$distances, 
       VAZ.beta.metadata$starting_material, 
       mean)

## Compute variance per group.
tapply(VAZ.phase2.bd.total$distances, 
       VAZ.beta.metadata$starting_material, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase2.bd.total)

## Boxplot of distances to centroid.
boxplot(VAZ.phase2.bd.total, xlab = "starting material", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:2), labels = c("Dried tissue", "Homogenate"))

## Plots indicate that there is little difference in multivariate 
## dispersion of total beta diversity between types of starting material. 
## Statistically check whether variance is different between types
## using standard parametric anova or permutation tests.
anova(VAZ.phase2.bd.total)     # No significant difference 
permutest(VAZ.phase2.bd.total) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase2.bd.total)  # No significant difference between groups


## BY AMOUNT OF STARTING MATERIAL:
VAZ.phase2.bd.total <- betadisper(VAZ.phase2.dist$beta.jac, 
                                  VAZ.beta.metadata$amount)

## Check homogeneity of multivariate dispersions. Groups being tested 
## should have the sample multivariate spread to conform to assumptions 
## of PERMANOVA.
VAZ.phase2.total <- with(VAZ.beta.metadata, VAZ.phase2.bd.total)
VAZ.phase2.total

## Compute mean distance to centroid per group.
tapply(VAZ.phase2.bd.total$distances, 
       VAZ.beta.metadata$amount, 
       mean)

## Compute variance per group.
tapply(VAZ.phase2.bd.total$distances, 
       VAZ.beta.metadata$amount, 
       var)

## Ordination plot of distances to centroid.
plot(VAZ.phase2.bd.total)

## Boxplot of distances to centroid.
boxplot(VAZ.phase2.bd.total, xlab = "amount", xaxt = "n", bty = "n")
axis(side = 1, at = c(1:3), labels = c("1", "2", "3"))

## Plots indicate that there is slight difference in multivariate 
## dispersion of total beta diversity between amounts of starting material. 
## Statistically check whether variance is different between amounts
## using standard parametric anova or permutation tests.
anova(VAZ.phase2.bd.total)     # No significant difference 
permutest(VAZ.phase2.bd.total) # No significant difference 

## Analyse pairwise differences between groups using parametric Tukey's 
## HSD test.
TukeyHSD(VAZ.phase2.bd.total)  # No significant difference between groups


## NMDS
## Ordination of beta diversity partitioned by nestedness. The metaMDS 
## function automatically transforms data and checks solution robustness.
VAZ.phase2.comm.total <- metaMDS(VAZ.phase2.dist$beta.jac, 
                                 dist = "jaccard", 
                                 k = 2,
                                 maxit = 999,
                                 trymax = 1000,
                                 noshare = TRUE,
                                 wascores = TRUE)

## Assess goodness of ordination fit (stress plot).
VAZ.phase2.comm.total$stress
stressplot(VAZ.phase2.comm.total)

## Plot site scores as text.
ordiplot(VAZ.phase2.comm.total, display = "sites", type = "text", cex = 0.5)

## Extract NMDS scores.
VAZ.phase2.total.scores <- scores(VAZ.phase2.comm.total, display = "sites")

## Add required metadata to compute centroids.
VAZ.phase2.total.scores <- cbind(as.data.frame(VAZ.phase2.total.scores), 
                                 Type = VAZ.beta.metadata$starting_material,
                                 Amount = VAZ.beta.metadata$amount,
                                 Sponge = VAZ.beta.metadata$sponge)

## Compute the group centroids, i.e. the mean coordinate on each axis
## for each group.
VAZ.phase2.total.centroids <- aggregate(cbind(NMDS1, NMDS2) ~ Type + Amount + Sponge, 
                                        data = VAZ.phase2.total.scores, 
                                        FUN = mean)

## Replicate the group centroid for each observation in each group by 
## merging the NMDS scores with the calculated group centroids.
VAZ.phase2.total.segments <- merge(VAZ.phase2.total.scores, 
                                   setNames(VAZ.phase2.total.centroids, 
                                            c("Type", "Amount", "Sponge", "oNMDS1", "oNMDS2")),
                                   by = c("Type", "Amount", "Sponge"), 
                                   sort = FALSE)

## Statistically check difference in nestedness of communities.
## Apply PERMANOVA using adonis(), considered more robust than anosim()
VAZ.phase2.total.adonis <- adonis(VAZ.phase2.dist$beta.jac ~ starting_material
                                  + amount + starting_material:amount,
                                  VAZ.beta.metadata)

## Inspect results:
VAZ.phase2.total.adonis

## There is no substantial difference in total beta diversity between 
## amounts of starting material, only type of starting material.
## Therefore, communities in one type of starting material are 
## substantially different to other types of starting material.


#===============#
# SUMMARY PLOTS #
#===============#

## Bind dataframes for scores, centroids and segments for each component
## of beta diversity and each sponge species. Remove VAZ3-H2-REP2 and
## VAZ2-W2-REP3 as these are outliers which skew NMDS visualisation.
## Scores:
phase2.turn.scores <- bind_rows(PHAK.phase2.turn.scores,
                                VAZ.phase2.turn.scores)

phase2.nest.scores <- bind_rows(PHAK.phase2.nest.scores,
                                VAZ.phase2.nest.scores)

phase2.total.scores <- bind_rows(PHAK.phase2.total.scores,
                                 VAZ.phase2.total.scores)

## Centroids:
phase2.turn.centroids <- bind_rows(PHAK.phase2.turn.centroids,
                                   VAZ.phase2.turn.centroids)

phase2.nest.centroids <- bind_rows(PHAK.phase2.nest.centroids,
                                   VAZ.phase2.nest.centroids)

phase2.total.centroids <- bind_rows(PHAK.phase2.total.centroids,
                                    VAZ.phase2.total.centroids)

## Segments:
phase2.turn.segments <- bind_rows(PHAK.phase2.turn.segments,
                                  VAZ.phase2.turn.segments)

phase2.nest.segments <- bind_rows(PHAK.phase2.nest.segments,
                                  VAZ.phase2.nest.segments)

phase2.total.segments <- bind_rows(PHAK.phase2.total.segments,
                                   VAZ.phase2.total.segments)


## Plot beta diversity partitioned by turnover.
p11a <- ggplot(phase2.turn.scores, 
               aes(x = NMDS1, y = NMDS2, 
                   fill = Amount, shape = Sponge)) + 
  geom_point(data = phase2.turn.centroids, size = 5, alpha = 0.5) + 
  geom_segment(data = phase2.turn.segments,
               mapping = aes(xend = oNMDS1, yend = oNMDS2, 
                             colour = Amount)) +
  geom_point(size = 3, alpha = 0.5) +
  scale_fill_manual(name = "Amount",
                    values = c("darkorange", "purple", "cyan4")) +
  scale_colour_manual(name = "Amount",
                      values = c("darkorange", "purple", "cyan4"),
                      guide = "none") +
  scale_shape_manual(name = "Sponge",
                     values = c(21, 24)) +
  scale_x_continuous(limits = c(-0.8, 0.8), breaks = seq(-0.8, 0.8, 0.4),
                     labels = scales::number_format(accuracy = 0.1)) + 
  scale_y_continuous(limits = c(-0.4, 0.4), breaks = seq(-0.4, 0.4, 0.2),
                     labels = scales::number_format(accuracy = 0.1)) + 
  guides(fill = guide_legend(override.aes = list(shape = 21, size = 5)),
         shape = guide_legend(override.aes = list(size = 5))) +
  labs(title = expression(bold("(c) "~beta~-"diversity")), 
       subtitle = "(i) Turnover", 
       x = "NMDS1", y = "NMDS2") + 
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        plot.subtitle = element_text(face = "bold", hjust = 0, color = "black", margin = unit(c(2, 0, 0, 0), "mm")),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "bottom") +
  facet_grid(Sponge ~ Type)
p11a

## Plot beta diversity partitioned by nestedness-resultant.
p11b <- ggplot(phase2.nest.scores, 
               aes(x = NMDS1, y = NMDS2, 
                   fill = Amount, shape = Sponge)) + 
  geom_point(data = phase2.nest.centroids, size = 5, alpha = 0.5) + 
  geom_segment(data = phase2.nest.segments,
               mapping = aes(xend = oNMDS1, yend = oNMDS2, 
                             colour = Amount)) +
  geom_point(size = 3, alpha = 0.5) +
  scale_fill_manual(name = "Amount",
                    values = c("darkorange", "purple", "cyan4")) +
  scale_colour_manual(name = "Amount",
                      values = c("darkorange", "purple", "cyan4"),
                      guide = "none") +
  scale_shape_manual(name = "Sponge",
                     values = c(21, 24)) +
  scale_x_continuous(limits = c(-0.6, 0.6), breaks = seq(-0.6, 0.6, 0.3),
                     labels = scales::number_format(accuracy = 0.1)) + 
  scale_y_continuous(limits = c(-0.4, 0.4), breaks = seq(-0.4, 0.4, 0.2),
                     labels = scales::number_format(accuracy = 0.1)) + 
  guides(fill = guide_legend(override.aes = list(shape = 21, size = 5)),
         shape = guide_legend(override.aes = list(size = 5))) +
  labs(subtitle = "(ii) Nestedness-resultant", 
       x = "NMDS1", y = "NMDS2") + 
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        plot.subtitle = element_text(face = "bold", hjust = 0, color = "black", margin = unit(c(2, 0, 0, 0), "mm")),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "bottom") +
  facet_grid(Sponge ~ Type)
p11b

## Plot total beta diversity.
p11c <- ggplot(phase2.total.scores, 
               aes(x = NMDS1, y = NMDS2, 
                   fill = Amount, shape = Sponge)) + 
  geom_point(data = phase2.total.centroids, size = 5, alpha = 0.5) + 
  geom_segment(data = phase2.total.segments,
               mapping = aes(xend = oNMDS1, yend = oNMDS2, 
                             colour = Amount)) +
  geom_point(size = 3, alpha = 0.5) +
  scale_fill_manual(name = "Amount",
                    values = c("darkorange", "purple", "cyan4")) +
  scale_colour_manual(name = "Amount",
                      values = c("darkorange", "purple", "cyan4"),
                      guide = "none") +
  scale_shape_manual(name = "Sponge",
                     values = c(21, 24)) +
  scale_x_continuous(limits = c(-0.6, 0.6), breaks = seq(-0.6, 0.6, 0.3),
                     labels = scales::number_format(accuracy = 0.1)) + 
  scale_y_continuous(limits = c(-0.2, 0.6), breaks = seq(-0.2, 0.6, 0.2),
                     labels = scales::number_format(accuracy = 0.1)) + 
  guides(fill = guide_legend(override.aes = list(shape = 21, size = 5)),
         shape = guide_legend(override.aes = list(size = 5))) +
  labs(subtitle = expression(bold("(c) Total"~beta~-"diversity")), 
       x = "NMDS1", y = "NMDS2") + 
  theme_bw() +
  theme(panel.background = element_rect(fill = "white"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        plot.title = element_text(face = "bold", hjust = 0, colour = "black"),
        plot.subtitle = element_text(face = "bold", hjust = 0, color = "black", margin = unit(c(2, 0, 0, 0), "mm")),
        axis.title.x = element_text(margin = unit(c(8, 0, 0, 0), "mm")),
        axis.title.y = element_text(margin = unit(c(0, 5, 0, 0), "mm")),
        axis.text.x = element_text(colour = "black"),
        axis.text.y = element_text(colour = "black"),
        strip.text.y = element_text(angle = 360),
        text = element_text(size = 20),
        legend.key = element_blank(),
        legend.position = "bottom") +
  facet_grid(Sponge ~ Type)
p11c


## Plot all diversity results.
g5 <- ggarrange(ggarrange(p9, p10, nrow = 2, ncol = 1, align = "hv"),
                ggarrange(p11a, p11b, p11c, nrow = 3,  ncol = 1, 
                          align = "hv", common.legend = TRUE, legend = "right"),
                nrow = 1, ncol = 2)

## Export plot.
#ggsave(filename = "../figures/Fig7_phase2_alpha_beta_diversity.jpeg", 
#       plot = g5, width = 25, height = 20, dpi = 300, units = "in")


#################
# END OF SCRIPT #
#################

